@@ -3,81 +3,113 @@ import functools
 import logging
 import voluptuous as vol
 
-from homeassistant.components.media_player import (
-    MediaPlayerDevice, PLATFORM_SCHEMA)
+from homeassistant.components.media_player import MediaPlayerDevice, PLATFORM_SCHEMA
 from homeassistant.components.media_player.const import (
-    SUPPORT_NEXT_TRACK, SUPPORT_PAUSE, SUPPORT_PLAY, SUPPORT_PREVIOUS_TRACK,
-    SUPPORT_SELECT_SOURCE, SUPPORT_STOP, SUPPORT_TURN_OFF, SUPPORT_TURN_ON,
-    SUPPORT_VOLUME_MUTE, SUPPORT_VOLUME_STEP)
+    SUPPORT_NEXT_TRACK,
+    SUPPORT_PAUSE,
+    SUPPORT_PLAY,
+    SUPPORT_PREVIOUS_TRACK,
+    SUPPORT_SELECT_SOURCE,
+    SUPPORT_STOP,
+    SUPPORT_TURN_OFF,
+    SUPPORT_TURN_ON,
+    SUPPORT_VOLUME_MUTE,
+    SUPPORT_VOLUME_STEP,
+)
 from homeassistant.const import (
-    ATTR_COMMAND, ATTR_ENTITY_ID, CONF_DEVICE_CLASS, CONF_HOST, CONF_NAME,
-    CONF_PORT, STATE_IDLE, STATE_OFF, STATE_PAUSED, STATE_PLAYING,
-    STATE_STANDBY)
+    ATTR_COMMAND,
+    ATTR_ENTITY_ID,
+    CONF_DEVICE_CLASS,
+    CONF_HOST,
+    CONF_NAME,
+    CONF_PORT,
+    STATE_IDLE,
+    STATE_OFF,
+    STATE_PAUSED,
+    STATE_PLAYING,
+    STATE_STANDBY,
+)
 from homeassistant.exceptions import PlatformNotReady
 import homeassistant.helpers.config_validation as cv
 
-ANDROIDTV_DOMAIN = 'androidtv'
+ANDROIDTV_DOMAIN = "androidtv"
 
 _LOGGER = logging.getLogger(__name__)
 
-SUPPORT_ANDROIDTV = SUPPORT_PAUSE | SUPPORT_PLAY | \
-    SUPPORT_TURN_ON | SUPPORT_TURN_OFF | SUPPORT_PREVIOUS_TRACK | \
-    SUPPORT_NEXT_TRACK | SUPPORT_STOP | SUPPORT_VOLUME_MUTE | \
-    SUPPORT_VOLUME_STEP
+SUPPORT_ANDROIDTV = (
+    SUPPORT_PAUSE
+    | SUPPORT_PLAY
+    | SUPPORT_TURN_ON
+    | SUPPORT_TURN_OFF
+    | SUPPORT_PREVIOUS_TRACK
+    | SUPPORT_NEXT_TRACK
+    | SUPPORT_STOP
+    | SUPPORT_VOLUME_MUTE
+    | SUPPORT_VOLUME_STEP
+)
 
-SUPPORT_FIRETV = SUPPORT_PAUSE | SUPPORT_PLAY | \
-    SUPPORT_TURN_ON | SUPPORT_TURN_OFF | SUPPORT_PREVIOUS_TRACK | \
-    SUPPORT_NEXT_TRACK | SUPPORT_SELECT_SOURCE | SUPPORT_STOP
+SUPPORT_FIRETV = (
+    SUPPORT_PAUSE
+    | SUPPORT_PLAY
+    | SUPPORT_TURN_ON
+    | SUPPORT_TURN_OFF
+    | SUPPORT_PREVIOUS_TRACK
+    | SUPPORT_NEXT_TRACK
+    | SUPPORT_SELECT_SOURCE
+    | SUPPORT_STOP
+)
 
-CONF_ADBKEY = 'adbkey'
-CONF_ADB_SERVER_IP = 'adb_server_ip'
-CONF_ADB_SERVER_PORT = 'adb_server_port'
-CONF_APPS = 'apps'
-CONF_GET_SOURCES = 'get_sources'
-CONF_TURN_ON_COMMAND = 'turn_on_command'
-CONF_TURN_OFF_COMMAND = 'turn_off_command'
+CONF_ADBKEY = "adbkey"
+CONF_ADB_SERVER_IP = "adb_server_ip"
+CONF_ADB_SERVER_PORT = "adb_server_port"
+CONF_APPS = "apps"
+CONF_GET_SOURCES = "get_sources"
+CONF_TURN_ON_COMMAND = "turn_on_command"
+CONF_TURN_OFF_COMMAND = "turn_off_command"
 
-DEFAULT_NAME = 'Android TV'
+DEFAULT_NAME = "Android TV"
 DEFAULT_PORT = 5555
 DEFAULT_ADB_SERVER_PORT = 5037
 DEFAULT_GET_SOURCES = True
-DEFAULT_DEVICE_CLASS = 'auto'
+DEFAULT_DEVICE_CLASS = "auto"
 
-DEVICE_ANDROIDTV = 'androidtv'
-DEVICE_FIRETV = 'firetv'
+DEVICE_ANDROIDTV = "androidtv"
+DEVICE_FIRETV = "firetv"
 DEVICE_CLASSES = [DEFAULT_DEVICE_CLASS, DEVICE_ANDROIDTV, DEVICE_FIRETV]
 
-SERVICE_ADB_COMMAND = 'adb_command'
+SERVICE_ADB_COMMAND = "adb_command"
 
-SERVICE_ADB_COMMAND_SCHEMA = vol.Schema({
-    vol.Required(ATTR_ENTITY_ID): cv.entity_ids,
-    vol.Required(ATTR_COMMAND): cv.string,
-})
+SERVICE_ADB_COMMAND_SCHEMA = vol.Schema(
+    {vol.Required(ATTR_ENTITY_ID): cv.entity_ids, vol.Required(ATTR_COMMAND): cv.string}
+)
 
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend({
-    vol.Required(CONF_HOST): cv.string,
-    vol.Optional(CONF_DEVICE_CLASS, default=DEFAULT_DEVICE_CLASS):
-        vol.In(DEVICE_CLASSES),
-    vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
-    vol.Optional(CONF_PORT, default=DEFAULT_PORT): cv.port,
-    vol.Optional(CONF_ADBKEY): cv.isfile,
-    vol.Optional(CONF_ADB_SERVER_IP): cv.string,
-    vol.Optional(CONF_ADB_SERVER_PORT, default=DEFAULT_ADB_SERVER_PORT):
-        cv.port,
-    vol.Optional(CONF_GET_SOURCES, default=DEFAULT_GET_SOURCES): cv.boolean,
-    vol.Optional(CONF_APPS, default=dict()):
-        vol.Schema({cv.string: cv.string}),
-    vol.Optional(CONF_TURN_ON_COMMAND): cv.string,
-    vol.Optional(CONF_TURN_OFF_COMMAND): cv.string
-})
+PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
+    {
+        vol.Required(CONF_HOST): cv.string,
+        vol.Optional(CONF_DEVICE_CLASS, default=DEFAULT_DEVICE_CLASS): vol.In(
+            DEVICE_CLASSES
+        ),
+        vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
+        vol.Optional(CONF_PORT, default=DEFAULT_PORT): cv.port,
+        vol.Optional(CONF_ADBKEY): cv.isfile,
+        vol.Optional(CONF_ADB_SERVER_IP): cv.string,
+        vol.Optional(CONF_ADB_SERVER_PORT, default=DEFAULT_ADB_SERVER_PORT): cv.port,
+        vol.Optional(CONF_GET_SOURCES, default=DEFAULT_GET_SOURCES): cv.boolean,
+        vol.Optional(CONF_APPS, default=dict()): vol.Schema({cv.string: cv.string}),
+        vol.Optional(CONF_TURN_ON_COMMAND): cv.string,
+        vol.Optional(CONF_TURN_OFF_COMMAND): cv.string,
+    }
+)
 
 # Translate from `AndroidTV` / `FireTV` reported state to HA state.
-ANDROIDTV_STATES = {'off': STATE_OFF,
-                    'idle': STATE_IDLE,
-                    'standby': STATE_STANDBY,
-                    'playing': STATE_PLAYING,
-                    'paused': STATE_PAUSED}
+ANDROIDTV_STATES = {
+    "off": STATE_OFF,
+    "idle": STATE_IDLE,
+    "standby": STATE_STANDBY,
+    "playing": STATE_PLAYING,
+    "paused": STATE_PAUSED,
+}
 
 
 def setup_platform(hass, config, add_entities, discovery_info=None):
@@ -86,14 +118,15 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
 
     hass.data.setdefault(ANDROIDTV_DOMAIN, {})
 
-    host = '{0}:{1}'.format(config[CONF_HOST], config[CONF_PORT])
+    host = "{0}:{1}".format(config[CONF_HOST], config[CONF_PORT])
 
     if CONF_ADB_SERVER_IP not in config:
         # Use "python-adb" (Python ADB implementation)
         adb_log = "using Python ADB implementation "
         if CONF_ADBKEY in config:
-            aftv = setup(host, config[CONF_ADBKEY],
-                         device_class=config[CONF_DEVICE_CLASS])
+            aftv = setup(
+                host, config[CONF_ADBKEY], device_class=config[CONF_DEVICE_CLASS]
+            )
             adb_log += "with adbkey='{0}'".format(config[CONF_ADBKEY])
 
         else:
@@ -101,44 +134,52 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
             adb_log += "without adbkey authentication"
     else:
         # Use "pure-python-adb" (communicate with ADB server)
-        aftv = setup(host, adb_server_ip=config[CONF_ADB_SERVER_IP],
-                     adb_server_port=config[CONF_ADB_SERVER_PORT],
-                     device_class=config[CONF_DEVICE_CLASS])
+        aftv = setup(
+            host,
+            adb_server_ip=config[CONF_ADB_SERVER_IP],
+            adb_server_port=config[CONF_ADB_SERVER_PORT],
+            device_class=config[CONF_DEVICE_CLASS],
+        )
         adb_log = "using ADB server at {0}:{1}".format(
-            config[CONF_ADB_SERVER_IP], config[CONF_ADB_SERVER_PORT])
+            config[CONF_ADB_SERVER_IP], config[CONF_ADB_SERVER_PORT]
+        )
 
     if not aftv.available:
         # Determine the name that will be used for the device in the log
         if CONF_NAME in config:
             device_name = config[CONF_NAME]
         elif config[CONF_DEVICE_CLASS] == DEVICE_ANDROIDTV:
-            device_name = 'Android TV device'
+            device_name = "Android TV device"
         elif config[CONF_DEVICE_CLASS] == DEVICE_FIRETV:
-            device_name = 'Fire TV device'
+            device_name = "Fire TV device"
         else:
-            device_name = 'Android TV / Fire TV device'
+            device_name = "Android TV / Fire TV device"
 
-        _LOGGER.warning("Could not connect to %s at %s %s",
-                        device_name, host, adb_log)
+        _LOGGER.warning("Could not connect to %s at %s %s", device_name, host, adb_log)
         raise PlatformNotReady
 
     if host in hass.data[ANDROIDTV_DOMAIN]:
         _LOGGER.warning("Platform already setup on %s, skipping", host)
     else:
         if aftv.DEVICE_CLASS == DEVICE_ANDROIDTV:
-            device = AndroidTVDevice(aftv, config[CONF_NAME],
-                                     config[CONF_APPS],
-                                     config.get(CONF_TURN_ON_COMMAND),
-                                     config.get(CONF_TURN_OFF_COMMAND))
-            device_name = config[CONF_NAME] if CONF_NAME in config \
-                else 'Android TV'
+            device = AndroidTVDevice(
+                aftv,
+                config[CONF_NAME],
+                config[CONF_APPS],
+                config.get(CONF_TURN_ON_COMMAND),
+                config.get(CONF_TURN_OFF_COMMAND),
+            )
+            device_name = config[CONF_NAME] if CONF_NAME in config else "Android TV"
         else:
-            device = FireTVDevice(aftv, config[CONF_NAME], config[CONF_APPS],
-                                  config[CONF_GET_SOURCES],
-                                  config.get(CONF_TURN_ON_COMMAND),
-                                  config.get(CONF_TURN_OFF_COMMAND))
-            device_name = config[CONF_NAME] if CONF_NAME in config \
-                else 'Fire TV'
+            device = FireTVDevice(
+                aftv,
+                config[CONF_NAME],
+                config[CONF_APPS],
+                config[CONF_GET_SOURCES],
+                config.get(CONF_TURN_ON_COMMAND),
+                config.get(CONF_TURN_OFF_COMMAND),
+            )
+            device_name = config[CONF_NAME] if CONF_NAME in config else "Fire TV"
 
         add_entities([device])
         _LOGGER.debug("Setup %s at %s%s", device_name, host, adb_log)
@@ -151,26 +192,38 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
         """Dispatch service calls to target entities."""
         cmd = service.data.get(ATTR_COMMAND)
         entity_id = service.data.get(ATTR_ENTITY_ID)
-        target_devices = [dev for dev in hass.data[ANDROIDTV_DOMAIN].values()
-                          if dev.entity_id in entity_id]
+        target_devices = [
+            dev
+            for dev in hass.data[ANDROIDTV_DOMAIN].values()
+            if dev.entity_id in entity_id
+        ]
 
         for target_device in target_devices:
             output = target_device.adb_command(cmd)
 
             # log the output, if there is any
             if output:
-                _LOGGER.info("Output of command '%s' from '%s': %s",
-                             cmd, target_device.entity_id, output)
+                _LOGGER.info(
+                    "Output of command '%s' from '%s': %s",
+                    cmd,
+                    target_device.entity_id,
+                    output,
+                )
 
-    hass.services.register(ANDROIDTV_DOMAIN, SERVICE_ADB_COMMAND,
-                           service_adb_command,
-                           schema=SERVICE_ADB_COMMAND_SCHEMA)
+    hass.services.register(
+        ANDROIDTV_DOMAIN,
+        SERVICE_ADB_COMMAND,
+        service_adb_command,
+        schema=SERVICE_ADB_COMMAND_SCHEMA,
+    )
 
 
 def adb_decorator(override_available=False):
     """Send an ADB command if the device is available and catch exceptions."""
+
     def _adb_decorator(func):
         """Wait if previous ADB commands haven't finished."""
+
         @functools.wraps(func)
         def _adb_exception_catcher(self, *args, **kwargs):
             # If the device is unavailable, don't do anything
@@ -182,7 +235,9 @@ def adb_decorator(override_available=False):
             except self.exceptions as err:
                 _LOGGER.error(
                     "Failed to execute an ADB command. ADB connection re-"
-                    "establishing attempt in the next update. Error: %s", err)
+                    "establishing attempt in the next update. Error: %s",
+                    err,
+                )
                 self._available = False  # pylint: disable=protected-access
                 return None
 
@@ -194,8 +249,7 @@ def adb_decorator(override_available=False):
 class ADBDevice(MediaPlayerDevice):
     """Representation of an Android TV or Fire TV device."""
 
-    def __init__(self, aftv, name, apps, turn_on_command,
-                 turn_off_command):
+    def __init__(self, aftv, name, apps, turn_on_command, turn_off_command):
         """Initialize the Android TV / Fire TV device."""
         from androidtv.constants import APPS, KEYS
 
@@ -211,15 +265,23 @@ class ADBDevice(MediaPlayerDevice):
         # ADB exceptions to catch
         if not self.aftv.adb_server_ip:
             # Using "python-adb" (Python ADB implementation)
-            from adb.adb_protocol import (InvalidChecksumError,
-                                          InvalidCommandError,
-                                          InvalidResponseError)
+            from adb.adb_protocol import (
+                InvalidChecksumError,
+                InvalidCommandError,
+                InvalidResponseError,
+            )
             from adb.usb_exceptions import TcpTimeoutException
 
-            self.exceptions = (AttributeError, BrokenPipeError, TypeError,
-                               ValueError, InvalidChecksumError,
-                               InvalidCommandError, InvalidResponseError,
-                               TcpTimeoutException)
+            self.exceptions = (
+                AttributeError,
+                BrokenPipeError,
+                TypeError,
+                ValueError,
+                InvalidChecksumError,
+                InvalidCommandError,
+                InvalidResponseError,
+                TcpTimeoutException,
+            )
         else:
             # Using "pure-python-adb" (communicate with ADB server)
             self.exceptions = (ConnectionResetError, RuntimeError)
@@ -248,7 +310,7 @@ class ADBDevice(MediaPlayerDevice):
     @property
     def device_state_attributes(self):
         """Provide the last ADB command's response as an attribute."""
-        return {'adb_response': self._adb_response}
+        return {"adb_response": self._adb_response}
 
     @property
     def name(self):
@@ -311,12 +373,12 @@ class ADBDevice(MediaPlayerDevice):
         """Send an ADB command to an Android TV / Fire TV device."""
         key = self._keys.get(cmd)
         if key:
-            self.aftv.adb_shell('input keyevent {}'.format(key))
+            self.aftv.adb_shell("input keyevent {}".format(key))
             self._adb_response = None
             self.schedule_update_ha_state()
             return
 
-        if cmd == 'GET_PROPERTIES':
+        if cmd == "GET_PROPERTIES":
             self._adb_response = str(self.aftv.get_properties_dict())
             self.schedule_update_ha_state()
             return self._adb_response
@@ -334,16 +396,14 @@ class ADBDevice(MediaPlayerDevice):
 class AndroidTVDevice(ADBDevice):
     """Representation of an Android TV device."""
 
-    def __init__(self, aftv, name, apps, turn_on_command,
-                 turn_off_command):
+    def __init__(self, aftv, name, apps, turn_on_command, turn_off_command):
         """Initialize the Android TV device."""
-        super().__init__(aftv, name, apps, turn_on_command,
-                         turn_off_command)
+        super().__init__(aftv, name, apps, turn_on_command, turn_off_command)
 
         self._device = None
         self._device_properties = self.aftv.device_properties
         self._is_volume_muted = None
-        self._unique_id = self._device_properties.get('serialno')
+        self._unique_id = self._device_properties.get("serialno")
         self._volume_level = None
 
     @adb_decorator(override_available=True)
@@ -362,8 +422,9 @@ class AndroidTVDevice(ADBDevice):
             return
 
         # Get the updated state and attributes.
-        state, self._current_app, self._device, self._is_volume_muted, \
-            self._volume_level = self.aftv.update()
+        state, self._current_app, self._device, self._is_volume_muted, self._volume_level = (
+            self.aftv.update()
+        )
 
         self._state = ANDROIDTV_STATES[state]
 
@@ -416,11 +477,11 @@ class AndroidTVDevice(ADBDevice):
 class FireTVDevice(ADBDevice):
     """Representation of a Fire TV device."""
 
-    def __init__(self, aftv, name, apps, get_sources,
-                 turn_on_command, turn_off_command):
+    def __init__(
+        self, aftv, name, apps, get_sources, turn_on_command, turn_off_command
+    ):
         """Initialize the Fire TV device."""
-        super().__init__(aftv, name, apps, turn_on_command,
-                         turn_off_command)
+        super().__init__(aftv, name, apps, turn_on_command, turn_off_command)
 
         self._get_sources = get_sources
         self._running_apps = None
@@ -441,8 +502,9 @@ class FireTVDevice(ADBDevice):
             return
 
         # Get the `state`, `current_app`, and `running_apps`.
-        state, self._current_app, self._running_apps = \
-            self.aftv.update(self._get_sources)
+        state, self._current_app, self._running_apps = self.aftv.update(
+            self._get_sources
+        )
 
         self._state = ANDROIDTV_STATES[state]
 
@@ -474,7 +536,7 @@ class FireTVDevice(ADBDevice):
         opening it.
         """
         if isinstance(source, str):
-            if not source.startswith('!'):
+            if not source.startswith("!"):
                 self.aftv.launch_app(source)
             else:
                 self.aftv.stop_app(source[1:].lstrip())
