@@ -8,28 +8,35 @@ import voluptuous as vol
 
 import homeassistant.helpers.config_validation as cv
 from homeassistant.components.sensor import PLATFORM_SCHEMA
-from homeassistant.const import (CONF_NAME, CONF_HOST, CONF_PORT,
-                                 EVENT_HOMEASSISTANT_START)
+from homeassistant.const import (
+    CONF_NAME,
+    CONF_HOST,
+    CONF_PORT,
+    EVENT_HOMEASSISTANT_START,
+)
 from homeassistant.helpers.entity import Entity
 
 _LOGGER = logging.getLogger(__name__)
 
-DEFAULT_NAME = 'SSL Certificate Expiry'
+DEFAULT_NAME = "SSL Certificate Expiry"
 DEFAULT_PORT = 443
 
 SCAN_INTERVAL = timedelta(hours=12)
 
 TIMEOUT = 10.0
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend({
-    vol.Required(CONF_HOST): cv.string,
-    vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
-    vol.Optional(CONF_PORT, default=DEFAULT_PORT): cv.port,
-})
+PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
+    {
+        vol.Required(CONF_HOST): cv.string,
+        vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
+        vol.Optional(CONF_PORT, default=DEFAULT_PORT): cv.port,
+    }
+)
 
 
 def setup_platform(hass, config, add_entities, discovery_info=None):
     """Set up certificate expiry sensor."""
+
     def run_setup(event):
         """Wait until Home Assistant is fully initialized before creating.
 
@@ -39,8 +46,7 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
         server_port = config.get(CONF_PORT)
         sensor_name = config.get(CONF_NAME)
 
-        add_entities([SSLCertificate(sensor_name, server_name, server_port)],
-                     True)
+        add_entities([SSLCertificate(sensor_name, server_name, server_port)], True)
 
     # To allow checking of the HA certificate we must first be running.
     hass.bus.listen_once(EVENT_HOMEASSISTANT_START, run_setup)
@@ -65,7 +71,7 @@ class SSLCertificate(Entity):
     @property
     def unit_of_measurement(self):
         """Return the unit this state is expressed in."""
-        return 'days'
+        return "days"
 
     @property
     def state(self):
@@ -75,7 +81,7 @@ class SSLCertificate(Entity):
     @property
     def icon(self):
         """Icon to use in the frontend, if any."""
-        return 'mdi:certificate'
+        return "mdi:certificate"
 
     @property
     def available(self):
@@ -87,10 +93,8 @@ class SSLCertificate(Entity):
         ctx = ssl.create_default_context()
         try:
             address = (self.server_name, self.server_port)
-            with socket.create_connection(
-                    address, timeout=TIMEOUT) as sock:
-                with ctx.wrap_socket(
-                        sock, server_hostname=address[0]) as ssock:
+            with socket.create_connection(address, timeout=TIMEOUT) as sock:
+                with ctx.wrap_socket(sock, server_hostname=address[0]) as ssock:
                     cert = ssock.getpeercert()
 
         except socket.gaierror:
@@ -98,17 +102,17 @@ class SSLCertificate(Entity):
             self._available = False
             return
         except socket.timeout:
-            _LOGGER.error(
-                "Connection timeout with server: %s", self.server_name)
+            _LOGGER.error("Connection timeout with server: %s", self.server_name)
             self._available = False
             return
         except OSError:
-            _LOGGER.error("Cannot fetch certificate from %s",
-                          self.server_name, exc_info=1)
+            _LOGGER.error(
+                "Cannot fetch certificate from %s", self.server_name, exc_info=1
+            )
             self._available = False
             return
 
-        ts_seconds = ssl.cert_time_to_seconds(cert['notAfter'])
+        ts_seconds = ssl.cert_time_to_seconds(cert["notAfter"])
         timestamp = datetime.fromtimestamp(ts_seconds)
         expiry = timestamp - datetime.today()
         self._available = True
