@@ -7,166 +7,97 @@ import logging
 import voluptuous as vol
 
 from homeassistant.components.sensor import PLATFORM_SCHEMA
-from homeassistant.const import (
-    CONF_HOST, CONF_PORT, EVENT_HOMEASSISTANT_STOP)
+from homeassistant.const import CONF_HOST, CONF_PORT, EVENT_HOMEASSISTANT_STOP
 from homeassistant.core import CoreState
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.entity import Entity
 
 _LOGGER = logging.getLogger(__name__)
 
-CONF_DSMR_VERSION = 'dsmr_version'
-CONF_RECONNECT_INTERVAL = 'reconnect_interval'
-CONF_PRECISION = 'precision'
+CONF_DSMR_VERSION = "dsmr_version"
+CONF_RECONNECT_INTERVAL = "reconnect_interval"
+CONF_PRECISION = "precision"
 
-DEFAULT_DSMR_VERSION = '2.2'
-DEFAULT_PORT = '/dev/ttyUSB0'
+DEFAULT_DSMR_VERSION = "2.2"
+DEFAULT_PORT = "/dev/ttyUSB0"
 DEFAULT_PRECISION = 3
 
-DOMAIN = 'dsmr'
+DOMAIN = "dsmr"
 
-ICON_GAS = 'mdi:fire'
-ICON_POWER = 'mdi:flash'
-ICON_POWER_FAILURE = 'mdi:flash-off'
-ICON_SWELL_SAG = 'mdi:pulse'
+ICON_GAS = "mdi:fire"
+ICON_POWER = "mdi:flash"
+ICON_POWER_FAILURE = "mdi:flash-off"
+ICON_SWELL_SAG = "mdi:pulse"
 
 # Smart meter sends telegram every 10 seconds
 MIN_TIME_BETWEEN_UPDATES = timedelta(seconds=10)
 
 RECONNECT_INTERVAL = 5
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend({
-    vol.Optional(CONF_PORT, default=DEFAULT_PORT): cv.string,
-    vol.Optional(CONF_HOST): cv.string,
-    vol.Optional(CONF_DSMR_VERSION, default=DEFAULT_DSMR_VERSION): vol.All(
-        cv.string, vol.In(['5', '4', '2.2'])),
-    vol.Optional(CONF_RECONNECT_INTERVAL, default=30): int,
-    vol.Optional(CONF_PRECISION, default=DEFAULT_PRECISION): vol.Coerce(int),
-})
+PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
+    {
+        vol.Optional(CONF_PORT, default=DEFAULT_PORT): cv.string,
+        vol.Optional(CONF_HOST): cv.string,
+        vol.Optional(CONF_DSMR_VERSION, default=DEFAULT_DSMR_VERSION): vol.All(
+            cv.string, vol.In(["5", "4", "2.2"])
+        ),
+        vol.Optional(CONF_RECONNECT_INTERVAL, default=30): int,
+        vol.Optional(CONF_PRECISION, default=DEFAULT_PRECISION): vol.Coerce(int),
+    }
+)
 
 
-async def async_setup_platform(hass, config, async_add_entities,
-                               discovery_info=None):
+async def async_setup_platform(hass, config, async_add_entities, discovery_info=None):
     """Set up the DSMR sensor."""
     # Suppress logging
-    logging.getLogger('dsmr_parser').setLevel(logging.ERROR)
+    logging.getLogger("dsmr_parser").setLevel(logging.ERROR)
 
     from dsmr_parser import obis_references as obis_ref
-    from dsmr_parser.clients.protocol import (
-        create_dsmr_reader, create_tcp_dsmr_reader)
+    from dsmr_parser.clients.protocol import create_dsmr_reader, create_tcp_dsmr_reader
     import serial
 
     dsmr_version = config[CONF_DSMR_VERSION]
 
     # Define list of name,obis mappings to generate entities
     obis_mapping = [
-        [
-            'Power Consumption',
-            obis_ref.CURRENT_ELECTRICITY_USAGE
-        ],
-        [
-            'Power Production',
-            obis_ref.CURRENT_ELECTRICITY_DELIVERY
-        ],
-        [
-            'Power Tariff',
-            obis_ref.ELECTRICITY_ACTIVE_TARIFF
-        ],
-        [
-            'Power Consumption (low)',
-            obis_ref.ELECTRICITY_USED_TARIFF_1
-        ],
-        [
-            'Power Consumption (normal)',
-            obis_ref.ELECTRICITY_USED_TARIFF_2
-        ],
-        [
-            'Power Production (low)',
-            obis_ref.ELECTRICITY_DELIVERED_TARIFF_1
-        ],
-        [
-            'Power Production (normal)',
-            obis_ref.ELECTRICITY_DELIVERED_TARIFF_2
-        ],
-        [
-            'Power Consumption Phase L1',
-            obis_ref.INSTANTANEOUS_ACTIVE_POWER_L1_POSITIVE
-        ],
-        [
-            'Power Consumption Phase L2',
-            obis_ref.INSTANTANEOUS_ACTIVE_POWER_L2_POSITIVE
-        ],
-        [
-            'Power Consumption Phase L3',
-            obis_ref.INSTANTANEOUS_ACTIVE_POWER_L3_POSITIVE
-        ],
-        [
-            'Power Production Phase L1',
-            obis_ref.INSTANTANEOUS_ACTIVE_POWER_L1_NEGATIVE
-        ],
-        [
-            'Power Production Phase L2',
-            obis_ref.INSTANTANEOUS_ACTIVE_POWER_L2_NEGATIVE
-        ],
-        [
-            'Power Production Phase L3',
-            obis_ref.INSTANTANEOUS_ACTIVE_POWER_L3_NEGATIVE
-        ],
-        [
-            'Long Power Failure Count',
-            obis_ref.LONG_POWER_FAILURE_COUNT
-        ],
-        [
-            'Voltage Sags Phase L1',
-            obis_ref.VOLTAGE_SAG_L1_COUNT
-        ],
-        [
-            'Voltage Sags Phase L2',
-            obis_ref.VOLTAGE_SAG_L2_COUNT
-        ],
-        [
-            'Voltage Sags Phase L3',
-            obis_ref.VOLTAGE_SAG_L3_COUNT
-        ],
-        [
-            'Voltage Swells Phase L1',
-            obis_ref.VOLTAGE_SWELL_L1_COUNT
-        ],
-        [
-            'Voltage Swells Phase L2',
-            obis_ref.VOLTAGE_SWELL_L2_COUNT
-        ],
-        [
-            'Voltage Swells Phase L3',
-            obis_ref.VOLTAGE_SWELL_L3_COUNT
-        ],
-        [
-            'Voltage Phase L1',
-            obis_ref.INSTANTANEOUS_VOLTAGE_L1
-        ],
-        [
-            'Voltage Phase L2',
-            obis_ref.INSTANTANEOUS_VOLTAGE_L2
-        ],
-        [
-            'Voltage Phase L3',
-            obis_ref.INSTANTANEOUS_VOLTAGE_L3
-        ],
+        ["Power Consumption", obis_ref.CURRENT_ELECTRICITY_USAGE],
+        ["Power Production", obis_ref.CURRENT_ELECTRICITY_DELIVERY],
+        ["Power Tariff", obis_ref.ELECTRICITY_ACTIVE_TARIFF],
+        ["Power Consumption (low)", obis_ref.ELECTRICITY_USED_TARIFF_1],
+        ["Power Consumption (normal)", obis_ref.ELECTRICITY_USED_TARIFF_2],
+        ["Power Production (low)", obis_ref.ELECTRICITY_DELIVERED_TARIFF_1],
+        ["Power Production (normal)", obis_ref.ELECTRICITY_DELIVERED_TARIFF_2],
+        ["Power Consumption Phase L1", obis_ref.INSTANTANEOUS_ACTIVE_POWER_L1_POSITIVE],
+        ["Power Consumption Phase L2", obis_ref.INSTANTANEOUS_ACTIVE_POWER_L2_POSITIVE],
+        ["Power Consumption Phase L3", obis_ref.INSTANTANEOUS_ACTIVE_POWER_L3_POSITIVE],
+        ["Power Production Phase L1", obis_ref.INSTANTANEOUS_ACTIVE_POWER_L1_NEGATIVE],
+        ["Power Production Phase L2", obis_ref.INSTANTANEOUS_ACTIVE_POWER_L2_NEGATIVE],
+        ["Power Production Phase L3", obis_ref.INSTANTANEOUS_ACTIVE_POWER_L3_NEGATIVE],
+        ["Long Power Failure Count", obis_ref.LONG_POWER_FAILURE_COUNT],
+        ["Voltage Sags Phase L1", obis_ref.VOLTAGE_SAG_L1_COUNT],
+        ["Voltage Sags Phase L2", obis_ref.VOLTAGE_SAG_L2_COUNT],
+        ["Voltage Sags Phase L3", obis_ref.VOLTAGE_SAG_L3_COUNT],
+        ["Voltage Swells Phase L1", obis_ref.VOLTAGE_SWELL_L1_COUNT],
+        ["Voltage Swells Phase L2", obis_ref.VOLTAGE_SWELL_L2_COUNT],
+        ["Voltage Swells Phase L3", obis_ref.VOLTAGE_SWELL_L3_COUNT],
+        ["Voltage Phase L1", obis_ref.INSTANTANEOUS_VOLTAGE_L1],
+        ["Voltage Phase L2", obis_ref.INSTANTANEOUS_VOLTAGE_L2],
+        ["Voltage Phase L3", obis_ref.INSTANTANEOUS_VOLTAGE_L3],
     ]
 
     # Generate device entities
     devices = [DSMREntity(name, obis, config) for name, obis in obis_mapping]
 
     # Protocol version specific obis
-    if dsmr_version in ('4', '5'):
+    if dsmr_version in ("4", "5"):
         gas_obis = obis_ref.HOURLY_GAS_METER_READING
     else:
         gas_obis = obis_ref.GAS_METER_READING
 
     # Add gas meter reading and derivative for usage
     devices += [
-        DSMREntity('Gas Consumption', gas_obis, config),
-        DerivativeDSMREntity('Hourly Gas Consumption', gas_obis, config),
+        DSMREntity("Gas Consumption", gas_obis, config),
+        DerivativeDSMREntity("Hourly Gas Consumption", gas_obis, config),
     ]
 
     async_add_entities(devices)
@@ -182,23 +113,33 @@ async def async_setup_platform(hass, config, async_add_entities,
     # serial and calls update_entities_telegram to update entities on arrival
     if CONF_HOST in config:
         reader_factory = partial(
-            create_tcp_dsmr_reader, config[CONF_HOST], config[CONF_PORT],
-            config[CONF_DSMR_VERSION], update_entities_telegram,
-            loop=hass.loop)
+            create_tcp_dsmr_reader,
+            config[CONF_HOST],
+            config[CONF_PORT],
+            config[CONF_DSMR_VERSION],
+            update_entities_telegram,
+            loop=hass.loop,
+        )
     else:
         reader_factory = partial(
-            create_dsmr_reader, config[CONF_PORT], config[CONF_DSMR_VERSION],
-            update_entities_telegram, loop=hass.loop)
+            create_dsmr_reader,
+            config[CONF_PORT],
+            config[CONF_DSMR_VERSION],
+            update_entities_telegram,
+            loop=hass.loop,
+        )
 
     async def connect_and_reconnect():
         """Connect to DSMR and keep reconnecting until Home Assistant stops."""
         while hass.state != CoreState.stopping:
             # Start DSMR asyncio.Protocol reader
             try:
-                transport, protocol = await hass.loop.create_task(
-                    reader_factory())
-            except (serial.serialutil.SerialException, ConnectionRefusedError,
-                    TimeoutError):
+                transport, protocol = await hass.loop.create_task(reader_factory())
+            except (
+                serial.serialutil.SerialException,
+                ConnectionRefusedError,
+                TimeoutError,
+            ):
                 # Log any error while establishing connection and drop to retry
                 # connection wait
                 _LOGGER.exception("Error connecting to DSMR")
@@ -207,7 +148,8 @@ async def async_setup_platform(hass, config, async_add_entities,
             if transport:
                 # Register listener to close transport on HA shutdown
                 stop_listener = hass.bus.async_listen_once(
-                    EVENT_HOMEASSISTANT_STOP, transport.close)
+                    EVENT_HOMEASSISTANT_STOP, transport.close
+                )
 
                 # Wait for reader to close
                 await protocol.wait_closed()
@@ -257,13 +199,13 @@ class DSMREntity(Entity):
     @property
     def icon(self):
         """Icon to use in the frontend, if any."""
-        if 'Sags' in self._name or 'Swells' in self.name:
+        if "Sags" in self._name or "Swells" in self.name:
             return ICON_SWELL_SAG
-        if 'Failure' in self._name:
+        if "Failure" in self._name:
             return ICON_POWER_FAILURE
-        if 'Power' in self._name:
+        if "Power" in self._name:
             return ICON_POWER
-        if 'Gas' in self._name:
+        if "Gas" in self._name:
             return ICON_GAS
 
     @property
@@ -271,7 +213,7 @@ class DSMREntity(Entity):
         """Return the state of sensor, if available, translate if needed."""
         from dsmr_parser import obis_references as obis
 
-        value = self.get_dsmr_object_attr('value')
+        value = self.get_dsmr_object_attr("value")
 
         if self._obis == obis.ELECTRICITY_ACTIVE_TARIFF:
             return self.translate_tariff(value)
@@ -289,17 +231,17 @@ class DSMREntity(Entity):
     @property
     def unit_of_measurement(self):
         """Return the unit of measurement of this entity, if any."""
-        return self.get_dsmr_object_attr('unit')
+        return self.get_dsmr_object_attr("unit")
 
     @staticmethod
     def translate_tariff(value):
         """Convert 2/1 to normal/low."""
         # DSMR V2.2: Note: Rate code 1 is used for low rate and rate code 2 is
         # used for normal rate.
-        if value == '0002':
-            return 'normal'
-        if value == '0001':
-            return 'low'
+        if value == "0002":
+            return "normal"
+        if value == "0001":
+            return "low"
 
         return None
 
@@ -331,9 +273,9 @@ class DerivativeDSMREntity(DSMREntity):
 
         """
         # check if the timestamp for the object differs from the previous one
-        timestamp = self.get_dsmr_object_attr('datetime')
+        timestamp = self.get_dsmr_object_attr("datetime")
         if timestamp and timestamp != self._previous_timestamp:
-            current_reading = self.get_dsmr_object_attr('value')
+            current_reading = self.get_dsmr_object_attr("value")
 
             if self._previous_reading is None:
                 # Can't calculate rate without previous datapoint
@@ -352,6 +294,6 @@ class DerivativeDSMREntity(DSMREntity):
     @property
     def unit_of_measurement(self):
         """Return the unit of measurement of this entity, per hour, if any."""
-        unit = self.get_dsmr_object_attr('unit')
+        unit = self.get_dsmr_object_attr("unit")
         if unit:
-            return unit + '/h'
+            return unit + "/h"
