@@ -21,8 +21,7 @@ import voluptuous as vol
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.entity import Entity
 from homeassistant.components.sensor import PLATFORM_SCHEMA
-from homeassistant.const import (
-    ATTR_ATTRIBUTION, CONF_NAME, CONF_MONITORED_CONDITIONS)
+from homeassistant.const import ATTR_ATTRIBUTION, CONF_NAME, CONF_MONITORED_CONDITIONS
 from homeassistant.util import Throttle
 import homeassistant.util.dt as dt_util
 from homeassistant.components.rest.sensor import RestData
@@ -31,26 +30,34 @@ _LOGGER = logging.getLogger(__name__)
 
 ATTRIBUTION = "Data provided by DWD"
 
-DEFAULT_NAME = 'DWD-Weather-Warnings'
+DEFAULT_NAME = "DWD-Weather-Warnings"
 
-CONF_REGION_NAME = 'region_name'
+CONF_REGION_NAME = "region_name"
 
 SCAN_INTERVAL = timedelta(minutes=15)
 
 MONITORED_CONDITIONS = {
-    'current_warning_level': ['Current Warning Level',
-                              None, 'mdi:close-octagon-outline'],
-    'advance_warning_level': ['Advance Warning Level',
-                              None, 'mdi:close-octagon-outline'],
+    "current_warning_level": [
+        "Current Warning Level",
+        None,
+        "mdi:close-octagon-outline",
+    ],
+    "advance_warning_level": [
+        "Advance Warning Level",
+        None,
+        "mdi:close-octagon-outline",
+    ],
 }
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend({
-    vol.Optional(CONF_REGION_NAME): cv.string,
-    vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
-    vol.Optional(CONF_MONITORED_CONDITIONS,
-                 default=list(MONITORED_CONDITIONS)):
-    vol.All(cv.ensure_list, [vol.In(MONITORED_CONDITIONS)]),
-})
+PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
+    {
+        vol.Optional(CONF_REGION_NAME): cv.string,
+        vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
+        vol.Optional(
+            CONF_MONITORED_CONDITIONS, default=list(MONITORED_CONDITIONS)
+        ): vol.All(cv.ensure_list, [vol.In(MONITORED_CONDITIONS)]),
+    }
+)
 
 
 def setup_platform(hass, config, add_entities, discovery_info=None):
@@ -60,8 +67,10 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
 
     api = DwdWeatherWarningsAPI(region_name)
 
-    sensors = [DwdWeatherWarningsSensor(api, name, condition)
-               for condition in config[CONF_MONITORED_CONDITIONS]]
+    sensors = [
+        DwdWeatherWarningsSensor(api, name, condition)
+        for condition in config[CONF_MONITORED_CONDITIONS]
+    ]
 
     add_entities(sensors, True)
 
@@ -106,50 +115,50 @@ class DwdWeatherWarningsSensor(Entity):
     @property
     def device_state_attributes(self):
         """Return the state attributes of the DWD-Weather-Warnings."""
-        data = {
-            ATTR_ATTRIBUTION: ATTRIBUTION,
-            'region_name': self._api.region_name
-        }
+        data = {ATTR_ATTRIBUTION: ATTRIBUTION, "region_name": self._api.region_name}
 
         if self._api.region_id is not None:
-            data['region_id'] = self._api.region_id
+            data["region_id"] = self._api.region_id
 
         if self._api.region_state is not None:
-            data['region_state'] = self._api.region_state
+            data["region_state"] = self._api.region_state
 
-        if self._api.data['time'] is not None:
-            data['last_update'] = dt_util.as_local(
-                dt_util.utc_from_timestamp(self._api.data['time'] / 1000))
+        if self._api.data["time"] is not None:
+            data["last_update"] = dt_util.as_local(
+                dt_util.utc_from_timestamp(self._api.data["time"] / 1000)
+            )
 
-        if self._var_id == 'current_warning_level':
-            prefix = 'current'
-        elif self._var_id == 'advance_warning_level':
-            prefix = 'advance'
+        if self._var_id == "current_warning_level":
+            prefix = "current"
+        elif self._var_id == "advance_warning_level":
+            prefix = "advance"
         else:
-            raise Exception('Unknown warning type')
+            raise Exception("Unknown warning type")
 
-        data['warning_count'] = self._api.data[prefix + '_warning_count']
+        data["warning_count"] = self._api.data[prefix + "_warning_count"]
         i = 0
-        for event in self._api.data[prefix + '_warnings']:
+        for event in self._api.data[prefix + "_warnings"]:
             i = i + 1
 
-            data['warning_{}_name'.format(i)] = event['event']
-            data['warning_{}_level'.format(i)] = event['level']
-            data['warning_{}_type'.format(i)] = event['type']
-            if event['headline']:
-                data['warning_{}_headline'.format(i)] = event['headline']
-            if event['description']:
-                data['warning_{}_description'.format(i)] = event['description']
-            if event['instruction']:
-                data['warning_{}_instruction'.format(i)] = event['instruction']
+            data["warning_{}_name".format(i)] = event["event"]
+            data["warning_{}_level".format(i)] = event["level"]
+            data["warning_{}_type".format(i)] = event["type"]
+            if event["headline"]:
+                data["warning_{}_headline".format(i)] = event["headline"]
+            if event["description"]:
+                data["warning_{}_description".format(i)] = event["description"]
+            if event["instruction"]:
+                data["warning_{}_instruction".format(i)] = event["instruction"]
 
-            if event['start'] is not None:
-                data['warning_{}_start'.format(i)] = dt_util.as_local(
-                    dt_util.utc_from_timestamp(event['start'] / 1000))
+            if event["start"] is not None:
+                data["warning_{}_start".format(i)] = dt_util.as_local(
+                    dt_util.utc_from_timestamp(event["start"] / 1000)
+                )
 
-            if event['end'] is not None:
-                data['warning_{}_end'.format(i)] = dt_util.as_local(
-                    dt_util.utc_from_timestamp(event['end'] / 1000))
+            if event["end"] is not None:
+                data["warning_{}_end".format(i)] = dt_util.as_local(
+                    dt_util.utc_from_timestamp(event["end"] / 1000)
+                )
 
         return data
 
@@ -169,13 +178,13 @@ class DwdWeatherWarningsAPI:
     def __init__(self, region_name):
         """Initialize the data object."""
         resource = "{}{}{}?{}".format(
-            'https://',
-            'www.dwd.de',
-            '/DWD/warnungen/warnapp_landkreise/json/warnings.json',
-            'jsonp=loadWarnings'
+            "https://",
+            "www.dwd.de",
+            "/DWD/warnungen/warnapp_landkreise/json/warnings.json",
+            "jsonp=loadWarnings",
         )
 
-        self._rest = RestData('GET', resource, None, None, None, True)
+        self._rest = RestData("GET", resource, None, None, None, True)
         self.region_name = region_name
         self.region_id = None
         self.region_state = None
@@ -189,20 +198,21 @@ class DwdWeatherWarningsAPI:
         try:
             self._rest.update()
 
-            json_string = self._rest.data[24:len(self._rest.data) - 2]
+            json_string = self._rest.data[24 : len(self._rest.data) - 2]
             json_obj = json.loads(json_string)
 
-            data = {'time': json_obj['time']}
+            data = {"time": json_obj["time"]}
 
             for mykey, myvalue in {
-                    'current': 'warnings',
-                    'advance': 'vorabInformation'
+                "current": "warnings",
+                "advance": "vorabInformation",
             }.items():
 
-                _LOGGER.debug("Found %d %s global DWD warnings",
-                              len(json_obj[myvalue]), mykey)
+                _LOGGER.debug(
+                    "Found %d %s global DWD warnings", len(json_obj[myvalue]), mykey
+                )
 
-                data['{}_warning_level'.format(mykey)] = 0
+                data["{}_warning_level".format(mykey)] = 0
                 my_warnings = []
 
                 if self.region_id is not None:
@@ -214,26 +224,25 @@ class DwdWeatherWarningsAPI:
                     # loop through all items to find warnings, region_id
                     # and region_state for region_name
                     for key in json_obj[myvalue]:
-                        my_region = json_obj[myvalue][key][0]['regionName']
+                        my_region = json_obj[myvalue][key][0]["regionName"]
                         if my_region != self.region_name:
                             continue
                         my_warnings = json_obj[myvalue][key]
-                        my_state = json_obj[myvalue][key][0]['stateShort']
+                        my_state = json_obj[myvalue][key][0]["stateShort"]
                         self.region_id = key
                         self.region_state = my_state
                         break
 
                 # Get max warning level
-                maxlevel = data['{}_warning_level'.format(mykey)]
+                maxlevel = data["{}_warning_level".format(mykey)]
                 for event in my_warnings:
-                    if event['level'] >= maxlevel:
-                        data['{}_warning_level'.format(mykey)] = event['level']
+                    if event["level"] >= maxlevel:
+                        data["{}_warning_level".format(mykey)] = event["level"]
 
-                data['{}_warning_count'.format(mykey)] = len(my_warnings)
-                data['{}_warnings'.format(mykey)] = my_warnings
+                data["{}_warning_count".format(mykey)] = len(my_warnings)
+                data["{}_warnings".format(mykey)] = my_warnings
 
-                _LOGGER.debug("Found %d %s local DWD warnings",
-                              len(my_warnings), mykey)
+                _LOGGER.debug("Found %d %s local DWD warnings", len(my_warnings), mykey)
 
             self.data = data
             self.available = True
