@@ -9,33 +9,38 @@ import logging
 
 import voluptuous as vol
 
-from homeassistant.components.camera import (
-    PLATFORM_SCHEMA, Camera)
+from homeassistant.components.camera import PLATFORM_SCHEMA, Camera
 from homeassistant.const import (
-    CONF_NAME, CONF_LATITUDE, CONF_LONGITUDE, ATTR_ATTRIBUTION)
+    CONF_NAME,
+    CONF_LATITUDE,
+    CONF_LONGITUDE,
+    ATTR_ATTRIBUTION,
+)
 from homeassistant.util import Throttle
 import homeassistant.helpers.config_validation as cv
 
 _LOGGER = logging.getLogger(__name__)
 
-ATTR_STATION = 'station'
-ATTR_LOCATION = 'location'
+ATTR_STATION = "station"
+ATTR_LOCATION = "location"
 
 CONF_ATTRIBUTION = "Data provided by Environment Canada"
-CONF_STATION = 'station'
-CONF_LOOP = 'loop'
-CONF_PRECIP_TYPE = 'precip_type'
+CONF_STATION = "station"
+CONF_LOOP = "loop"
+CONF_PRECIP_TYPE = "precip_type"
 
 MIN_TIME_BETWEEN_UPDATES = datetime.timedelta(minutes=10)
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend({
-    vol.Optional(CONF_LOOP, default=True): cv.boolean,
-    vol.Optional(CONF_NAME): cv.string,
-    vol.Optional(CONF_STATION): cv.string,
-    vol.Inclusive(CONF_LATITUDE, 'latlon'): cv.latitude,
-    vol.Inclusive(CONF_LONGITUDE, 'latlon'): cv.longitude,
-    vol.Optional(CONF_PRECIP_TYPE): ['RAIN', 'SNOW'],
-})
+PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
+    {
+        vol.Optional(CONF_LOOP, default=True): cv.boolean,
+        vol.Optional(CONF_NAME): cv.string,
+        vol.Optional(CONF_STATION): cv.string,
+        vol.Inclusive(CONF_LATITUDE, "latlon"): cv.latitude,
+        vol.Inclusive(CONF_LONGITUDE, "latlon"): cv.longitude,
+        vol.Optional(CONF_PRECIP_TYPE): ["RAIN", "SNOW"],
+    }
+)
 
 
 def setup_platform(hass, config, add_devices, discovery_info=None):
@@ -43,16 +48,13 @@ def setup_platform(hass, config, add_devices, discovery_info=None):
     from env_canada import ECRadar
 
     if config.get(CONF_STATION):
-        radar_object = ECRadar(station_id=config[CONF_STATION],
-                               precip_type=config.get(CONF_PRECIP_TYPE))
-    elif config.get(CONF_LATITUDE) and config.get(CONF_LONGITUDE):
-        radar_object = ECRadar(coordinates=(config[CONF_LATITUDE],
-                                            config[CONF_LONGITUDE]),
-                               precip_type=config.get(CONF_PRECIP_TYPE))
+        radar_object = ECRadar(
+            station_id=config[CONF_STATION], precip_type=config.get(CONF_PRECIP_TYPE)
+        )
     else:
-        radar_object = ECRadar(coordinates=(hass.config.latitude,
-                                            hass.config.longitude),
-                               precip_type=config.get(CONF_PRECIP_TYPE))
+        lat = config.get(CONF_LATITUDE, hass.config.latitude)
+        lon = config.get(CONF_LONGITUDE, hass.config.longitude)
+        radar_object = ECRadar(coordinates=(lat, lon))
 
     add_devices([ECCamera(radar_object, config.get(CONF_NAME))], True)
 
@@ -66,7 +68,7 @@ class ECCamera(Camera):
 
         self.radar_object = radar_object
         self.camera_name = camera_name
-        self.content_type = 'image/gif'
+        self.content_type = "image/gif"
         self.image = None
 
     def camera_image(self):
@@ -79,7 +81,7 @@ class ECCamera(Camera):
         """Return the name of the camera."""
         if self.camera_name is not None:
             return self.camera_name
-        return ' '.join([self.radar_object.station_name, 'Radar'])
+        return " ".join([self.radar_object.station_name, "Radar"])
 
     @property
     def device_state_attributes(self):
@@ -87,7 +89,7 @@ class ECCamera(Camera):
         attr = {
             ATTR_ATTRIBUTION: CONF_ATTRIBUTION,
             ATTR_LOCATION: self.radar_object.station_name,
-            ATTR_STATION: self.radar_object.station_code
+            ATTR_STATION: self.radar_object.station_code,
         }
 
         return attr
