@@ -5,9 +5,17 @@ from typing import Optional
 import voluptuous as vol
 
 from homeassistant.const import (
-    ATTR_ARMED, ATTR_BATTERY_LEVEL, CONF_DEVICE_CLASS, CONF_EXCLUDE,
-    CONF_ICON, CONF_PASSWORD, CONF_URL, CONF_USERNAME,
-    CONF_WHITE_VALUE, EVENT_HOMEASSISTANT_STOP)
+    ATTR_ARMED,
+    ATTR_BATTERY_LEVEL,
+    CONF_DEVICE_CLASS,
+    CONF_EXCLUDE,
+    CONF_ICON,
+    CONF_PASSWORD,
+    CONF_URL,
+    CONF_USERNAME,
+    CONF_WHITE_VALUE,
+    EVENT_HOMEASSISTANT_STOP,
+)
 from homeassistant.helpers import discovery
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.entity import Entity
@@ -15,72 +23,88 @@ from homeassistant.util import convert, slugify
 
 _LOGGER = logging.getLogger(__name__)
 
-ATTR_CURRENT_ENERGY_KWH = 'current_energy_kwh'
-ATTR_CURRENT_POWER_W = 'current_power_w'
+ATTR_CURRENT_ENERGY_KWH = "current_energy_kwh"
+ATTR_CURRENT_POWER_W = "current_power_w"
 
-CONF_COLOR = 'color'
-CONF_DEVICE_CONFIG = 'device_config'
-CONF_DIMMING = 'dimming'
-CONF_GATEWAYS = 'gateways'
-CONF_PLUGINS = 'plugins'
-CONF_RESET_COLOR = 'reset_color'
-DOMAIN = 'fibaro'
-FIBARO_CONTROLLERS = 'fibaro_controllers'
-FIBARO_DEVICES = 'fibaro_devices'
-FIBARO_COMPONENTS = ['binary_sensor', 'climate', 'cover', 'light',
-                     'scene', 'sensor', 'switch']
+CONF_COLOR = "color"
+CONF_DEVICE_CONFIG = "device_config"
+CONF_DIMMING = "dimming"
+CONF_GATEWAYS = "gateways"
+CONF_PLUGINS = "plugins"
+CONF_RESET_COLOR = "reset_color"
+DOMAIN = "fibaro"
+FIBARO_CONTROLLERS = "fibaro_controllers"
+FIBARO_DEVICES = "fibaro_devices"
+FIBARO_COMPONENTS = [
+    "binary_sensor",
+    "climate",
+    "cover",
+    "light",
+    "scene",
+    "sensor",
+    "switch",
+]
 
 FIBARO_TYPEMAP = {
-    'com.fibaro.multilevelSensor': "sensor",
-    'com.fibaro.binarySwitch': 'switch',
-    'com.fibaro.multilevelSwitch': 'switch',
-    'com.fibaro.FGD212': 'light',
-    'com.fibaro.FGR': 'cover',
-    'com.fibaro.doorSensor': 'binary_sensor',
-    'com.fibaro.doorWindowSensor': 'binary_sensor',
-    'com.fibaro.FGMS001': 'binary_sensor',
-    'com.fibaro.heatDetector': 'binary_sensor',
-    'com.fibaro.lifeDangerSensor': 'binary_sensor',
-    'com.fibaro.smokeSensor': 'binary_sensor',
-    'com.fibaro.remoteSwitch': 'switch',
-    'com.fibaro.sensor': 'sensor',
-    'com.fibaro.colorController': 'light',
-    'com.fibaro.securitySensor': 'binary_sensor',
-    'com.fibaro.hvac': 'climate',
-    'com.fibaro.setpoint': 'climate',
-    'com.fibaro.FGT001': 'climate',
-    'com.fibaro.thermostatDanfoss': 'climate'
+    "com.fibaro.multilevelSensor": "sensor",
+    "com.fibaro.binarySwitch": "switch",
+    "com.fibaro.multilevelSwitch": "switch",
+    "com.fibaro.FGD212": "light",
+    "com.fibaro.FGR": "cover",
+    "com.fibaro.doorSensor": "binary_sensor",
+    "com.fibaro.doorWindowSensor": "binary_sensor",
+    "com.fibaro.FGMS001": "binary_sensor",
+    "com.fibaro.heatDetector": "binary_sensor",
+    "com.fibaro.lifeDangerSensor": "binary_sensor",
+    "com.fibaro.smokeSensor": "binary_sensor",
+    "com.fibaro.remoteSwitch": "switch",
+    "com.fibaro.sensor": "sensor",
+    "com.fibaro.colorController": "light",
+    "com.fibaro.securitySensor": "binary_sensor",
+    "com.fibaro.hvac": "climate",
+    "com.fibaro.setpoint": "climate",
+    "com.fibaro.FGT001": "climate",
+    "com.fibaro.thermostatDanfoss": "climate",
 }
 
-DEVICE_CONFIG_SCHEMA_ENTRY = vol.Schema({
-    vol.Optional(CONF_DIMMING): cv.boolean,
-    vol.Optional(CONF_COLOR): cv.boolean,
-    vol.Optional(CONF_WHITE_VALUE): cv.boolean,
-    vol.Optional(CONF_RESET_COLOR): cv.boolean,
-    vol.Optional(CONF_DEVICE_CLASS): cv.string,
-    vol.Optional(CONF_ICON): cv.string,
-})
+DEVICE_CONFIG_SCHEMA_ENTRY = vol.Schema(
+    {
+        vol.Optional(CONF_DIMMING): cv.boolean,
+        vol.Optional(CONF_COLOR): cv.boolean,
+        vol.Optional(CONF_WHITE_VALUE): cv.boolean,
+        vol.Optional(CONF_RESET_COLOR): cv.boolean,
+        vol.Optional(CONF_DEVICE_CLASS): cv.string,
+        vol.Optional(CONF_ICON): cv.string,
+    }
+)
 
 FIBARO_ID_LIST_SCHEMA = vol.Schema([cv.string])
 
-GATEWAY_CONFIG = vol.Schema({
-    vol.Required(CONF_PASSWORD): cv.string,
-    vol.Required(CONF_USERNAME): cv.string,
-    vol.Required(CONF_URL): cv.url,
-    vol.Optional(CONF_PLUGINS, default=False): cv.boolean,
-    vol.Optional(CONF_EXCLUDE, default=[]): FIBARO_ID_LIST_SCHEMA,
-    vol.Optional(CONF_DEVICE_CONFIG, default={}):
-        vol.Schema({cv.string: DEVICE_CONFIG_SCHEMA_ENTRY})
-}, extra=vol.ALLOW_EXTRA)
+GATEWAY_CONFIG = vol.Schema(
+    {
+        vol.Required(CONF_PASSWORD): cv.string,
+        vol.Required(CONF_USERNAME): cv.string,
+        vol.Required(CONF_URL): cv.url,
+        vol.Optional(CONF_PLUGINS, default=False): cv.boolean,
+        vol.Optional(CONF_EXCLUDE, default=[]): FIBARO_ID_LIST_SCHEMA,
+        vol.Optional(CONF_DEVICE_CONFIG, default={}): vol.Schema(
+            {cv.string: DEVICE_CONFIG_SCHEMA_ENTRY}
+        ),
+    },
+    extra=vol.ALLOW_EXTRA,
+)
 
-CONFIG_SCHEMA = vol.Schema({
-    DOMAIN: vol.Schema({
-        vol.Required(CONF_GATEWAYS): vol.All(cv.ensure_list, [GATEWAY_CONFIG]),
-    })
-}, extra=vol.ALLOW_EXTRA)
+CONFIG_SCHEMA = vol.Schema(
+    {
+        DOMAIN: vol.Schema(
+            {vol.Required(CONF_GATEWAYS): vol.All(cv.ensure_list, [GATEWAY_CONFIG])}
+        )
+    },
+    extra=vol.ALLOW_EXTRA,
+)
 
 
-class FibaroController():
+class FibaroController:
     """Initiate Fibaro Controller Class."""
 
     def __init__(self, config):
@@ -88,7 +112,8 @@ class FibaroController():
         from fiblary3.client.v4.client import Client as FibaroClient
 
         self._client = FibaroClient(
-            config[CONF_URL], config[CONF_USERNAME], config[CONF_PASSWORD])
+            config[CONF_URL], config[CONF_USERNAME], config[CONF_PASSWORD]
+        )
         self._scene_map = None
         # Whether to import devices from plugins
         self._import_plugins = config[CONF_PLUGINS]
@@ -99,7 +124,7 @@ class FibaroController():
         self._callbacks = {}  # Update value callbacks by deviceId
         self._state_handler = None  # Fiblary's StateHandler object
         self._excluded_devices = config[CONF_EXCLUDE]
-        self.hub_serial = None   # Unique serial number of the hub
+        self.hub_serial = None  # Unique serial number of the hub
 
     def connect(self):
         """Start the communication with the Fibaro controller."""
@@ -108,12 +133,12 @@ class FibaroController():
             info = self._client.info.get()
             self.hub_serial = slugify(info.serialNumber)
         except AssertionError:
-            _LOGGER.error("Can't connect to Fibaro HC. "
-                          "Please check URL.")
+            _LOGGER.error("Can't connect to Fibaro HC. " "Please check URL.")
             return False
         if login is None or login.status is False:
-            _LOGGER.error("Invalid login for Fibaro HC. "
-                          "Please check username and password")
+            _LOGGER.error(
+                "Invalid login for Fibaro HC. " "Please check username and password"
+            )
             return False
 
         self._room_map = {room.id: room for room in self._client.rooms.list()}
@@ -124,6 +149,7 @@ class FibaroController():
     def enable_state_handler(self):
         """Start StateHandler thread for monitoring updates."""
         from fiblary3.client.v4.client import StateHandler
+
         self._state_handler = StateHandler(self._client, self._on_state_change)
 
     def disable_state_handler(self):
@@ -134,28 +160,26 @@ class FibaroController():
     def _on_state_change(self, state):
         """Handle change report received from the HomeCenter."""
         callback_set = set()
-        for change in state.get('changes', []):
+        for change in state.get("changes", []):
             try:
-                dev_id = change.pop('id')
+                dev_id = change.pop("id")
                 if dev_id not in self._device_map.keys():
                     continue
                 device = self._device_map[dev_id]
                 for property_name, value in change.items():
-                    if property_name == 'log':
+                    if property_name == "log":
                         if value and value != "transfer OK":
-                            _LOGGER.debug("LOG %s: %s",
-                                          device.friendly_name, value)
+                            _LOGGER.debug("LOG %s: %s", device.friendly_name, value)
                         continue
-                    if property_name == 'logTemp':
+                    if property_name == "logTemp":
                         continue
                     if property_name in device.properties:
-                        device.properties[property_name] = \
-                            value
-                        _LOGGER.debug("<- %s.%s = %s", device.ha_id,
-                                      property_name, str(value))
+                        device.properties[property_name] = value
+                        _LOGGER.debug(
+                            "<- %s.%s = %s", device.ha_id, property_name, str(value)
+                        )
                     else:
-                        _LOGGER.warning("%s.%s not found", device.ha_id,
-                                        property_name)
+                        _LOGGER.warning("%s.%s not found", device.ha_id, property_name)
                     if dev_id in self._callbacks:
                         callback_set.add(dev_id)
             except (ValueError, KeyError):
@@ -170,8 +194,10 @@ class FibaroController():
     def get_children(self, device_id):
         """Get a list of child devices."""
         return [
-            device for device in self._device_map.values()
-            if device.parentId == device_id]
+            device
+            for device in self._device_map.values()
+            if device.parentId == device_id
+        ]
 
     def get_siblings(self, device_id):
         """Get the siblings of a device."""
@@ -182,29 +208,31 @@ class FibaroController():
         """Map device to HA device type."""
         # Use our lookup table to identify device type
         device_type = None
-        if 'type' in device:
+        if "type" in device:
             device_type = FIBARO_TYPEMAP.get(device.type)
-        if device_type is None and 'baseType' in device:
+        if device_type is None and "baseType" in device:
             device_type = FIBARO_TYPEMAP.get(device.baseType)
 
         # We can also identify device type by its capabilities
         if device_type is None:
-            if 'setBrightness' in device.actions:
-                device_type = 'light'
-            elif 'turnOn' in device.actions:
-                device_type = 'switch'
-            elif 'open' in device.actions:
-                device_type = 'cover'
-            elif 'value' in device.properties:
-                if device.properties.value in ('true', 'false'):
-                    device_type = 'binary_sensor'
+            if "setBrightness" in device.actions:
+                device_type = "light"
+            elif "turnOn" in device.actions:
+                device_type = "switch"
+            elif "open" in device.actions:
+                device_type = "cover"
+            elif "value" in device.properties:
+                if device.properties.value in ("true", "false"):
+                    device_type = "binary_sensor"
                 else:
-                    device_type = 'sensor'
+                    device_type = "sensor"
 
         # Switches that control lights should show up as lights
-        if device_type == 'switch' and \
-                device.properties.get('isLight', 'false') == 'true':
-            device_type = 'light'
+        if (
+            device_type == "switch"
+            and device.properties.get("isLight", "false") == "true"
+        ):
+            device_type = "light"
         return device_type
 
     def _read_scenes(self):
@@ -215,17 +243,17 @@ class FibaroController():
                 continue
             device.fibaro_controller = self
             if device.roomID == 0:
-                room_name = 'Unknown'
+                room_name = "Unknown"
             else:
                 room_name = self._room_map[device.roomID].name
             device.room_name = room_name
-            device.friendly_name = '{} {}'.format(room_name, device.name)
-            device.ha_id = 'scene_{}_{}_{}'.format(
-                slugify(room_name), slugify(device.name), device.id)
-            device.unique_id_str = "{}.scene.{}".format(
-                self.hub_serial, device.id)
+            device.friendly_name = "{} {}".format(room_name, device.name)
+            device.ha_id = "scene_{}_{}_{}".format(
+                slugify(room_name), slugify(device.name), device.id
+            )
+            device.unique_id_str = "{}.scene.{}".format(self.hub_serial, device.id)
             self._scene_map[device.id] = device
-            self.fibaro_devices['scene'].append(device)
+            self.fibaro_devices["scene"].append(device)
 
     def _read_devices(self):
         """Read and process the device list."""
@@ -237,42 +265,48 @@ class FibaroController():
             try:
                 device.fibaro_controller = self
                 if device.roomID == 0:
-                    room_name = 'Unknown'
+                    room_name = "Unknown"
                 else:
                     room_name = self._room_map[device.roomID].name
                 device.room_name = room_name
-                device.friendly_name = room_name + ' ' + device.name
-                device.ha_id = '{}_{}_{}'.format(
-                    slugify(room_name), slugify(device.name), device.id)
-                if device.enabled and \
-                        ('isPlugin' not in device or
-                         (not device.isPlugin or self._import_plugins)) and \
-                        device.ha_id not in self._excluded_devices:
+                device.friendly_name = room_name + " " + device.name
+                device.ha_id = "{}_{}_{}".format(
+                    slugify(room_name), slugify(device.name), device.id
+                )
+                if (
+                    device.enabled
+                    and (
+                        "isPlugin" not in device
+                        or (not device.isPlugin or self._import_plugins)
+                    )
+                    and device.ha_id not in self._excluded_devices
+                ):
                     device.mapped_type = self._map_device_to_type(device)
-                    device.device_config = \
-                        self._device_config.get(device.ha_id, {})
+                    device.device_config = self._device_config.get(device.ha_id, {})
                 else:
                     device.mapped_type = None
                 dtype = device.mapped_type
                 if dtype:
-                    device.unique_id_str = "{}.{}".format(
-                        self.hub_serial, device.id)
+                    device.unique_id_str = "{}.{}".format(self.hub_serial, device.id)
                     self._device_map[device.id] = device
-                    if dtype != 'climate':
+                    if dtype != "climate":
                         self.fibaro_devices[dtype].append(device)
                     else:
                         # if a sibling of this has been added, skip this one
                         # otherwise add the first visible device in the group
                         # which is a hack, but solves a problem with FGT having
                         # hidden compatibility devices before the real device
-                        if last_climate_parent != device.parentId and \
-                                device.visible:
+                        if last_climate_parent != device.parentId and device.visible:
                             self.fibaro_devices[dtype].append(device)
                             last_climate_parent = device.parentId
-                _LOGGER.debug("%s (%s, %s) -> %s %s",
-                              device.ha_id, device.type,
-                              device.baseType, dtype,
-                              str(device))
+                _LOGGER.debug(
+                    "%s (%s, %s) -> %s %s",
+                    device.ha_id,
+                    device.type,
+                    device.baseType,
+                    dtype,
+                    str(device),
+                )
             except (KeyError, ValueError):
                 pass
 
@@ -298,12 +332,12 @@ def setup(hass, base_config):
             hass.data[FIBARO_CONTROLLERS][controller.hub_serial] = controller
             for component in FIBARO_COMPONENTS:
                 hass.data[FIBARO_DEVICES][component].extend(
-                    controller.fibaro_devices[component])
+                    controller.fibaro_devices[component]
+                )
 
     if hass.data[FIBARO_CONTROLLERS]:
         for component in FIBARO_COMPONENTS:
-            discovery.load_platform(hass, component, DOMAIN, {},
-                                    base_config)
+            discovery.load_platform(hass, component, DOMAIN, {}, base_config)
         for controller in hass.data[FIBARO_CONTROLLERS].values():
             controller.enable_state_handler()
         hass.bus.listen_once(EVENT_HOMEASSISTANT_STOP, stop_fibaro)
@@ -333,35 +367,37 @@ class FibaroDevice(Entity):
     @property
     def level(self):
         """Get the level of Fibaro device."""
-        if 'value' in self.fibaro_device.properties:
+        if "value" in self.fibaro_device.properties:
             return self.fibaro_device.properties.value
         return None
 
     @property
     def level2(self):
         """Get the tilt level of Fibaro device."""
-        if 'value2' in self.fibaro_device.properties:
+        if "value2" in self.fibaro_device.properties:
             return self.fibaro_device.properties.value2
         return None
 
     def dont_know_message(self, action):
         """Make a warning in case we don't know how to perform an action."""
-        _LOGGER.warning("Not sure how to setValue: %s "
-                        "(available actions: %s)", str(self.ha_id),
-                        str(self.fibaro_device.actions))
+        _LOGGER.warning(
+            "Not sure how to setValue: %s " "(available actions: %s)",
+            str(self.ha_id),
+            str(self.fibaro_device.actions),
+        )
 
     def set_level(self, level):
         """Set the level of Fibaro device."""
         self.action("setValue", level)
-        if 'value' in self.fibaro_device.properties:
+        if "value" in self.fibaro_device.properties:
             self.fibaro_device.properties.value = level
-        if 'brightness' in self.fibaro_device.properties:
+        if "brightness" in self.fibaro_device.properties:
             self.fibaro_device.properties.brightness = level
 
     def set_level2(self, level):
         """Set the level2 of Fibaro device."""
         self.action("setValue2", level)
-        if 'value2' in self.fibaro_device.properties:
+        if "value2" in self.fibaro_device.properties:
             self.fibaro_device.properties.value2 = level
 
     def call_turn_on(self):
@@ -380,15 +416,13 @@ class FibaroDevice(Entity):
         white = int(max(0, min(255, white)))
         color_str = "{},{},{},{}".format(red, green, blue, white)
         self.fibaro_device.properties.color = color_str
-        self.action("setColor", str(red), str(green),
-                    str(blue), str(white))
+        self.action("setColor", str(red), str(green), str(blue), str(white))
 
     def action(self, cmd, *args):
         """Perform an action on the Fibaro HC."""
         if cmd in self.fibaro_device.actions:
             getattr(self.fibaro_device, cmd)(*args)
-            _LOGGER.debug("-> %s.%s%s called", str(self.ha_id),
-                          str(cmd), str(args))
+            _LOGGER.debug("-> %s.%s%s called", str(self.ha_id), str(cmd), str(args))
         else:
             self.dont_know_message(cmd)
 
@@ -400,7 +434,7 @@ class FibaroDevice(Entity):
     @property
     def current_power_w(self):
         """Return the current power usage in W."""
-        if 'power' in self.fibaro_device.properties:
+        if "power" in self.fibaro_device.properties:
             power = self.fibaro_device.properties.power
             if power:
                 return convert(power, float, 0.0)
@@ -410,10 +444,12 @@ class FibaroDevice(Entity):
     @property
     def current_binary_state(self):
         """Return the current binary state."""
-        if self.fibaro_device.properties.value == 'false':
+        if self.fibaro_device.properties.value == "false":
             return False
-        if self.fibaro_device.properties.value == 'true' or \
-                int(self.fibaro_device.properties.value) > 0:
+        if (
+            self.fibaro_device.properties.value == "true"
+            or int(self.fibaro_device.properties.value) > 0
+        ):
             return True
         return False
 
@@ -442,19 +478,22 @@ class FibaroDevice(Entity):
         attr = {}
 
         try:
-            if 'battery' in self.fibaro_device.interfaces:
-                attr[ATTR_BATTERY_LEVEL] = \
-                    int(self.fibaro_device.properties.batteryLevel)
-            if 'fibaroAlarmArm' in self.fibaro_device.interfaces:
+            if "battery" in self.fibaro_device.interfaces:
+                attr[ATTR_BATTERY_LEVEL] = int(
+                    self.fibaro_device.properties.batteryLevel
+                )
+            if "fibaroAlarmArm" in self.fibaro_device.interfaces:
                 attr[ATTR_ARMED] = bool(self.fibaro_device.properties.armed)
-            if 'power' in self.fibaro_device.interfaces:
+            if "power" in self.fibaro_device.interfaces:
                 attr[ATTR_CURRENT_POWER_W] = convert(
-                    self.fibaro_device.properties.power, float, 0.0)
-            if 'energy' in self.fibaro_device.interfaces:
+                    self.fibaro_device.properties.power, float, 0.0
+                )
+            if "energy" in self.fibaro_device.interfaces:
                 attr[ATTR_CURRENT_ENERGY_KWH] = convert(
-                    self.fibaro_device.properties.energy, float, 0.0)
+                    self.fibaro_device.properties.energy, float, 0.0
+                )
         except (ValueError, KeyError):
             pass
 
-        attr['fibaro_id'] = self.fibaro_device.id
+        attr["fibaro_id"] = self.fibaro_device.id
         return attr
