@@ -12,13 +12,12 @@ from homeassistant.components.sensor import PLATFORM_SCHEMA
 _LOGGER = logging.getLogger(__name__)
 
 
-CONF_FILE_PATHS = 'file_paths'
-ICON = 'mdi:file'
+CONF_FILE_PATHS = "file_paths"
+ICON = "mdi:file"
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend({
-    vol.Required(CONF_FILE_PATHS):
-        vol.All(cv.ensure_list, [cv.isfile]),
-})
+PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
+    {vol.Required(CONF_FILE_PATHS): vol.All(cv.ensure_list, [cv.isfile])}
+)
 
 
 def setup_platform(hass, config, add_entities, discovery_info=None):
@@ -26,8 +25,7 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
     sensors = []
     for path in config.get(CONF_FILE_PATHS):
         if not hass.config.is_allowed_path(path):
-            _LOGGER.error(
-                "Filepath %s is not valid or allowed", path)
+            _LOGGER.error("Filepath %s is not valid or allowed", path)
             continue
         else:
             sensors.append(Filesize(path))
@@ -41,11 +39,11 @@ class Filesize(Entity):
 
     def __init__(self, path):
         """Initialize the data object."""
-        self._path = path   # Need to check its a valid path
+        self._path = path  # Need to check its a valid path
         self._size = None
         self._last_updated = None
         self._name = path.split("/")[-1]
-        self._unit_of_measurement = 'MB'
+        self._unit_of_measurement = "MB"
 
     def update(self):
         """Update the sensor."""
@@ -63,7 +61,7 @@ class Filesize(Entity):
     def state(self):
         """Return the size of the file in MB."""
         decimals = 2
-        state_mb = round(self._size/1e6, decimals)
+        state_mb = round(self._size / 1e6, decimals)
         return state_mb
 
     @property
@@ -75,10 +73,10 @@ class Filesize(Entity):
     def device_state_attributes(self):
         """Return other details about the sensor state."""
         attr = {
-            'path': self._path,
-            'last_updated': self._last_updated,
-            'bytes': self._size,
-            }
+            "path": self._path,
+            "last_updated": self._last_updated,
+            "bytes": self._size,
+        }
         return attr
 
     @property
