@@ -4,24 +4,21 @@ import voluptuous as vol
 
 from homeassistant.components import websocket_api
 
-DATA_STORAGE = 'frontend_storage'
+DATA_STORAGE = "frontend_storage"
 STORAGE_VERSION_USER_DATA = 1
-STORAGE_KEY_USER_DATA = 'frontend.user_data_{}'
+STORAGE_KEY_USER_DATA = "frontend.user_data_{}"
 
 
 async def async_setup_frontend_storage(hass):
     """Set up frontend storage."""
     hass.data[DATA_STORAGE] = ({}, {})
-    hass.components.websocket_api.async_register_command(
-        websocket_set_user_data
-    )
-    hass.components.websocket_api.async_register_command(
-        websocket_get_user_data
-    )
+    hass.components.websocket_api.async_register_command(websocket_set_user_data)
+    hass.components.websocket_api.async_register_command(websocket_get_user_data)
 
 
 def with_store(orig_func):
     """Decorate function to provide data."""
+
     @wraps(orig_func)
     async def with_store_func(hass, connection, msg):
         """Provide user specific data and store to function."""
@@ -32,25 +29,24 @@ def with_store(orig_func):
         if store is None:
             store = stores[user_id] = hass.helpers.storage.Store(
                 STORAGE_VERSION_USER_DATA,
-                STORAGE_KEY_USER_DATA.format(connection.user.id)
+                STORAGE_KEY_USER_DATA.format(connection.user.id),
             )
 
         if user_id not in data:
             data[user_id] = await store.async_load() or {}
 
-        await orig_func(
-            hass, connection, msg,
-            store,
-            data[user_id],
-        )
+        await orig_func(hass, connection, msg, store, data[user_id])
+
     return with_store_func
 
 
-@websocket_api.websocket_command({
-    vol.Required('type'): 'frontend/set_user_data',
-    vol.Required('key'): str,
-    vol.Required('value'): vol.Any(bool, str, int, float, dict, list, None),
-})
+@websocket_api.websocket_command(
+    {
+        vol.Required("type"): "frontend/set_user_data",
+        vol.Required("key"): str,
+        vol.Required("value"): vol.Any(bool, str, int, float, dict, list, None),
+    }
+)
 @websocket_api.async_response
 @with_store
 async def websocket_set_user_data(hass, connection, msg, store, data):
@@ -58,17 +54,14 @@ async def websocket_set_user_data(hass, connection, msg, store, data):
 
     Async friendly.
     """
-    data[msg['key']] = msg['value']
+    data[msg["key"]] = msg["value"]
     await store.async_save(data)
-    connection.send_message(websocket_api.result_message(
-        msg['id'],
-    ))
+    connection.send_message(websocket_api.result_message(msg["id"]))
 
 
-@websocket_api.websocket_command({
-    vol.Required('type'): 'frontend/get_user_data',
-    vol.Optional('key'): str,
-})
+@websocket_api.websocket_command(
+    {vol.Required("type"): "frontend/get_user_data", vol.Optional("key"): str}
+)
 @websocket_api.async_response
 @with_store
 async def websocket_get_user_data(hass, connection, msg, store, data):
@@ -76,8 +69,8 @@ async def websocket_get_user_data(hass, connection, msg, store, data):
 
     Async friendly.
     """
-    connection.send_message(websocket_api.result_message(
-        msg['id'], {
-            'value': data.get(msg['key']) if 'key' in msg else data
-        }
-    ))
+    connection.send_message(
+        websocket_api.result_message(
+            msg["id"], {"value": data.get(msg["key"]) if "key" in msg else data}
+        )
+    )
