@@ -8,42 +8,51 @@ import homeassistant.helpers.config_validation as cv
 from homeassistant.components.cover import CoverDevice, PLATFORM_SCHEMA
 from homeassistant.helpers.event import track_utc_time_change
 from homeassistant.const import (
-    CONF_DEVICE, CONF_USERNAME, CONF_PASSWORD, CONF_ACCESS_TOKEN, CONF_NAME,
-    STATE_CLOSED, STATE_OPEN, CONF_COVERS)
+    CONF_DEVICE,
+    CONF_USERNAME,
+    CONF_PASSWORD,
+    CONF_ACCESS_TOKEN,
+    CONF_NAME,
+    STATE_CLOSED,
+    STATE_OPEN,
+    CONF_COVERS,
+)
 
 _LOGGER = logging.getLogger(__name__)
 
-ATTR_AVAILABLE = 'available'
-ATTR_SENSOR_STRENGTH = 'sensor_reflection_rate'
-ATTR_SIGNAL_STRENGTH = 'wifi_signal_strength'
-ATTR_TIME_IN_STATE = 'time_in_state'
+ATTR_AVAILABLE = "available"
+ATTR_SENSOR_STRENGTH = "sensor_reflection_rate"
+ATTR_SIGNAL_STRENGTH = "wifi_signal_strength"
+ATTR_TIME_IN_STATE = "time_in_state"
 
-DEFAULT_NAME = 'Garadget'
+DEFAULT_NAME = "Garadget"
 
-STATE_CLOSING = 'closing'
-STATE_OFFLINE = 'offline'
-STATE_OPENING = 'opening'
-STATE_STOPPED = 'stopped'
+STATE_CLOSING = "closing"
+STATE_OFFLINE = "offline"
+STATE_OPENING = "opening"
+STATE_STOPPED = "stopped"
 
 STATES_MAP = {
-    'open': STATE_OPEN,
-    'opening': STATE_OPENING,
-    'closed': STATE_CLOSED,
-    'closing': STATE_CLOSING,
-    'stopped': STATE_STOPPED
+    "open": STATE_OPEN,
+    "opening": STATE_OPENING,
+    "closed": STATE_CLOSED,
+    "closing": STATE_CLOSING,
+    "stopped": STATE_STOPPED,
 }
 
-COVER_SCHEMA = vol.Schema({
-    vol.Optional(CONF_ACCESS_TOKEN): cv.string,
-    vol.Optional(CONF_DEVICE): cv.string,
-    vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
-    vol.Optional(CONF_PASSWORD): cv.string,
-    vol.Optional(CONF_USERNAME): cv.string,
-})
+COVER_SCHEMA = vol.Schema(
+    {
+        vol.Optional(CONF_ACCESS_TOKEN): cv.string,
+        vol.Optional(CONF_DEVICE): cv.string,
+        vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
+        vol.Optional(CONF_PASSWORD): cv.string,
+        vol.Optional(CONF_USERNAME): cv.string,
+    }
+)
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend({
-    vol.Required(CONF_COVERS): cv.schema_with_slug_keys(COVER_SCHEMA),
-})
+PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
+    {vol.Required(CONF_COVERS): cv.schema_with_slug_keys(COVER_SCHEMA)}
+)
 
 
 def setup_platform(hass, config, add_entities, discovery_info=None):
@@ -53,11 +62,11 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
 
     for device_id, device_config in devices.items():
         args = {
-            'name': device_config.get(CONF_NAME),
-            'device_id': device_config.get(CONF_DEVICE, device_id),
-            'username': device_config.get(CONF_USERNAME),
-            'password': device_config.get(CONF_PASSWORD),
-            'access_token': device_config.get(CONF_ACCESS_TOKEN)
+            "name": device_config.get(CONF_NAME),
+            "device_id": device_config.get(CONF_DEVICE, device_id),
+            "username": device_config.get(CONF_USERNAME),
+            "password": device_config.get(CONF_PASSWORD),
+            "access_token": device_config.get(CONF_ACCESS_TOKEN),
         }
 
         covers.append(GaradgetCover(hass, args))
@@ -70,14 +79,14 @@ class GaradgetCover(CoverDevice):
 
     def __init__(self, hass, args):
         """Initialize the cover."""
-        self.particle_url = 'https://api.particle.io'
+        self.particle_url = "https://api.particle.io"
         self.hass = hass
-        self._name = args['name']
-        self.device_id = args['device_id']
-        self.access_token = args['access_token']
+        self._name = args["name"]
+        self.device_id = args["device_id"]
+        self.access_token = args["access_token"]
         self.obtained_token = False
-        self._username = args['username']
-        self._password = args['password']
+        self._username = args["username"]
+        self._password = args["password"]
         self._state = None
         self.time_in_state = None
         self.signal = None
@@ -91,19 +100,20 @@ class GaradgetCover(CoverDevice):
 
         try:
             if self._name is None:
-                doorconfig = self._get_variable('doorConfig')
-                if doorconfig['nme'] is not None:
-                    self._name = doorconfig['nme']
+                doorconfig = self._get_variable("doorConfig")
+                if doorconfig["nme"] is not None:
+                    self._name = doorconfig["nme"]
             self.update()
         except requests.exceptions.ConnectionError as ex:
-            _LOGGER.error(
-                "Unable to connect to server: %(reason)s", dict(reason=ex))
+            _LOGGER.error("Unable to connect to server: %(reason)s", dict(reason=ex))
             self._state = STATE_OFFLINE
             self._available = False
             self._name = DEFAULT_NAME
         except KeyError:
-            _LOGGER.warning("Garadget device %(device)s seems to be offline",
-                            dict(device=self.device_id))
+            _LOGGER.warning(
+                "Garadget device %(device)s seems to be offline",
+                dict(device=self.device_id),
+            )
             self._name = DEFAULT_NAME
             self._state = STATE_OFFLINE
             self._available = False
@@ -158,30 +168,27 @@ class GaradgetCover(CoverDevice):
     @property
     def device_class(self):
         """Return the class of this device, from component DEVICE_CLASSES."""
-        return 'garage'
+        return "garage"
 
     def get_token(self):
         """Get new token for usage during this session."""
         args = {
-            'grant_type': 'password',
-            'username': self._username,
-            'password': self._password
+            "grant_type": "password",
+            "username": self._username,
+            "password": self._password,
         }
-        url = '{}/oauth/token'.format(self.particle_url)
-        ret = requests.post(
-            url, auth=('particle', 'particle'), data=args, timeout=10)
+        url = "{}/oauth/token".format(self.particle_url)
+        ret = requests.post(url, auth=("particle", "particle"), data=args, timeout=10)
 
         try:
-            return ret.json()['access_token']
+            return ret.json()["access_token"]
         except KeyError:
             _LOGGER.error("Unable to retrieve access token")
 
     def remove_token(self):
         """Remove authorization token from API."""
-        url = '{}/v1/access_tokens/{}'.format(
-            self.particle_url, self.access_token)
-        ret = requests.delete(
-            url, auth=(self._username, self._password), timeout=10)
+        url = "{}/v1/access_tokens/{}".format(self.particle_url, self.access_token)
+        ret = requests.delete(url, auth=(self._username, self._password), timeout=10)
         return ret.text
 
     def _start_watcher(self, command):
@@ -189,7 +196,8 @@ class GaradgetCover(CoverDevice):
         _LOGGER.debug("Starting Watcher for command: %s ", command)
         if self._unsub_listener_cover is None:
             self._unsub_listener_cover = track_utc_time_change(
-                self.hass, self._check_state)
+                self.hass, self._check_state
+            )
 
     def _check_state(self, now):
         """Check the state of the service during an operation."""
@@ -197,42 +205,43 @@ class GaradgetCover(CoverDevice):
 
     def close_cover(self, **kwargs):
         """Close the cover."""
-        if self._state not in ['close', 'closing']:
-            ret = self._put_command('setState', 'close')
-            self._start_watcher('close')
-            return ret.get('return_value') == 1
+        if self._state not in ["close", "closing"]:
+            ret = self._put_command("setState", "close")
+            self._start_watcher("close")
+            return ret.get("return_value") == 1
 
     def open_cover(self, **kwargs):
         """Open the cover."""
-        if self._state not in ['open', 'opening']:
-            ret = self._put_command('setState', 'open')
-            self._start_watcher('open')
-            return ret.get('return_value') == 1
+        if self._state not in ["open", "opening"]:
+            ret = self._put_command("setState", "open")
+            self._start_watcher("open")
+            return ret.get("return_value") == 1
 
     def stop_cover(self, **kwargs):
         """Stop the door where it is."""
-        if self._state not in ['stopped']:
-            ret = self._put_command('setState', 'stop')
-            self._start_watcher('stop')
-            return ret['return_value'] == 1
+        if self._state not in ["stopped"]:
+            ret = self._put_command("setState", "stop")
+            self._start_watcher("stop")
+            return ret["return_value"] == 1
 
     def update(self):
         """Get updated status from API."""
         try:
-            status = self._get_variable('doorStatus')
-            _LOGGER.debug("Current Status: %s", status['status'])
-            self._state = STATES_MAP.get(status['status'], None)
-            self.time_in_state = status['time']
-            self.signal = status['signal']
-            self.sensor = status['sensor']
+            status = self._get_variable("doorStatus")
+            _LOGGER.debug("Current Status: %s", status["status"])
+            self._state = STATES_MAP.get(status["status"], None)
+            self.time_in_state = status["time"]
+            self.signal = status["signal"]
+            self.sensor = status["sensor"]
             self._available = True
         except requests.exceptions.ConnectionError as ex:
-            _LOGGER.error(
-                "Unable to connect to server: %(reason)s", dict(reason=ex))
+            _LOGGER.error("Unable to connect to server: %(reason)s", dict(reason=ex))
             self._state = STATE_OFFLINE
         except KeyError:
-            _LOGGER.warning("Garadget device %(device)s seems to be offline",
-                            dict(device=self.device_id))
+            _LOGGER.warning(
+                "Garadget device %(device)s seems to be offline",
+                dict(device=self.device_id),
+            )
             self._state = STATE_OFFLINE
 
         if self._state not in [STATE_CLOSING, STATE_OPENING]:
@@ -242,21 +251,21 @@ class GaradgetCover(CoverDevice):
 
     def _get_variable(self, var):
         """Get latest status."""
-        url = '{}/v1/devices/{}/{}?access_token={}'.format(
-            self.particle_url, self.device_id, var, self.access_token)
+        url = "{}/v1/devices/{}/{}?access_token={}".format(
+            self.particle_url, self.device_id, var, self.access_token
+        )
         ret = requests.get(url, timeout=10)
         result = {}
-        for pairs in ret.json()['result'].split('|'):
-            key = pairs.split('=')
+        for pairs in ret.json()["result"].split("|"):
+            key = pairs.split("=")
             result[key[0]] = key[1]
         return result
 
     def _put_command(self, func, arg=None):
         """Send commands to API."""
-        params = {'access_token': self.access_token}
+        params = {"access_token": self.access_token}
         if arg:
-            params['command'] = arg
-        url = '{}/v1/devices/{}/{}'.format(
-            self.particle_url, self.device_id, func)
+            params["command"] = arg
+        url = "{}/v1/devices/{}/{}".format(self.particle_url, self.device_id, func)
         ret = requests.post(url, data=params, timeout=10)
         return ret.json()
