@@ -1,6 +1,7 @@
 """Support for Homekit device discovery."""
 import logging
 
+from homeassistant.core import callback
 from homeassistant.helpers.entity import Entity
 from homeassistant.exceptions import ConfigEntryNotReady
 from homeassistant.helpers import device_registry as dr
@@ -8,10 +9,8 @@ from homeassistant.helpers import device_registry as dr
 # We need an import from .config_flow, without it .config_flow is never loaded.
 from .config_flow import HomekitControllerFlowHandler  # noqa: F401
 from .connection import get_accessory_information, HKDevice
-from .const import (
-    CONTROLLER, ENTITY_MAP, KNOWN_DEVICES
-)
-from .const import DOMAIN   # noqa: pylint: disable=unused-import
+from .const import CONTROLLER, ENTITY_MAP, KNOWN_DEVICES
+from .const import DOMAIN  # noqa: pylint: disable=unused-import
 from .storage import EntityMapStorage
 
 _LOGGER = logging.getLogger(__name__)
@@ -19,7 +18,7 @@ _LOGGER = logging.getLogger(__name__)
 
 def escape_characteristic_name(char_name):
     """Escape any dash or dots in a characteristics name."""
-    return char_name.replace('-', '_').replace('.', '_')
+    return char_name.replace("-", "_").replace(".", "_")
 
 
 class HomeKitEntity(Entity):
@@ -27,14 +26,41 @@ class HomeKitEntity(Entity):
 
     def __init__(self, accessory, devinfo):
         """Initialise a generic HomeKit device."""
-        self._available = True
         self._accessory = accessory
-        self._aid = devinfo['aid']
-        self._iid = devinfo['iid']
+        self._aid = devinfo["aid"]
+        self._iid = devinfo["iid"]
         self._features = 0
         self._chars = {}
         self.setup()
 
+        self._signals = []
+
+    async def async_added_to_hass(self):
+        """Entity added to hass."""
+        self._signals.append(
+            self.hass.helpers.dispatcher.async_dispatcher_connect(
+                self._accessory.signal_state_updated, self.async_state_changed
+            )
+        )
+
+        self._accessory.add_pollable_characteristics(self.pollable_characteristics)
+
+    async def async_will_remove_from_hass(self):
+        """Prepare to be removed from hass."""
+        self._accessory.remove_pollable_characteristics(self._aid)
+
+        for signal_remove in self._signals:
+            signal_remove()
+        self._signals.clear()
+
+    @property
+    def should_poll(self) -> bool:
+        """Return False.
+
+        Data update is triggered from HKDevice.
+        """
+        return False
+
     def setup(self):
         """Configure an entity baed on its HomeKit characterstics metadata."""
         # pylint: disable=import-error
@@ -43,24 +69,22 @@ class HomeKitEntity(Entity):
         accessories = self._accessory.accessories
 
         get_uuid = CharacteristicsTypes.get_uuid
-        characteristic_types = [
-            get_uuid(c) for c in self.get_characteristic_types()
-        ]
+        characteristic_types = [get_uuid(c) for c in self.get_characteristic_types()]
 
-        self._chars_to_poll = []
+        self.pollable_characteristics = []
         self._chars = {}
         self._char_names = {}
 
         for accessory in accessories:
-            if accessory['aid'] != self._aid:
+            if accessory["aid"] != self._aid:
                 continue
             self._accessory_info = get_accessory_information(accessory)
-            for service in accessory['services']:
-                if service['iid'] != self._iid:
+            for service in accessory["services"]:
+                if service["iid"] != self._iid:
                     continue
-                for char in service['characteristics']:
+                for char in service["characteristics"]:
                     try:
-                        uuid = CharacteristicsTypes.get_uuid(char['type'])
+                        uuid = CharacteristicsTypes.get_uuid(char["type"])
                     except KeyError:
                         # If a KeyError is raised its a non-standard
                         # characteristic. We must ignore it in this case.
@@ -75,93 +99,81 @@ class HomeKitEntity(Entity):
         from homekit.model.characteristics import CharacteristicsTypes
 
         # Build up a list of (aid, iid) tuples to poll on update()
-        self._chars_to_poll.append((self._aid, char['iid']))
+        self.pollable_characteristics.append((self._aid, char["iid"]))
 
         # Build a map of ctype -> iid
-        short_name = CharacteristicsTypes.get_short(char['type'])
-        self._chars[short_name] = char['iid']
-        self._char_names[char['iid']] = short_name
+        short_name = CharacteristicsTypes.get_short(char["type"])
+        self._chars[short_name] = char["iid"]
+        self._char_names[char["iid"]] = short_name
 
         # Callback to allow entity to configure itself based on this
         # characteristics metadata (valid values, value ranges, features, etc)
         setup_fn_name = escape_characteristic_name(short_name)
-        setup_fn = getattr(self, '_setup_{}'.format(setup_fn_name), None)
+        setup_fn = getattr(self, "_setup_{}".format(setup_fn_name), None)
         if not setup_fn:
             return
         # pylint: disable=not-callable
         setup_fn(char)
 
-    async def async_update(self):
-        """Obtain a HomeKit device's state."""
-        # pylint: disable=import-error
-        from homekit.exceptions import (
-            AccessoryDisconnectedError, AccessoryNotFoundError,
-            EncryptionError)
-
-        try:
-            new_values_dict = await self._accessory.get_characteristics(
-                self._chars_to_poll
-            )
-        except AccessoryNotFoundError:
-            # Not only did the connection fail, but also the accessory is not
-            # visible on the network.
-            self._available = False
-            return
-        except (AccessoryDisconnectedError, EncryptionError):
-            # Temporary connection failure. Device is still available but our
-            # connection was dropped.
-            return
-
-        self._available = True
-
-        for (_, iid), result in new_values_dict.items():
-            if 'value' not in result:
+    @callback
+    def async_state_changed(self):
+        """Collect new data from bridge and update the entity state in hass."""
+        accessory_state = self._accessory.current_state.get(self._aid, {})
+        for iid, result in accessory_state.items():
+            # No value so dont process this result
+            if "value" not in result:
                 continue
+
+            # Unknown iid - this is probably for a sibling service that is part
+            # of the same physical accessory. Ignore it.
+            if iid not in self._char_names:
+                continue
+
             # Callback to update the entity with this characteristic value
             char_name = escape_characteristic_name(self._char_names[iid])
-            update_fn = getattr(self, '_update_{}'.format(char_name), None)
+            update_fn = getattr(self, "_update_{}".format(char_name), None)
             if not update_fn:
                 continue
+
             # pylint: disable=not-callable
-            update_fn(result['value'])
+            update_fn(result["value"])
+
+        self.async_write_ha_state()
 
     @property
     def unique_id(self):
         """Return the ID of this device."""
-        serial = self._accessory_info['serial-number']
+        serial = self._accessory_info["serial-number"]
         return "homekit-{}-{}".format(serial, self._iid)
 
     @property
     def name(self):
         """Return the name of the device if any."""
-        return self._accessory_info.get('name')
+        return self._accessory_info.get("name")
 
     @property
     def available(self) -> bool:
         """Return True if entity is available."""
-        return self._available
+        return self._accessory.available
 
     @property
     def device_info(self):
         """Return the device info."""
-        accessory_serial = self._accessory_info['serial-number']
+        accessory_serial = self._accessory_info["serial-number"]
 
         device_info = {
-            'identifiers': {
-                (DOMAIN, 'serial-number', accessory_serial),
-            },
-            'name': self._accessory_info['name'],
-            'manufacturer': self._accessory_info.get('manufacturer', ''),
-            'model': self._accessory_info.get('model', ''),
-            'sw_version': self._accessory_info.get('firmware.revision', ''),
+            "identifiers": {(DOMAIN, "serial-number", accessory_serial)},
+            "name": self._accessory_info["name"],
+            "manufacturer": self._accessory_info.get("manufacturer", ""),
+            "model": self._accessory_info.get("model", ""),
+            "sw_version": self._accessory_info.get("firmware.revision", ""),
         }
 
         # Some devices only have a single accessory - we don't add a
         # via_device otherwise it would be self referential.
-        bridge_serial = self._accessory.connection_info['serial-number']
+        bridge_serial = self._accessory.connection_info["serial-number"]
         if accessory_serial != bridge_serial:
-            device_info['via_device'] = (
-                DOMAIN, 'serial-number', bridge_serial)
+            device_info["via_device"] = (DOMAIN, "serial-number", bridge_serial)
 
         return device_info
 
@@ -185,13 +197,13 @@ async def async_setup_entry(hass, entry):
     device_registry.async_get_or_create(
         config_entry_id=entry.entry_id,
         identifiers={
-            (DOMAIN, 'serial-number', conn_info['serial-number']),
-            (DOMAIN, 'accessory-id', conn.unique_id),
+            (DOMAIN, "serial-number", conn_info["serial-number"]),
+            (DOMAIN, "accessory-id", conn.unique_id),
         },
         name=conn.name,
-        manufacturer=conn_info.get('manufacturer'),
-        model=conn_info.get('model'),
-        sw_version=conn_info.get('firmware.revision'),
+        manufacturer=conn_info.get("manufacturer"),
+        model=conn_info.get("model"),
+        sw_version=conn_info.get("firmware.revision"),
     )
 
     return True
@@ -211,7 +223,18 @@ async def async_setup(hass, config):
     return True
 
 
+async def async_unload_entry(hass, entry):
+    """Disconnect from HomeKit devices before unloading entry."""
+    hkid = entry.data["AccessoryPairingID"]
+
+    if hkid in hass.data[KNOWN_DEVICES]:
+        connection = hass.data[KNOWN_DEVICES][hkid]
+        await connection.async_unload()
+
+    return True
+
+
 async def async_remove_entry(hass, entry):
     """Cleanup caches before removing config entry."""
-    hkid = entry.data['AccessoryPairingID']
+    hkid = entry.data["AccessoryPairingID"]
     hass.data[ENTITY_MAP].async_delete_map(hkid)
