@@ -3,12 +3,17 @@ import logging
 
 from homeassistant.components.alarm_control_panel import AlarmControlPanel
 from homeassistant.const import (
-    ATTR_BATTERY_LEVEL, STATE_ALARM_ARMED_AWAY, STATE_ALARM_ARMED_HOME,
-    STATE_ALARM_ARMED_NIGHT, STATE_ALARM_DISARMED, STATE_ALARM_TRIGGERED)
+    ATTR_BATTERY_LEVEL,
+    STATE_ALARM_ARMED_AWAY,
+    STATE_ALARM_ARMED_HOME,
+    STATE_ALARM_ARMED_NIGHT,
+    STATE_ALARM_DISARMED,
+    STATE_ALARM_TRIGGERED,
+)
 
 from . import KNOWN_DEVICES, HomeKitEntity
 
-ICON = 'mdi:security'
+ICON = "mdi:security"
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -28,21 +33,20 @@ TARGET_STATE_MAP = {
 }
 
 
-async def async_setup_platform(
-        hass, config, async_add_entities, discovery_info=None):
+async def async_setup_platform(hass, config, async_add_entities, discovery_info=None):
     """Legacy set up platform."""
     pass
 
 
 async def async_setup_entry(hass, config_entry, async_add_entities):
     """Set up Homekit alarm control panel."""
-    hkid = config_entry.data['AccessoryPairingID']
+    hkid = config_entry.data["AccessoryPairingID"]
     conn = hass.data[KNOWN_DEVICES][hkid]
 
     def async_add_service(aid, service):
-        if service['stype'] != 'security-system':
+        if service["stype"] != "security-system":
             return False
-        info = {'aid': aid, 'iid': service['iid']}
+        info = {"aid": aid, "iid": service["iid"]}
         async_add_entities([HomeKitAlarmControlPanel(conn, info)], True)
         return True
 
@@ -62,6 +66,7 @@ class HomeKitAlarmControlPanel(HomeKitEntity, AlarmControlPanel):
         """Define the homekit characteristics the entity cares about."""
         # pylint: disable=import-error
         from homekit.model.characteristics import CharacteristicsTypes
+
         return [
             CharacteristicsTypes.SECURITY_SYSTEM_STATE_CURRENT,
             CharacteristicsTypes.SECURITY_SYSTEM_STATE_TARGET,
@@ -102,9 +107,13 @@ class HomeKitAlarmControlPanel(HomeKitEntity, AlarmControlPanel):
 
     async def set_alarm_state(self, state, code=None):
         """Send state command."""
-        characteristics = [{'aid': self._aid,
-                            'iid': self._chars['security-system-state.target'],
-                            'value': TARGET_STATE_MAP[state]}]
+        characteristics = [
+            {
+                "aid": self._aid,
+                "iid": self._chars["security-system-state.target"],
+                "value": TARGET_STATE_MAP[state],
+            }
+        ]
         await self._accessory.put_characteristics(characteristics)
 
     @property
@@ -113,6 +122,4 @@ class HomeKitAlarmControlPanel(HomeKitEntity, AlarmControlPanel):
         if self._battery_level is None:
             return None
 
-        return {
-            ATTR_BATTERY_LEVEL: self._battery_level,
-        }
+        return {ATTR_BATTERY_LEVEL: self._battery_level}
