@@ -2,16 +2,25 @@
 import logging
 
 from homematicip.aio.device import (
-    AsyncBrandDimmer, AsyncBrandSwitchMeasuring,
-    AsyncBrandSwitchNotificationLight, AsyncDimmer, AsyncFullFlushDimmer,
-    AsyncPluggableDimmer)
+    AsyncBrandDimmer,
+    AsyncBrandSwitchMeasuring,
+    AsyncBrandSwitchNotificationLight,
+    AsyncDimmer,
+    AsyncFullFlushDimmer,
+    AsyncPluggableDimmer,
+)
 from homematicip.aio.home import AsyncHome
 from homematicip.base.enums import RGBColorState
 from homematicip.base.functionalChannels import NotificationLightChannel
 
 from homeassistant.components.light import (
-    ATTR_BRIGHTNESS, ATTR_COLOR_NAME, ATTR_HS_COLOR, SUPPORT_BRIGHTNESS,
-    SUPPORT_COLOR, Light)
+    ATTR_BRIGHTNESS,
+    ATTR_COLOR_NAME,
+    ATTR_HS_COLOR,
+    SUPPORT_BRIGHTNESS,
+    SUPPORT_COLOR,
+    Light,
+)
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.core import HomeAssistant
 
@@ -19,18 +28,18 @@ from . import DOMAIN as HMIPC_DOMAIN, HMIPC_HAPID, HomematicipGenericDevice
 
 _LOGGER = logging.getLogger(__name__)
 
-ATTR_ENERGY_COUNTER = 'energy_counter_kwh'
-ATTR_POWER_CONSUMPTION = 'power_consumption'
+ATTR_ENERGY_COUNTER = "energy_counter_kwh"
+ATTR_POWER_CONSUMPTION = "power_consumption"
 
 
-async def async_setup_platform(
-        hass, config, async_add_entities, discovery_info=None):
+async def async_setup_platform(hass, config, async_add_entities, discovery_info=None):
     """Old way of setting up HomematicIP Cloud lights."""
     pass
 
 
-async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry,
-                            async_add_entities) -> None:
+async def async_setup_entry(
+    hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities
+) -> None:
     """Set up the HomematicIP Cloud lights from a config entry."""
     home = hass.data[HMIPC_DOMAIN][config_entry.data[HMIPC_HAPID]].home
     devices = []
@@ -39,13 +48,18 @@ async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry,
             devices.append(HomematicipLightMeasuring(home, device))
         elif isinstance(device, AsyncBrandSwitchNotificationLight):
             devices.append(HomematicipLight(home, device))
-            devices.append(HomematicipNotificationLight(
-                home, device, device.topLightChannelIndex))
-            devices.append(HomematicipNotificationLight(
-                home, device, device.bottomLightChannelIndex))
-        elif isinstance(device,
-                        (AsyncDimmer, AsyncPluggableDimmer,
-                         AsyncBrandDimmer, AsyncFullFlushDimmer)):
+            devices.append(
+                HomematicipNotificationLight(home, device, device.topLightChannelIndex)
+            )
+            devices.append(
+                HomematicipNotificationLight(
+                    home, device, device.bottomLightChannelIndex
+                )
+            )
+        elif isinstance(
+            device,
+            (AsyncDimmer, AsyncPluggableDimmer, AsyncBrandDimmer, AsyncFullFlushDimmer),
+        ):
             devices.append(HomematicipDimmer(home, device))
 
     if devices:
@@ -81,8 +95,9 @@ class HomematicipLightMeasuring(HomematicipLight):
         """Return the state attributes of the generic device."""
         attr = super().device_state_attributes
         if self._device.currentPowerConsumption > 0.05:
-            attr[ATTR_POWER_CONSUMPTION] = \
-                round(self._device.currentPowerConsumption, 2)
+            attr[ATTR_POWER_CONSUMPTION] = round(
+                self._device.currentPowerConsumption, 2
+            )
         attr[ATTR_ENERGY_COUNTER] = round(self._device.energyCounter, 2)
         return attr
 
@@ -97,14 +112,13 @@ class HomematicipDimmer(HomematicipGenericDevice, Light):
     @property
     def is_on(self) -> bool:
         """Return true if device is on."""
-        return self._device.dimLevel is not None and \
-            self._device.dimLevel > 0.0
+        return self._device.dimLevel is not None and self._device.dimLevel > 0.0
 
     @property
     def brightness(self) -> int:
         """Return the brightness of this light between 0..255."""
         if self._device.dimLevel:
-            return int(self._device.dimLevel*255)
+            return int(self._device.dimLevel * 255)
         return 0
 
     @property
@@ -115,7 +129,7 @@ class HomematicipDimmer(HomematicipGenericDevice, Light):
     async def async_turn_on(self, **kwargs):
         """Turn the light on."""
         if ATTR_BRIGHTNESS in kwargs:
-            await self._device.set_dim_level(kwargs[ATTR_BRIGHTNESS]/255.0)
+            await self._device.set_dim_level(kwargs[ATTR_BRIGHTNESS] / 255.0)
         else:
             await self._device.set_dim_level(1)
 
@@ -131,9 +145,9 @@ class HomematicipNotificationLight(HomematicipGenericDevice, Light):
         """Initialize the dimmer light device."""
         self.channel = channel
         if self.channel == 2:
-            super().__init__(home, device, 'Top')
+            super().__init__(home, device, "Top")
         else:
-            super().__init__(home, device, 'Bottom')
+            super().__init__(home, device, "Bottom")
 
         self._color_switcher = {
             RGBColorState.WHITE: [0.0, 0.0],
@@ -142,7 +156,7 @@ class HomematicipNotificationLight(HomematicipGenericDevice, Light):
             RGBColorState.GREEN: [120.0, 100.0],
             RGBColorState.TURQUOISE: [180.0, 100.0],
             RGBColorState.BLUE: [240.0, 100.0],
-            RGBColorState.PURPLE: [300.0, 100.0]
+            RGBColorState.PURPLE: [300.0, 100.0],
         }
 
     @property
@@ -152,8 +166,10 @@ class HomematicipNotificationLight(HomematicipGenericDevice, Light):
     @property
     def is_on(self) -> bool:
         """Return true if device is on."""
-        return self._func_channel.dimLevel is not None and \
-            self._func_channel.dimLevel > 0.0
+        return (
+            self._func_channel.dimLevel is not None
+            and self._func_channel.dimLevel > 0.0
+        )
 
     @property
     def brightness(self) -> int:
@@ -179,7 +195,7 @@ class HomematicipNotificationLight(HomematicipGenericDevice, Light):
     @property
     def name(self) -> str:
         """Return the name of the generic device."""
-        return "{} {}".format(super().name, 'Notification')
+        return "{} {}".format(super().name, "Notification")
 
     @property
     def supported_features(self) -> int:
@@ -189,9 +205,7 @@ class HomematicipNotificationLight(HomematicipGenericDevice, Light):
     @property
     def unique_id(self) -> str:
         """Return a unique ID."""
-        return "{}_{}_{}".format(self.__class__.__name__,
-                                 self.post,
-                                 self._device.id)
+        return "{}_{}_{}".format(self.__class__.__name__, self.post, self._device.id)
 
     async def async_turn_on(self, **kwargs):
         """Turn the light on."""
@@ -212,17 +226,12 @@ class HomematicipNotificationLight(HomematicipGenericDevice, Light):
         brightness = max(10, brightness)
         dim_level = brightness / 255.0
 
-        await self._device.set_rgb_dim_level(
-            self.channel,
-            simple_rgb_color,
-            dim_level)
+        await self._device.set_rgb_dim_level(self.channel, simple_rgb_color, dim_level)
 
     async def async_turn_off(self, **kwargs):
         """Turn the light off."""
         simple_rgb_color = self._func_channel.simpleRGBColorState
-        await self._device.set_rgb_dim_level(
-            self.channel,
-            simple_rgb_color, 0.0)
+        await self._device.set_rgb_dim_level(self.channel, simple_rgb_color, 0.0)
 
 
 def _convert_color(color) -> RGBColorState:
