@@ -10,7 +10,10 @@ from aiohttp.web_exceptions import HTTPMovedPermanently
 import voluptuous as vol
 
 from homeassistant.const import (
-    EVENT_HOMEASSISTANT_START, EVENT_HOMEASSISTANT_STOP, SERVER_PORT)
+    EVENT_HOMEASSISTANT_START,
+    EVENT_HOMEASSISTANT_STOP,
+    SERVER_PORT,
+)
 import homeassistant.helpers.config_validation as cv
 import homeassistant.util as hass_util
 from homeassistant.util import ssl as ssl_util
@@ -18,41 +21,38 @@ from homeassistant.util.logging import HideSensitiveDataFilter
 
 from .auth import setup_auth
 from .ban import setup_bans
-from .const import (  # noqa
-    KEY_AUTHENTICATED,
-    KEY_HASS,
-    KEY_HASS_USER,
-    KEY_REAL_IP,
-)
+from .const import KEY_AUTHENTICATED, KEY_HASS, KEY_HASS_USER, KEY_REAL_IP  # noqa
 from .cors import setup_cors
 from .real_ip import setup_real_ip
 from .static import CACHE_HEADERS, CachingStaticResource
 from .view import HomeAssistantView  # noqa
 
-DOMAIN = 'http'
+DOMAIN = "http"
 
-CONF_API_PASSWORD = 'api_password'
-CONF_SERVER_HOST = 'server_host'
-CONF_SERVER_PORT = 'server_port'
-CONF_BASE_URL = 'base_url'
-CONF_SSL_CERTIFICATE = 'ssl_certificate'
-CONF_SSL_PEER_CERTIFICATE = 'ssl_peer_certificate'
-CONF_SSL_KEY = 'ssl_key'
-CONF_CORS_ORIGINS = 'cors_allowed_origins'
-CONF_USE_X_FORWARDED_FOR = 'use_x_forwarded_for'
-CONF_TRUSTED_PROXIES = 'trusted_proxies'
-CONF_TRUSTED_NETWORKS = 'trusted_networks'
-CONF_LOGIN_ATTEMPTS_THRESHOLD = 'login_attempts_threshold'
-CONF_IP_BAN_ENABLED = 'ip_ban_enabled'
-CONF_SSL_PROFILE = 'ssl_profile'
+CONF_API_PASSWORD = "api_password"
+CONF_SERVER_HOST = "server_host"
+CONF_SERVER_PORT = "server_port"
+CONF_BASE_URL = "base_url"
+CONF_SSL_CERTIFICATE = "ssl_certificate"
+CONF_SSL_PEER_CERTIFICATE = "ssl_peer_certificate"
+CONF_SSL_KEY = "ssl_key"
+CONF_CORS_ORIGINS = "cors_allowed_origins"
+CONF_USE_X_FORWARDED_FOR = "use_x_forwarded_for"
+CONF_TRUSTED_PROXIES = "trusted_proxies"
+CONF_TRUSTED_NETWORKS = "trusted_networks"
+CONF_LOGIN_ATTEMPTS_THRESHOLD = "login_attempts_threshold"
+CONF_IP_BAN_ENABLED = "ip_ban_enabled"
+CONF_SSL_PROFILE = "ssl_profile"
 
-SSL_MODERN = 'modern'
-SSL_INTERMEDIATE = 'intermediate'
+SSL_MODERN = "modern"
+SSL_INTERMEDIATE = "intermediate"
 
 _LOGGER = logging.getLogger(__name__)
 
-DEFAULT_SERVER_HOST = '0.0.0.0'
-DEFAULT_DEVELOPMENT = '0'
+DEFAULT_SERVER_HOST = "0.0.0.0"
+DEFAULT_DEVELOPMENT = "0"
+# To be able to load custom cards.
+DEFAULT_CORS = "https://cast.home-assistant.io"
 NO_LOGIN_ATTEMPT_THRESHOLD = -1
 
 
@@ -65,7 +65,8 @@ def trusted_networks_deprecated(value):
         "Configuring trusted_networks via the http integration has been"
         " deprecated. Use the trusted networks auth provider instead."
         " For instructions, see https://www.home-assistant.io/docs/"
-        "authentication/providers/#trusted-networks")
+        "authentication/providers/#trusted-networks"
+    )
     return value
 
 
@@ -78,49 +79,54 @@ def api_password_deprecated(value):
         "Configuring api_password via the http integration has been"
         " deprecated. Use the legacy api password auth provider instead."
         " For instructions, see https://www.home-assistant.io/docs/"
-        "authentication/providers/#legacy-api-password")
+        "authentication/providers/#legacy-api-password"
+    )
     return value
 
 
-HTTP_SCHEMA = vol.Schema({
-    vol.Optional(CONF_API_PASSWORD):
-        vol.All(cv.string, api_password_deprecated),
-    vol.Optional(CONF_SERVER_HOST, default=DEFAULT_SERVER_HOST): cv.string,
-    vol.Optional(CONF_SERVER_PORT, default=SERVER_PORT): cv.port,
-    vol.Optional(CONF_BASE_URL): cv.string,
-    vol.Optional(CONF_SSL_CERTIFICATE): cv.isfile,
-    vol.Optional(CONF_SSL_PEER_CERTIFICATE): cv.isfile,
-    vol.Optional(CONF_SSL_KEY): cv.isfile,
-    vol.Optional(CONF_CORS_ORIGINS, default=[]):
-        vol.All(cv.ensure_list, [cv.string]),
-    vol.Inclusive(CONF_USE_X_FORWARDED_FOR, 'proxy'): cv.boolean,
-    vol.Inclusive(CONF_TRUSTED_PROXIES, 'proxy'):
-        vol.All(cv.ensure_list, [ip_network]),
-    vol.Optional(CONF_TRUSTED_NETWORKS, default=[]):
-        vol.All(cv.ensure_list, [ip_network], trusted_networks_deprecated),
-    vol.Optional(CONF_LOGIN_ATTEMPTS_THRESHOLD,
-                 default=NO_LOGIN_ATTEMPT_THRESHOLD):
-        vol.Any(cv.positive_int, NO_LOGIN_ATTEMPT_THRESHOLD),
-    vol.Optional(CONF_IP_BAN_ENABLED, default=True): cv.boolean,
-    vol.Optional(CONF_SSL_PROFILE, default=SSL_MODERN):
-        vol.In([SSL_INTERMEDIATE, SSL_MODERN]),
-})
+HTTP_SCHEMA = vol.Schema(
+    {
+        vol.Optional(CONF_API_PASSWORD): vol.All(cv.string, api_password_deprecated),
+        vol.Optional(CONF_SERVER_HOST, default=DEFAULT_SERVER_HOST): cv.string,
+        vol.Optional(CONF_SERVER_PORT, default=SERVER_PORT): cv.port,
+        vol.Optional(CONF_BASE_URL): cv.string,
+        vol.Optional(CONF_SSL_CERTIFICATE): cv.isfile,
+        vol.Optional(CONF_SSL_PEER_CERTIFICATE): cv.isfile,
+        vol.Optional(CONF_SSL_KEY): cv.isfile,
+        vol.Optional(CONF_CORS_ORIGINS, default=[DEFAULT_CORS]): vol.All(
+            cv.ensure_list, [cv.string]
+        ),
+        vol.Inclusive(CONF_USE_X_FORWARDED_FOR, "proxy"): cv.boolean,
+        vol.Inclusive(CONF_TRUSTED_PROXIES, "proxy"): vol.All(
+            cv.ensure_list, [ip_network]
+        ),
+        vol.Optional(CONF_TRUSTED_NETWORKS, default=[]): vol.All(
+            cv.ensure_list, [ip_network], trusted_networks_deprecated
+        ),
+        vol.Optional(
+            CONF_LOGIN_ATTEMPTS_THRESHOLD, default=NO_LOGIN_ATTEMPT_THRESHOLD
+        ): vol.Any(cv.positive_int, NO_LOGIN_ATTEMPT_THRESHOLD),
+        vol.Optional(CONF_IP_BAN_ENABLED, default=True): cv.boolean,
+        vol.Optional(CONF_SSL_PROFILE, default=SSL_MODERN): vol.In(
+            [SSL_INTERMEDIATE, SSL_MODERN]
+        ),
+    }
+)
 
-CONFIG_SCHEMA = vol.Schema({
-    DOMAIN: HTTP_SCHEMA,
-}, extra=vol.ALLOW_EXTRA)
+CONFIG_SCHEMA = vol.Schema({DOMAIN: HTTP_SCHEMA}, extra=vol.ALLOW_EXTRA)
 
 
 class ApiConfig:
     """Configuration settings for API server."""
 
-    def __init__(self, host: str, port: Optional[int] = SERVER_PORT,
-                 use_ssl: bool = False) -> None:
+    def __init__(
+        self, host: str, port: Optional[int] = SERVER_PORT, use_ssl: bool = False
+    ) -> None:
         """Initialize a new API config object."""
         self.host = host
         self.port = port
 
-        host = host.rstrip('/')
+        host = host.rstrip("/")
         if host.startswith(("http://", "https://")):
             self.base_url = host
         elif use_ssl:
@@ -129,7 +135,7 @@ class ApiConfig:
             self.base_url = "http://{}".format(host)
 
         if port is not None:
-            self.base_url += ':{}'.format(port)
+            self.base_url += ":{}".format(port)
 
 
 async def async_setup(hass, config):
@@ -153,8 +159,9 @@ async def async_setup(hass, config):
     ssl_profile = conf[CONF_SSL_PROFILE]
 
     if api_password is not None:
-        logging.getLogger('aiohttp.access').addFilter(
-            HideSensitiveDataFilter(api_password))
+        logging.getLogger("aiohttp.access").addFilter(
+            HideSensitiveDataFilter(api_password)
+        )
 
     server = HomeAssistantHTTP(
         hass,
@@ -203,11 +210,21 @@ async def async_setup(hass, config):
 class HomeAssistantHTTP:
     """HTTP server for Home Assistant."""
 
-    def __init__(self, hass,
-                 ssl_certificate, ssl_peer_certificate,
-                 ssl_key, server_host, server_port, cors_origins,
-                 use_x_forwarded_for, trusted_proxies,
-                 login_threshold, is_ban_enabled, ssl_profile):
+    def __init__(
+        self,
+        hass,
+        ssl_certificate,
+        ssl_peer_certificate,
+        ssl_key,
+        server_host,
+        server_port,
+        cors_origins,
+        use_x_forwarded_for,
+        trusted_proxies,
+        login_threshold,
+        is_ban_enabled,
+        ssl_profile,
+    ):
         """Initialize the HTTP Home Assistant server."""
         app = self.app = web.Application(middlewares=[])
         app[KEY_HASS] = hass
@@ -246,13 +263,13 @@ class HomeAssistantHTTP:
             # Instantiate the view, if needed
             view = view()
 
-        if not hasattr(view, 'url'):
+        if not hasattr(view, "url"):
             class_name = view.__class__.__name__
             raise AttributeError(
                 '{0} missing required attribute "url"'.format(class_name)
             )
 
-        if not hasattr(view, 'name'):
+        if not hasattr(view, "name"):
             class_name = view.__class__.__name__
             raise AttributeError(
                 '{0} missing required attribute "name"'.format(class_name)
@@ -269,11 +286,12 @@ class HomeAssistantHTTP:
         for the redirect, otherwise it has to be a string with placeholders in
         rule syntax.
         """
-        def redirect(request):
+
+        async def redirect(request):
             """Redirect to location."""
             raise HTTPMovedPermanently(redirect_to)
 
-        self.app.router.add_route('GET', url, redirect)
+        self.app.router.add_route("GET", url, redirect)
 
     def register_static_path(self, url_path, path, cache_headers=True):
         """Register a folder or file to serve as a static path."""
@@ -286,15 +304,18 @@ class HomeAssistantHTTP:
             return
 
         if cache_headers:
+
             async def serve_file(request):
                 """Serve file from disk."""
                 return web.FileResponse(path, headers=CACHE_HEADERS)
+
         else:
+
             async def serve_file(request):
                 """Serve file from disk."""
                 return web.FileResponse(path)
 
-        self.app.router.add_route('GET', url_path, serve_file)
+        self.app.router.add_route("GET", url_path, serve_file)
 
     async def start(self):
         """Start the aiohttp server."""
@@ -305,18 +326,21 @@ class HomeAssistantHTTP:
                 else:
                     context = ssl_util.server_context_modern()
                 await self.hass.async_add_executor_job(
-                    context.load_cert_chain, self.ssl_certificate,
-                    self.ssl_key)
+                    context.load_cert_chain, self.ssl_certificate, self.ssl_key
+                )
             except OSError as error:
-                _LOGGER.error("Could not read SSL certificate from %s: %s",
-                              self.ssl_certificate, error)
+                _LOGGER.error(
+                    "Could not read SSL certificate from %s: %s",
+                    self.ssl_certificate,
+                    error,
+                )
                 return
 
             if self.ssl_peer_certificate:
                 context.verify_mode = ssl.CERT_REQUIRED
                 await self.hass.async_add_executor_job(
-                    context.load_verify_locations,
-                    self.ssl_peer_certificate)
+                    context.load_verify_locations, self.ssl_peer_certificate
+                )
 
         else:
             context = None
@@ -330,13 +354,15 @@ class HomeAssistantHTTP:
 
         self.runner = web.AppRunner(self.app)
         await self.runner.setup()
-        self.site = web.TCPSite(self.runner, self.server_host,
-                                self.server_port, ssl_context=context)
+        self.site = web.TCPSite(
+            self.runner, self.server_host, self.server_port, ssl_context=context
+        )
         try:
             await self.site.start()
         except OSError as error:
-            _LOGGER.error("Failed to create HTTP server at port %d: %s",
-                          self.server_port, error)
+            _LOGGER.error(
+                "Failed to create HTTP server at port %d: %s", self.server_port, error
+            )
 
     async def stop(self):
         """Stop the aiohttp server."""
