@@ -2,13 +2,17 @@
 from aiohttp.web_urldispatcher import Resource, ResourceRoute, StaticResource
 from aiohttp.hdrs import ACCEPT, CONTENT_TYPE, ORIGIN, AUTHORIZATION
 
-from homeassistant.const import (
-    HTTP_HEADER_HA_AUTH, HTTP_HEADER_X_REQUESTED_WITH)
+from homeassistant.const import HTTP_HEADER_HA_AUTH, HTTP_HEADER_X_REQUESTED_WITH
 from homeassistant.core import callback
 
 ALLOWED_CORS_HEADERS = [
-    ORIGIN, ACCEPT, HTTP_HEADER_X_REQUESTED_WITH, CONTENT_TYPE,
-    HTTP_HEADER_HA_AUTH, AUTHORIZATION]
+    ORIGIN,
+    ACCEPT,
+    HTTP_HEADER_X_REQUESTED_WITH,
+    CONTENT_TYPE,
+    HTTP_HEADER_HA_AUTH,
+    AUTHORIZATION,
+]
 VALID_CORS_TYPES = (Resource, ResourceRoute, StaticResource)
 
 
@@ -17,18 +21,21 @@ def setup_cors(app, origins):
     """Set up CORS."""
     import aiohttp_cors
 
-    cors = aiohttp_cors.setup(app, defaults={
-        host: aiohttp_cors.ResourceOptions(
-            allow_headers=ALLOWED_CORS_HEADERS,
-            allow_methods='*',
-        ) for host in origins
-    })
+    cors = aiohttp_cors.setup(
+        app,
+        defaults={
+            host: aiohttp_cors.ResourceOptions(
+                allow_headers=ALLOWED_CORS_HEADERS, allow_methods="*"
+            )
+            for host in origins
+        },
+    )
 
     cors_added = set()
 
     def _allow_cors(route, config=None):
         """Allow CORS on a route."""
-        if hasattr(route, 'resource'):
+        if hasattr(route, "resource"):
             path = route.resource
         else:
             path = route
@@ -38,18 +45,23 @@ def setup_cors(app, origins):
 
         path = path.canonical
 
+        if path.startswith("/api/hassio_ingress/"):
+            return
+
         if path in cors_added:
             return
 
         cors.add(route, config)
         cors_added.add(path)
 
-    app['allow_cors'] = lambda route: _allow_cors(route, {
-        '*': aiohttp_cors.ResourceOptions(
-            allow_headers=ALLOWED_CORS_HEADERS,
-            allow_methods='*',
-        )
-    })
+    app["allow_cors"] = lambda route: _allow_cors(
+        route,
+        {
+            "*": aiohttp_cors.ResourceOptions(
+                allow_headers=ALLOWED_CORS_HEADERS, allow_methods="*"
+            )
+        },
+    )
 
     if not origins:
         return
