@@ -3,12 +3,19 @@ from datetime import timedelta
 from functools import reduce
 import logging
 import operator
+from typing import Any, Callable
 
 import voluptuous as vol
 import attr
+from huawei_lte_api.AuthorizedConnection import AuthorizedConnection
+from huawei_lte_api.Client import Client
+from huawei_lte_api.exceptions import ResponseErrorNotSupportedException
 
 from homeassistant.const import (
-    CONF_URL, CONF_USERNAME, CONF_PASSWORD, EVENT_HOMEASSISTANT_STOP,
+    CONF_URL,
+    CONF_USERNAME,
+    CONF_PASSWORD,
+    EVENT_HOMEASSISTANT_STOP,
 )
 from homeassistant.helpers import config_validation as cv
 from homeassistant.util import Throttle
@@ -17,20 +24,30 @@ _LOGGER = logging.getLogger(__name__)
 
 # dicttoxml (used by huawei-lte-api) has uselessly verbose INFO level.
 # https://github.com/quandyfactory/dicttoxml/issues/60
-logging.getLogger('dicttoxml').setLevel(logging.WARNING)
+logging.getLogger("dicttoxml").setLevel(logging.WARNING)
 
 MIN_TIME_BETWEEN_UPDATES = timedelta(seconds=10)
 
-DOMAIN = 'huawei_lte'
-DATA_KEY = 'huawei_lte'
+DOMAIN = "huawei_lte"
+DATA_KEY = "huawei_lte"
 
-CONFIG_SCHEMA = vol.Schema({
-    DOMAIN: vol.All(cv.ensure_list, [vol.Schema({
-        vol.Required(CONF_URL): cv.url,
-        vol.Required(CONF_USERNAME): cv.string,
-        vol.Required(CONF_PASSWORD): cv.string,
-    })])
-}, extra=vol.ALLOW_EXTRA)
+CONFIG_SCHEMA = vol.Schema(
+    {
+        DOMAIN: vol.All(
+            cv.ensure_list,
+            [
+                vol.Schema(
+                    {
+                        vol.Required(CONF_URL): cv.url,
+                        vol.Required(CONF_USERNAME): cv.string,
+                        vol.Required(CONF_PASSWORD): cv.string,
+                    }
+                )
+            ],
+        )
+    },
+    extra=vol.ALLOW_EXTRA,
+)
 
 
 @attr.s
@@ -40,7 +57,7 @@ class RouterData:
     client = attr.ib()
     device_information = attr.ib(init=False, factory=dict)
     device_signal = attr.ib(init=False, factory=dict)
-    traffic_statistics = attr.ib(init=False, factory=dict)
+    monitoring_traffic_statistics = attr.ib(init=False, factory=dict)
     wlan_host_list = attr.ib(init=False, factory=dict)
 
     _subscriptions = attr.ib(init=False, factory=set)
@@ -81,19 +98,23 @@ class RouterData:
 
     def _update(self) -> None:
         debugging = _LOGGER.isEnabledFor(logging.DEBUG)
-        if debugging or "device_information" in self._subscriptions:
-            self.device_information = self.client.device.information()
-            _LOGGER.debug("device_information=%s", self.device_information)
-        if debugging or "device_signal" in self._subscriptions:
-            self.device_signal = self.client.device.signal()
-            _LOGGER.debug("device_signal=%s", self.device_signal)
-        if debugging or "traffic_statistics" in self._subscriptions:
-            self.traffic_statistics = \
-                self.client.monitoring.traffic_statistics()
-            _LOGGER.debug("traffic_statistics=%s", self.traffic_statistics)
-        if debugging or "wlan_host_list" in self._subscriptions:
-            self.wlan_host_list = self.client.wlan.host_list()
-            _LOGGER.debug("wlan_host_list=%s", self.wlan_host_list)
+
+        def get_data(path: str, func: Callable[[None], Any]) -> None:
+            if debugging or path in self._subscriptions:
+                try:
+                    setattr(self, path, func())
+                except ResponseErrorNotSupportedException as ex:
+                    _LOGGER.warning("%s not supported by device", path, exc_info=ex)
+                    self._subscriptions.discard(path)
+                finally:
+                    _LOGGER.debug("%s=%s", path, getattr(self, path))
+
+        get_data("device_information", self.client.device.information)
+        get_data("device_signal", self.client.device.signal)
+        get_data(
+            "monitoring_traffic_statistics", self.client.monitoring.traffic_statistics
+        )
+        get_data("wlan_host_list", self.client.wlan.host_list)
 
 
 @attr.s
@@ -123,18 +144,11 @@ def setup(hass, config) -> bool:
 
 def _setup_lte(hass, lte_config) -> None:
     """Set up Huawei LTE router."""
-    from huawei_lte_api.AuthorizedConnection import AuthorizedConnection
-    from huawei_lte_api.Client import Client
-
     url = lte_config[CONF_URL]
     username = lte_config[CONF_USERNAME]
     password = lte_config[CONF_PASSWORD]
 
-    connection = AuthorizedConnection(
-        url,
-        username=username,
-        password=password,
-    )
+    connection = AuthorizedConnection(url, username=username, password=password)
     client = Client(connection)
 
     data = RouterData(client)
