@@ -5,60 +5,61 @@ import logging
 
 import voluptuous as vol
 
-from homeassistant.const import (
-    ATTR_ENTITY_ID, ATTR_NAME, CONF_ENTITY_ID, CONF_NAME)
+from homeassistant.const import ATTR_ENTITY_ID, ATTR_NAME, CONF_ENTITY_ID, CONF_NAME
 from homeassistant.core import callback
 from homeassistant.exceptions import HomeAssistantError
 import homeassistant.helpers.config_validation as cv
+from homeassistant.helpers.config_validation import ENTITY_SERVICE_SCHEMA
 from homeassistant.helpers.entity import Entity
 from homeassistant.helpers.entity_component import EntityComponent
 from homeassistant.util.async_ import run_callback_threadsafe
 
 _LOGGER = logging.getLogger(__name__)
 
-DOMAIN = 'image_processing'
+DOMAIN = "image_processing"
 SCAN_INTERVAL = timedelta(seconds=10)
 
 DEVICE_CLASSES = [
-    'alpr',        # Automatic license plate recognition
-    'face',        # Face
-    'ocr',         # OCR
+    "alpr",  # Automatic license plate recognition
+    "face",  # Face
+    "ocr",  # OCR
 ]
 
-SERVICE_SCAN = 'scan'
+SERVICE_SCAN = "scan"
 
-EVENT_DETECT_FACE = 'image_processing.detect_face'
+EVENT_DETECT_FACE = "image_processing.detect_face"
 
-ATTR_AGE = 'age'
-ATTR_CONFIDENCE = 'confidence'
-ATTR_FACES = 'faces'
-ATTR_GENDER = 'gender'
-ATTR_GLASSES = 'glasses'
-ATTR_MOTION = 'motion'
-ATTR_TOTAL_FACES = 'total_faces'
+ATTR_AGE = "age"
+ATTR_CONFIDENCE = "confidence"
+ATTR_FACES = "faces"
+ATTR_GENDER = "gender"
+ATTR_GLASSES = "glasses"
+ATTR_MOTION = "motion"
+ATTR_TOTAL_FACES = "total_faces"
 
-CONF_SOURCE = 'source'
-CONF_CONFIDENCE = 'confidence'
+CONF_SOURCE = "source"
+CONF_CONFIDENCE = "confidence"
 
 DEFAULT_TIMEOUT = 10
 DEFAULT_CONFIDENCE = 80
 
-SOURCE_SCHEMA = vol.Schema({
-    vol.Required(CONF_ENTITY_ID): cv.entity_domain('camera'),
-    vol.Optional(CONF_NAME): cv.string,
-})
+SOURCE_SCHEMA = vol.Schema(
+    {
+        vol.Required(CONF_ENTITY_ID): cv.entity_domain("camera"),
+        vol.Optional(CONF_NAME): cv.string,
+    }
+)
 
-PLATFORM_SCHEMA = cv.PLATFORM_SCHEMA.extend({
-    vol.Optional(CONF_SOURCE): vol.All(cv.ensure_list, [SOURCE_SCHEMA]),
-    vol.Optional(CONF_CONFIDENCE, default=DEFAULT_CONFIDENCE):
-        vol.All(vol.Coerce(float), vol.Range(min=0, max=100)),
-})
+PLATFORM_SCHEMA = cv.PLATFORM_SCHEMA.extend(
+    {
+        vol.Optional(CONF_SOURCE): vol.All(cv.ensure_list, [SOURCE_SCHEMA]),
+        vol.Optional(CONF_CONFIDENCE, default=DEFAULT_CONFIDENCE): vol.All(
+            vol.Coerce(float), vol.Range(min=0, max=100)
+        ),
+    }
+)
 PLATFORM_SCHEMA_BASE = cv.PLATFORM_SCHEMA_BASE.extend(PLATFORM_SCHEMA.schema)
 
-SERVICE_SCAN_SCHEMA = vol.Schema({
-    vol.Optional(ATTR_ENTITY_ID): cv.comp_entity_ids,
-})
-
 
 async def async_setup(hass, config):
     """Set up the image processing."""
@@ -73,15 +74,14 @@ async def async_setup(hass, config):
         update_tasks = []
         for entity in image_entities:
             entity.async_set_context(service.context)
-            update_tasks.append(
-                entity.async_update_ha_state(True))
+            update_tasks.append(entity.async_update_ha_state(True))
 
         if update_tasks:
             await asyncio.wait(update_tasks)
 
     hass.services.async_register(
-        DOMAIN, SERVICE_SCAN, async_scan_service,
-        schema=SERVICE_SCAN_SCHEMA)
+        DOMAIN, SERVICE_SCAN, async_scan_service, schema=ENTITY_SERVICE_SCHEMA
+    )
 
     return True
 
@@ -122,7 +122,8 @@ class ImageProcessingEntity(Entity):
 
         try:
             image = await camera.async_get_image(
-                self.camera_entity, timeout=self.timeout)
+                self.camera_entity, timeout=self.timeout
+            )
 
         except HomeAssistantError as err:
             _LOGGER.error("Error on receive image from entity: %s", err)
@@ -168,22 +169,20 @@ class ImageProcessingFaceEntity(ImageProcessingEntity):
     @property
     def device_class(self):
         """Return the class of this device, from component DEVICE_CLASSES."""
-        return 'face'
+        return "face"
 
     @property
     def state_attributes(self):
         """Return device specific state attributes."""
-        attr = {
-            ATTR_FACES: self.faces,
-            ATTR_TOTAL_FACES: self.total_faces,
-        }
+        attr = {ATTR_FACES: self.faces, ATTR_TOTAL_FACES: self.total_faces}
 
         return attr
 
     def process_faces(self, faces, total):
         """Send event with detected faces and store data."""
         run_callback_threadsafe(
-            self.hass.loop, self.async_process_faces, faces, total).result()
+            self.hass.loop, self.async_process_faces, faces, total
+        ).result()
 
     @callback
     def async_process_faces(self, faces, total):
@@ -210,9 +209,7 @@ class ImageProcessingFaceEntity(ImageProcessingEntity):
                     continue
 
             face.update({ATTR_ENTITY_ID: self.entity_id})
-            self.hass.async_add_job(
-                self.hass.bus.async_fire, EVENT_DETECT_FACE, face
-            )
+            self.hass.async_add_job(self.hass.bus.async_fire, EVENT_DETECT_FACE, face)
 
         # Update entity store
         self.faces = faces
