@@ -5,29 +5,32 @@ import voluptuous as vol
 
 import homeassistant.helpers.config_validation as cv
 from homeassistant.components.device_tracker import (
-    DOMAIN, PLATFORM_SCHEMA, DeviceScanner)
-from homeassistant.const import (
-    CONF_HOST, CONF_PORT, CONF_PASSWORD, CONF_USERNAME
+    DOMAIN,
+    PLATFORM_SCHEMA,
+    DeviceScanner,
 )
+from homeassistant.const import CONF_HOST, CONF_PORT, CONF_PASSWORD, CONF_USERNAME
 
 _LOGGER = logging.getLogger(__name__)
 
 # Interface name to track devices for. Most likely one will not need to
 # change it from default 'Home'. This is needed not to track Guest WI-FI-
 # clients and router itself
-CONF_INTERFACE = 'interface'
+CONF_INTERFACE = "interface"
 
-DEFAULT_INTERFACE = 'Home'
+DEFAULT_INTERFACE = "Home"
 DEFAULT_PORT = 23
 
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend({
-    vol.Required(CONF_HOST): cv.string,
-    vol.Required(CONF_USERNAME): cv.string,
-    vol.Required(CONF_PORT, default=DEFAULT_PORT): cv.port,
-    vol.Required(CONF_PASSWORD): cv.string,
-    vol.Required(CONF_INTERFACE, default=DEFAULT_INTERFACE): cv.string,
-})
+PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
+    {
+        vol.Required(CONF_HOST): cv.string,
+        vol.Required(CONF_USERNAME): cv.string,
+        vol.Required(CONF_PORT, default=DEFAULT_PORT): cv.port,
+        vol.Required(CONF_PASSWORD): cv.string,
+        vol.Required(CONF_INTERFACE, default=DEFAULT_INTERFACE): cv.string,
+    }
+)
 
 
 def get_scanner(_hass, config):
@@ -43,16 +46,19 @@ class KeeneticNDMS2DeviceScanner(DeviceScanner):
     def __init__(self, config):
         """Initialize the scanner."""
         from ndms2_client import Client, TelnetConnection
+
         self.last_results = []
 
         self._interface = config[CONF_INTERFACE]
 
-        self._client = Client(TelnetConnection(
-            config.get(CONF_HOST),
-            config.get(CONF_PORT),
-            config.get(CONF_USERNAME),
-            config.get(CONF_PASSWORD),
-        ))
+        self._client = Client(
+            TelnetConnection(
+                config.get(CONF_HOST),
+                config.get(CONF_PORT),
+                config.get(CONF_USERNAME),
+                config.get(CONF_PASSWORD),
+            )
+        )
 
         self.success_init = self._update_info()
         _LOGGER.info("Scanner initialized")
@@ -65,16 +71,17 @@ class KeeneticNDMS2DeviceScanner(DeviceScanner):
 
     def get_device_name(self, device):
         """Return the name of the given device or None if we don't know."""
-        name = next((
-            result.name for result in self.last_results
-            if result.mac == device), None)
+        name = next(
+            (result.name for result in self.last_results if result.mac == device), None
+        )
         return name
 
     def get_extra_attributes(self, device):
         """Return the IP of the given device."""
-        attributes = next((
-            {'ip': result.ip} for result in self.last_results
-            if result.mac == device), {})
+        attributes = next(
+            ({"ip": result.ip} for result in self.last_results if result.mac == device),
+            {},
+        )
         return attributes
 
     def _update_info(self):
@@ -82,6 +89,7 @@ class KeeneticNDMS2DeviceScanner(DeviceScanner):
         _LOGGER.debug("Fetching devices from router...")
 
         from ndms2_client import ConnectionException
+
         try:
             self.last_results = [
                 dev
