@@ -8,35 +8,44 @@ import time
 import voluptuous as vol
 
 import homeassistant.helpers.config_validation as cv
-from homeassistant.const import (
-    EVENT_HOMEASSISTANT_START, EVENT_HOMEASSISTANT_STOP)
+from homeassistant.const import EVENT_HOMEASSISTANT_START, EVENT_HOMEASSISTANT_STOP
 
 _LOGGER = logging.getLogger(__name__)
 
-DEVICE_DESCRIPTOR = 'device_descriptor'
-DEVICE_ID_GROUP = 'Device description'
-DEVICE_NAME = 'device_name'
-DOMAIN = 'keyboard_remote'
+DEVICE_DESCRIPTOR = "device_descriptor"
+DEVICE_ID_GROUP = "Device description"
+DEVICE_NAME = "device_name"
+DOMAIN = "keyboard_remote"
 
-ICON = 'mdi:remote'
+ICON = "mdi:remote"
 
-KEY_CODE = 'key_code'
-KEY_VALUE = {'key_up': 0, 'key_down': 1, 'key_hold': 2}
-KEYBOARD_REMOTE_COMMAND_RECEIVED = 'keyboard_remote_command_received'
-KEYBOARD_REMOTE_CONNECTED = 'keyboard_remote_connected'
-KEYBOARD_REMOTE_DISCONNECTED = 'keyboard_remote_disconnected'
+KEY_CODE = "key_code"
+KEY_VALUE = {"key_up": 0, "key_down": 1, "key_hold": 2}
+KEYBOARD_REMOTE_COMMAND_RECEIVED = "keyboard_remote_command_received"
+KEYBOARD_REMOTE_CONNECTED = "keyboard_remote_connected"
+KEYBOARD_REMOTE_DISCONNECTED = "keyboard_remote_disconnected"
 
-TYPE = 'type'
+TYPE = "type"
 
-CONFIG_SCHEMA = vol.Schema({
-    DOMAIN:
-        vol.All(cv.ensure_list, [vol.Schema({
-            vol.Exclusive(DEVICE_DESCRIPTOR, DEVICE_ID_GROUP): cv.string,
-            vol.Exclusive(DEVICE_NAME, DEVICE_ID_GROUP): cv.string,
-            vol.Optional(TYPE, default='key_up'):
-                vol.All(cv.string, vol.Any('key_up', 'key_down', 'key_hold'))
-        })])
-}, extra=vol.ALLOW_EXTRA)
+CONFIG_SCHEMA = vol.Schema(
+    {
+        DOMAIN: vol.All(
+            cv.ensure_list,
+            [
+                vol.Schema(
+                    {
+                        vol.Exclusive(DEVICE_DESCRIPTOR, DEVICE_ID_GROUP): cv.string,
+                        vol.Exclusive(DEVICE_NAME, DEVICE_ID_GROUP): cv.string,
+                        vol.Optional(TYPE, default="key_up"): vol.All(
+                            cv.string, vol.Any("key_up", "key_down", "key_hold")
+                        ),
+                    }
+                )
+            ],
+        )
+    },
+    extra=vol.ALLOW_EXTRA,
+)
 
 
 def setup(hass, config):
@@ -77,19 +86,25 @@ class KeyboardRemoteThread(threading.Thread):
             _LOGGER.debug("Keyboard connected, %s", self.device_id)
         else:
             _LOGGER.debug(
-                "Keyboard not connected, %s. "
-                "Check /dev/input/event* permissions", self.device_id)
+                "Keyboard not connected, %s. " "Check /dev/input/event* permissions",
+                self.device_id,
+            )
 
-            id_folder = '/dev/input/by-id/'
+            id_folder = "/dev/input/by-id/"
 
             if os.path.isdir(id_folder):
                 from evdev import InputDevice, list_devices
-                device_names = [InputDevice(file_name).name
-                                for file_name in list_devices()]
+
+                device_names = [
+                    InputDevice(file_name).name for file_name in list_devices()
+                ]
                 _LOGGER.debug(
                     "Possible device names are: %s. "
                     "Possible device descriptors are %s: %s",
-                    device_names, id_folder, os.listdir(id_folder))
+                    device_names,
+                    id_folder,
+                    os.listdir(id_folder),
+                )
 
         threading.Thread.__init__(self)
         self.stopped = threading.Event()
@@ -98,6 +113,7 @@ class KeyboardRemoteThread(threading.Thread):
     def _get_keyboard_device(self):
         """Get the keyboard device."""
         from evdev import InputDevice, list_devices
+
         if self.device_name:
             devices = [InputDevice(file_name) for file_name in list_devices()]
             for device in devices:
@@ -122,7 +138,7 @@ class KeyboardRemoteThread(threading.Thread):
 
         while not self.stopped.isSet():
             # Sleeps to ease load on processor
-            time.sleep(.05)
+            time.sleep(0.05)
 
             if self.dev is None:
                 self.dev = self._get_keyboard_device()
@@ -132,8 +148,8 @@ class KeyboardRemoteThread(threading.Thread):
                         KEYBOARD_REMOTE_CONNECTED,
                         {
                             DEVICE_DESCRIPTOR: self.device_descriptor,
-                            DEVICE_NAME: self.device_name
-                        }
+                            DEVICE_NAME: self.device_name,
+                        },
                     )
                     _LOGGER.debug("Keyboard re-connected, %s", self.device_id)
                 else:
@@ -147,8 +163,8 @@ class KeyboardRemoteThread(threading.Thread):
                     KEYBOARD_REMOTE_DISCONNECTED,
                     {
                         DEVICE_DESCRIPTOR: self.device_descriptor,
-                        DEVICE_NAME: self.device_name
-                    }
+                        DEVICE_NAME: self.device_name,
+                    },
                 )
                 _LOGGER.debug("Keyboard disconnected, %s", self.device_id)
                 continue
@@ -163,8 +179,8 @@ class KeyboardRemoteThread(threading.Thread):
                     {
                         KEY_CODE: event.code,
                         DEVICE_DESCRIPTOR: self.device_descriptor,
-                        DEVICE_NAME: self.device_name
-                    }
+                        DEVICE_NAME: self.device_name,
+                    },
                 )
 
 
@@ -177,12 +193,12 @@ class KeyboardRemote:
         for dev_block in config:
             device_descriptor = dev_block.get(DEVICE_DESCRIPTOR)
             device_name = dev_block.get(DEVICE_NAME)
-            key_value = KEY_VALUE.get(dev_block.get(TYPE, 'key_up'))
+            key_value = KEY_VALUE.get(dev_block.get(TYPE, "key_up"))
 
-            if device_descriptor is not None\
-                    or device_name is not None:
+            if device_descriptor is not None or device_name is not None:
                 thread = KeyboardRemoteThread(
-                    hass, device_name, device_descriptor, key_value)
+                    hass, device_name, device_descriptor, key_value
+                )
                 self.threads.append(thread)
 
     def run(self):
