@@ -11,19 +11,21 @@ from homeassistant.helpers.entity import Entity
 
 _LOGGER = logging.getLogger(__name__)
 
-ATTR_LAST_PLAYED = 'last_played'
-ATTR_PLAY_COUNT = 'play_count'
-ATTR_TOP_PLAYED = 'top_played'
+ATTR_LAST_PLAYED = "last_played"
+ATTR_PLAY_COUNT = "play_count"
+ATTR_TOP_PLAYED = "top_played"
 ATTRIBUTION = "Data provided by Last.fm"
 
-CONF_USERS = 'users'
+CONF_USERS = "users"
 
-ICON = 'mdi:lastfm'
+ICON = "mdi:lastfm"
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend({
-    vol.Required(CONF_API_KEY): cv.string,
-    vol.Required(CONF_USERS, default=[]): vol.All(cv.ensure_list, [cv.string]),
-})
+PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
+    {
+        vol.Required(CONF_API_KEY): cv.string,
+        vol.Required(CONF_USERS, default=[]): vol.All(cv.ensure_list, [cv.string]),
+    }
+)
 
 
 def setup_platform(hass, config, add_entities, discovery_info=None):
@@ -70,7 +72,7 @@ class LastfmSensor(Entity):
     @property
     def entity_id(self):
         """Return the entity ID."""
-        return 'sensor.lastfm_{}'.format(self._name)
+        return "sensor.lastfm_{}".format(self._name)
 
     @property
     def state(self):
@@ -82,13 +84,11 @@ class LastfmSensor(Entity):
         self._cover = self._user.get_image()
         self._playcount = self._user.get_playcount()
         last = self._user.get_recent_tracks(limit=2)[0]
-        self._lastplayed = "{} - {}".format(
-            last.track.artist, last.track.title)
+        self._lastplayed = "{} - {}".format(last.track.artist, last.track.title)
         top = self._user.get_top_tracks(limit=1)[0]
         toptitle = re.search("', '(.+?)',", str(top))
         topartist = re.search("'(.+?)',", str(top))
-        self._topplayed = "{} - {}".format(
-            topartist.group(1), toptitle.group(1))
+        self._topplayed = "{} - {}".format(topartist.group(1), toptitle.group(1))
         if self._user.get_now_playing() is None:
             self._state = "Not Scrobbling"
             return
