@@ -13,7 +13,7 @@ from .helpers import get_api
 
 _LOGGER = logging.getLogger(__name__)
 
-DOCS_URL = 'https://www.home-assistant.io/components/life360'
+DOCS_URL = "https://www.home-assistant.io/components/life360"
 
 
 @config_entries.HANDLERS.register(DOMAIN)
@@ -48,23 +48,24 @@ class Life360ConfigFlow(config_entries.ConfigFlow):
                 # pylint: disable=no-value-for-parameter
                 vol.Email()(self._username)
                 authorization = self._api.get_authorization(
-                    self._username, self._password)
+                    self._username, self._password
+                )
             except vol.Invalid:
-                errors[CONF_USERNAME] = 'invalid_username'
+                errors[CONF_USERNAME] = "invalid_username"
             except LoginError:
-                errors['base'] = 'invalid_credentials'
+                errors["base"] = "invalid_credentials"
             else:
                 if self._username in self.configured_usernames:
-                    errors['base'] = 'user_already_configured'
+                    errors["base"] = "user_already_configured"
                 else:
                     return self.async_create_entry(
                         title=self._username,
                         data={
                             CONF_USERNAME: self._username,
                             CONF_PASSWORD: self._password,
-                            CONF_AUTHORIZATION: authorization
+                            CONF_AUTHORIZATION: authorization,
                         },
-                        description_placeholders={'docs_url': DOCS_URL}
+                        description_placeholders={"docs_url": DOCS_URL},
                     )
 
         data_schema = OrderedDict()
@@ -72,10 +73,10 @@ class Life360ConfigFlow(config_entries.ConfigFlow):
         data_schema[vol.Required(CONF_PASSWORD, default=self._password)] = str
 
         return self.async_show_form(
-            step_id='user',
+            step_id="user",
             data_schema=vol.Schema(data_schema),
             errors=errors,
-            description_placeholders={'docs_url': DOCS_URL}
+            description_placeholders={"docs_url": DOCS_URL},
         )
 
     async def async_step_import(self, user_input):
@@ -85,13 +86,13 @@ class Life360ConfigFlow(config_entries.ConfigFlow):
         try:
             authorization = self._api.get_authorization(username, password)
         except LoginError:
-            _LOGGER.error('Invalid credentials for %s', username)
-            return self.async_abort(reason='invalid_credentials')
+            _LOGGER.error("Invalid credentials for %s", username)
+            return self.async_abort(reason="invalid_credentials")
         return self.async_create_entry(
-            title='{} (from configuration)'.format(username),
+            title="{} (from configuration)".format(username),
             data={
                 CONF_USERNAME: username,
                 CONF_PASSWORD: password,
-                CONF_AUTHORIZATION: authorization
-            }
+                CONF_AUTHORIZATION: authorization,
+            },
         )
