@@ -9,39 +9,42 @@ from homeassistant.loader import bind_hass
 from homeassistant.helpers.entity_component import EntityComponent
 from homeassistant.helpers.entity import Entity
 from homeassistant.helpers.config_validation import (  # noqa
-    PLATFORM_SCHEMA, PLATFORM_SCHEMA_BASE)
+    ENTITY_SERVICE_SCHEMA,
+    PLATFORM_SCHEMA,
+    PLATFORM_SCHEMA_BASE,
+)
 import homeassistant.helpers.config_validation as cv
 from homeassistant.const import (
-    ATTR_CODE, ATTR_CODE_FORMAT, ATTR_ENTITY_ID, STATE_LOCKED, STATE_UNLOCKED,
-    SERVICE_LOCK, SERVICE_UNLOCK, SERVICE_OPEN)
+    ATTR_CODE,
+    ATTR_CODE_FORMAT,
+    STATE_LOCKED,
+    STATE_UNLOCKED,
+    SERVICE_LOCK,
+    SERVICE_UNLOCK,
+    SERVICE_OPEN,
+)
 from homeassistant.components import group
 
-ATTR_CHANGED_BY = 'changed_by'
+ATTR_CHANGED_BY = "changed_by"
 
-DOMAIN = 'lock'
+DOMAIN = "lock"
 SCAN_INTERVAL = timedelta(seconds=30)
 
-ENTITY_ID_ALL_LOCKS = group.ENTITY_ID_FORMAT.format('all_locks')
-ENTITY_ID_FORMAT = DOMAIN + '.{}'
+ENTITY_ID_ALL_LOCKS = group.ENTITY_ID_FORMAT.format("all_locks")
+ENTITY_ID_FORMAT = DOMAIN + ".{}"
 
-GROUP_NAME_ALL_LOCKS = 'all locks'
+GROUP_NAME_ALL_LOCKS = "all locks"
 
 MIN_TIME_BETWEEN_SCANS = timedelta(seconds=10)
 
-LOCK_SERVICE_SCHEMA = vol.Schema({
-    vol.Optional(ATTR_ENTITY_ID): cv.comp_entity_ids,
-    vol.Optional(ATTR_CODE): cv.string,
-})
+LOCK_SERVICE_SCHEMA = ENTITY_SERVICE_SCHEMA.extend({vol.Optional(ATTR_CODE): cv.string})
 
 # Bitfield of features supported by the lock entity
 SUPPORT_OPEN = 1
 
 _LOGGER = logging.getLogger(__name__)
 
-PROP_TO_ATTR = {
-    'changed_by': ATTR_CHANGED_BY,
-    'code_format': ATTR_CODE_FORMAT,
-}
+PROP_TO_ATTR = {"changed_by": ATTR_CHANGED_BY, "code_format": ATTR_CODE_FORMAT}
 
 
 @bind_hass
@@ -54,21 +57,19 @@ def is_locked(hass, entity_id=None):
 async def async_setup(hass, config):
     """Track states and offer events for locks."""
     component = hass.data[DOMAIN] = EntityComponent(
-        _LOGGER, DOMAIN, hass, SCAN_INTERVAL, GROUP_NAME_ALL_LOCKS)
+        _LOGGER, DOMAIN, hass, SCAN_INTERVAL, GROUP_NAME_ALL_LOCKS
+    )
 
     await component.async_setup(config)
 
     component.async_register_entity_service(
-        SERVICE_UNLOCK, LOCK_SERVICE_SCHEMA,
-        'async_unlock'
+        SERVICE_UNLOCK, LOCK_SERVICE_SCHEMA, "async_unlock"
     )
     component.async_register_entity_service(
-        SERVICE_LOCK, LOCK_SERVICE_SCHEMA,
-        'async_lock'
+        SERVICE_LOCK, LOCK_SERVICE_SCHEMA, "async_lock"
     )
     component.async_register_entity_service(
-        SERVICE_OPEN, LOCK_SERVICE_SCHEMA,
-        'async_open'
+        SERVICE_OPEN, LOCK_SERVICE_SCHEMA, "async_open"
     )
 
     return True
