@@ -6,19 +6,33 @@ import logging
 import async_timeout
 
 from homeassistant.components.notify import (
-    ATTR_DATA, ATTR_MESSAGE, ATTR_TARGET, ATTR_TITLE, ATTR_TITLE_DEFAULT,
-    BaseNotificationService)
+    ATTR_DATA,
+    ATTR_MESSAGE,
+    ATTR_TARGET,
+    ATTR_TITLE,
+    ATTR_TITLE_DEFAULT,
+    BaseNotificationService,
+)
 
 from homeassistant.helpers.aiohttp_client import async_get_clientsession
 import homeassistant.util.dt as dt_util
 
-from .const import (ATTR_APP_DATA, ATTR_APP_ID, ATTR_APP_VERSION,
-                    ATTR_DEVICE_NAME, ATTR_OS_VERSION, ATTR_PUSH_RATE_LIMITS,
-                    ATTR_PUSH_RATE_LIMITS_ERRORS,
-                    ATTR_PUSH_RATE_LIMITS_MAXIMUM,
-                    ATTR_PUSH_RATE_LIMITS_RESETS_AT,
-                    ATTR_PUSH_RATE_LIMITS_SUCCESSFUL, ATTR_PUSH_TOKEN,
-                    ATTR_PUSH_URL, DATA_CONFIG_ENTRIES, DOMAIN)
+from .const import (
+    ATTR_APP_DATA,
+    ATTR_APP_ID,
+    ATTR_APP_VERSION,
+    ATTR_DEVICE_NAME,
+    ATTR_OS_VERSION,
+    ATTR_PUSH_RATE_LIMITS,
+    ATTR_PUSH_RATE_LIMITS_ERRORS,
+    ATTR_PUSH_RATE_LIMITS_MAXIMUM,
+    ATTR_PUSH_RATE_LIMITS_RESETS_AT,
+    ATTR_PUSH_RATE_LIMITS_SUCCESSFUL,
+    ATTR_PUSH_TOKEN,
+    ATTR_PUSH_URL,
+    DATA_CONFIG_ENTRIES,
+    DOMAIN,
+)
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -46,17 +60,21 @@ def log_rate_limits(hass, device_name, resp, level=logging.INFO):
 
     rate_limits = resp[ATTR_PUSH_RATE_LIMITS]
     resetsAt = rate_limits[ATTR_PUSH_RATE_LIMITS_RESETS_AT]
-    resetsAtTime = (dt_util.parse_datetime(resetsAt) -
-                    datetime.now(timezone.utc))
-    rate_limit_msg = ("mobile_app push notification rate limits for %s: "
-                      "%d sent, %d allowed, %d errors, "
-                      "resets in %s")
-    _LOGGER.log(level, rate_limit_msg,
-                device_name,
-                rate_limits[ATTR_PUSH_RATE_LIMITS_SUCCESSFUL],
-                rate_limits[ATTR_PUSH_RATE_LIMITS_MAXIMUM],
-                rate_limits[ATTR_PUSH_RATE_LIMITS_ERRORS],
-                str(resetsAtTime).split(".")[0])
+    resetsAtTime = dt_util.parse_datetime(resetsAt) - datetime.now(timezone.utc)
+    rate_limit_msg = (
+        "mobile_app push notification rate limits for %s: "
+        "%d sent, %d allowed, %d errors, "
+        "resets in %s"
+    )
+    _LOGGER.log(
+        level,
+        rate_limit_msg,
+        device_name,
+        rate_limits[ATTR_PUSH_RATE_LIMITS_SUCCESSFUL],
+        rate_limits[ATTR_PUSH_RATE_LIMITS_MAXIMUM],
+        rate_limits[ATTR_PUSH_RATE_LIMITS_ERRORS],
+        str(resetsAtTime).split(".")[0],
+    )
 
 
 async def async_get_service(hass, config, discovery_info=None):
@@ -111,7 +129,7 @@ class MobileAppNotificationService(BaseNotificationService):
             if ATTR_OS_VERSION in entry_data:
                 reg_info[ATTR_OS_VERSION] = entry_data[ATTR_OS_VERSION]
 
-            data['registration_info'] = reg_info
+            data["registration_info"] = reg_info
 
             try:
                 with async_timeout.timeout(10):
@@ -119,21 +137,19 @@ class MobileAppNotificationService(BaseNotificationService):
                     result = await response.json()
 
                 if response.status == 201:
-                    log_rate_limits(self.hass,
-                                    entry_data[ATTR_DEVICE_NAME], result)
+                    log_rate_limits(self.hass, entry_data[ATTR_DEVICE_NAME], result)
                     return
 
-                fallback_error = result.get("errorMessage",
-                                            "Unknown error")
-                fallback_message = ("Internal server error, "
-                                    "please try again later: "
-                                    "{}").format(fallback_error)
+                fallback_error = result.get("errorMessage", "Unknown error")
+                fallback_message = (
+                    "Internal server error, " "please try again later: " "{}"
+                ).format(fallback_error)
                 message = result.get("message", fallback_message)
                 if response.status == 429:
                     _LOGGER.warning(message)
-                    log_rate_limits(self.hass,
-                                    entry_data[ATTR_DEVICE_NAME],
-                                    result, logging.WARNING)
+                    log_rate_limits(
+                        self.hass, entry_data[ATTR_DEVICE_NAME], result, logging.WARNING
+                    )
                 else:
                     _LOGGER.error(message)
 
