@@ -6,34 +6,45 @@ from homeassistant.helpers.dispatcher import async_dispatcher_connect
 from homeassistant.util.dt import as_local, parse_datetime
 
 from . import (
-    DATA_OPENUV_CLIENT, DATA_UV, DOMAIN, SENSORS, TOPIC_UPDATE,
-    TYPE_CURRENT_OZONE_LEVEL, TYPE_CURRENT_UV_INDEX, TYPE_CURRENT_UV_LEVEL,
-    TYPE_MAX_UV_INDEX, TYPE_SAFE_EXPOSURE_TIME_1, TYPE_SAFE_EXPOSURE_TIME_2,
-    TYPE_SAFE_EXPOSURE_TIME_3, TYPE_SAFE_EXPOSURE_TIME_4,
-    TYPE_SAFE_EXPOSURE_TIME_5, TYPE_SAFE_EXPOSURE_TIME_6, OpenUvEntity)
+    DATA_OPENUV_CLIENT,
+    DATA_UV,
+    DOMAIN,
+    SENSORS,
+    TOPIC_UPDATE,
+    TYPE_CURRENT_OZONE_LEVEL,
+    TYPE_CURRENT_UV_INDEX,
+    TYPE_CURRENT_UV_LEVEL,
+    TYPE_MAX_UV_INDEX,
+    TYPE_SAFE_EXPOSURE_TIME_1,
+    TYPE_SAFE_EXPOSURE_TIME_2,
+    TYPE_SAFE_EXPOSURE_TIME_3,
+    TYPE_SAFE_EXPOSURE_TIME_4,
+    TYPE_SAFE_EXPOSURE_TIME_5,
+    TYPE_SAFE_EXPOSURE_TIME_6,
+    OpenUvEntity,
+)
 
 _LOGGER = logging.getLogger(__name__)
 
-ATTR_MAX_UV_TIME = 'time'
+ATTR_MAX_UV_TIME = "time"
 
 EXPOSURE_TYPE_MAP = {
-    TYPE_SAFE_EXPOSURE_TIME_1: 'st1',
-    TYPE_SAFE_EXPOSURE_TIME_2: 'st2',
-    TYPE_SAFE_EXPOSURE_TIME_3: 'st3',
-    TYPE_SAFE_EXPOSURE_TIME_4: 'st4',
-    TYPE_SAFE_EXPOSURE_TIME_5: 'st5',
-    TYPE_SAFE_EXPOSURE_TIME_6: 'st6'
+    TYPE_SAFE_EXPOSURE_TIME_1: "st1",
+    TYPE_SAFE_EXPOSURE_TIME_2: "st2",
+    TYPE_SAFE_EXPOSURE_TIME_3: "st3",
+    TYPE_SAFE_EXPOSURE_TIME_4: "st4",
+    TYPE_SAFE_EXPOSURE_TIME_5: "st5",
+    TYPE_SAFE_EXPOSURE_TIME_6: "st6",
 }
 
-UV_LEVEL_EXTREME = 'Extreme'
-UV_LEVEL_VHIGH = 'Very High'
-UV_LEVEL_HIGH = 'High'
-UV_LEVEL_MODERATE = 'Moderate'
-UV_LEVEL_LOW = 'Low'
+UV_LEVEL_EXTREME = "Extreme"
+UV_LEVEL_VHIGH = "Very High"
+UV_LEVEL_HIGH = "High"
+UV_LEVEL_MODERATE = "Moderate"
+UV_LEVEL_LOW = "Low"
 
 
-async def async_setup_platform(
-        hass, config, async_add_entities, discovery_info=None):
+async def async_setup_platform(hass, config, async_add_entities, discovery_info=None):
     """Set up an OpenUV sensor based on existing config."""
     pass
 
@@ -46,8 +57,8 @@ async def async_setup_entry(hass, entry, async_add_entities):
     for sensor_type in openuv.sensor_conditions:
         name, icon, unit = SENSORS[sensor_type]
         sensors.append(
-            OpenUvSensor(
-                openuv, sensor_type, name, icon, unit, entry.entry_id))
+            OpenUvSensor(openuv, sensor_type, name, icon, unit, entry.entry_id)
+        )
 
     async_add_entities(sensors, True)
 
@@ -87,8 +98,7 @@ class OpenUvSensor(OpenUvEntity):
     @property
     def unique_id(self) -> str:
         """Return a unique, HASS-friendly identifier for this entity."""
-        return '{0}_{1}_{2}'.format(
-            self._latitude, self._longitude, self._sensor_type)
+        return "{0}_{1}_{2}".format(self._latitude, self._longitude, self._sensor_type)
 
     @property
     def unit_of_measurement(self):
@@ -97,13 +107,15 @@ class OpenUvSensor(OpenUvEntity):
 
     async def async_added_to_hass(self):
         """Register callbacks."""
+
         @callback
         def update():
             """Update the state."""
             self.async_schedule_update_ha_state(True)
 
         self._async_unsub_dispatcher_connect = async_dispatcher_connect(
-            self.hass, TOPIC_UPDATE, update)
+            self.hass, TOPIC_UPDATE, update
+        )
 
     async def async_will_remove_from_hass(self):
         """Disconnect dispatcher listener when removed."""
@@ -112,32 +124,35 @@ class OpenUvSensor(OpenUvEntity):
 
     async def async_update(self):
         """Update the state."""
-        data = self.openuv.data[DATA_UV]['result']
+        data = self.openuv.data[DATA_UV]["result"]
         if self._sensor_type == TYPE_CURRENT_OZONE_LEVEL:
-            self._state = data['ozone']
+            self._state = data["ozone"]
         elif self._sensor_type == TYPE_CURRENT_UV_INDEX:
-            self._state = data['uv']
+            self._state = data["uv"]
         elif self._sensor_type == TYPE_CURRENT_UV_LEVEL:
-            if data['uv'] >= 11:
+            if data["uv"] >= 11:
                 self._state = UV_LEVEL_EXTREME
-            elif data['uv'] >= 8:
+            elif data["uv"] >= 8:
                 self._state = UV_LEVEL_VHIGH
-            elif data['uv'] >= 6:
+            elif data["uv"] >= 6:
                 self._state = UV_LEVEL_HIGH
-            elif data['uv'] >= 3:
+            elif data["uv"] >= 3:
                 self._state = UV_LEVEL_MODERATE
             else:
                 self._state = UV_LEVEL_LOW
         elif self._sensor_type == TYPE_MAX_UV_INDEX:
-            self._state = data['uv_max']
-            self._attrs.update({
-                ATTR_MAX_UV_TIME: as_local(parse_datetime(data['uv_max_time']))
-            })
-        elif self._sensor_type in (TYPE_SAFE_EXPOSURE_TIME_1,
-                                   TYPE_SAFE_EXPOSURE_TIME_2,
-                                   TYPE_SAFE_EXPOSURE_TIME_3,
-                                   TYPE_SAFE_EXPOSURE_TIME_4,
-                                   TYPE_SAFE_EXPOSURE_TIME_5,
-                                   TYPE_SAFE_EXPOSURE_TIME_6):
-            self._state = data['safe_exposure_time'][EXPOSURE_TYPE_MAP[
-                self._sensor_type]]
+            self._state = data["uv_max"]
+            self._attrs.update(
+                {ATTR_MAX_UV_TIME: as_local(parse_datetime(data["uv_max_time"]))}
+            )
+        elif self._sensor_type in (
+            TYPE_SAFE_EXPOSURE_TIME_1,
+            TYPE_SAFE_EXPOSURE_TIME_2,
+            TYPE_SAFE_EXPOSURE_TIME_3,
+            TYPE_SAFE_EXPOSURE_TIME_4,
+            TYPE_SAFE_EXPOSURE_TIME_5,
+            TYPE_SAFE_EXPOSURE_TIME_6,
+        ):
+            self._state = data["safe_exposure_time"][
+                EXPOSURE_TYPE_MAP[self._sensor_type]
+            ]
