@@ -5,35 +5,44 @@ import voluptuous as vol
 
 from homeassistant.components.switch import PLATFORM_SCHEMA
 from homeassistant.const import (
-    CONF_NAME, CONF_USERNAME, CONF_PASSWORD, CONF_HOST, CONF_PORT, CONF_TOKEN,
-    CONF_SSL, CONF_VERIFY_SSL)
+    CONF_NAME,
+    CONF_USERNAME,
+    CONF_PASSWORD,
+    CONF_HOST,
+    CONF_PORT,
+    CONF_TOKEN,
+    CONF_SSL,
+    CONF_VERIFY_SSL,
+)
 from homeassistant.helpers.entity import Entity
 from homeassistant.util import Throttle
 import homeassistant.helpers.config_validation as cv
 
 _LOGGER = logging.getLogger(__name__)
 
-CONF_SERVER = 'server'
+CONF_SERVER = "server"
 
-DEFAULT_HOST = 'localhost'
-DEFAULT_NAME = 'Plex'
+DEFAULT_HOST = "localhost"
+DEFAULT_NAME = "Plex"
 DEFAULT_PORT = 32400
 DEFAULT_SSL = False
 DEFAULT_VERIFY_SSL = True
 
 MIN_TIME_BETWEEN_UPDATES = timedelta(minutes=1)
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend({
-    vol.Optional(CONF_HOST, default=DEFAULT_HOST): cv.string,
-    vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
-    vol.Optional(CONF_PASSWORD): cv.string,
-    vol.Optional(CONF_TOKEN): cv.string,
-    vol.Optional(CONF_PORT, default=DEFAULT_PORT): cv.port,
-    vol.Optional(CONF_SERVER): cv.string,
-    vol.Optional(CONF_USERNAME): cv.string,
-    vol.Optional(CONF_SSL, default=DEFAULT_SSL): cv.boolean,
-    vol.Optional(CONF_VERIFY_SSL, default=DEFAULT_VERIFY_SSL): cv.boolean,
-})
+PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
+    {
+        vol.Optional(CONF_HOST, default=DEFAULT_HOST): cv.string,
+        vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
+        vol.Optional(CONF_PASSWORD): cv.string,
+        vol.Optional(CONF_TOKEN): cv.string,
+        vol.Optional(CONF_PORT, default=DEFAULT_PORT): cv.port,
+        vol.Optional(CONF_SERVER): cv.string,
+        vol.Optional(CONF_USERNAME): cv.string,
+        vol.Optional(CONF_SSL, default=DEFAULT_SSL): cv.boolean,
+        vol.Optional(CONF_VERIFY_SSL, default=DEFAULT_VERIFY_SSL): cv.boolean,
+    }
+)
 
 
 def setup_platform(hass, config, add_entities, discovery_info=None):
@@ -46,17 +55,32 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
     plex_port = config.get(CONF_PORT)
     plex_token = config.get(CONF_TOKEN)
 
-    plex_url = '{}://{}:{}'.format('https' if config.get(CONF_SSL) else 'http',
-                                   plex_host, plex_port)
+    plex_url = "{}://{}:{}".format(
+        "https" if config.get(CONF_SSL) else "http", plex_host, plex_port
+    )
 
     import plexapi.exceptions
 
     try:
-        add_entities([PlexSensor(
-            name, plex_url, plex_user, plex_password, plex_server,
-            plex_token, config.get(CONF_VERIFY_SSL))], True)
-    except (plexapi.exceptions.BadRequest, plexapi.exceptions.Unauthorized,
-            plexapi.exceptions.NotFound) as error:
+        add_entities(
+            [
+                PlexSensor(
+                    name,
+                    plex_url,
+                    plex_user,
+                    plex_password,
+                    plex_server,
+                    plex_token,
+                    config.get(CONF_VERIFY_SSL),
+                )
+            ],
+            True,
+        )
+    except (
+        plexapi.exceptions.BadRequest,
+        plexapi.exceptions.Unauthorized,
+        plexapi.exceptions.NotFound,
+    ) as error:
         _LOGGER.error(error)
         return
 
@@ -64,8 +88,16 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
 class PlexSensor(Entity):
     """Representation of a Plex now playing sensor."""
 
-    def __init__(self, name, plex_url, plex_user, plex_password,
-                 plex_server, plex_token, verify_ssl):
+    def __init__(
+        self,
+        name,
+        plex_url,
+        plex_user,
+        plex_password,
+        plex_server,
+        plex_token,
+        verify_ssl,
+    ):
         """Initialize the sensor."""
         from plexapi.myplex import MyPlexAccount
         from plexapi.server import PlexServer
@@ -121,7 +153,7 @@ class PlexSensor(Entity):
             now_playing_user = "{0} - {1}".format(user, device)
             now_playing_title = ""
 
-            if sess.TYPE == 'episode':
+            if sess.TYPE == "episode":
                 # example:
                 # "Supernatural (2005) - S01 · E13 - Route 666"
                 season_title = sess.grandparentTitle
@@ -131,18 +163,18 @@ class PlexSensor(Entity):
                 if sess.index is not None:
                     season_episode += " · E{0}".format(sess.index)
                 episode_title = sess.title
-                now_playing_title = "{0} - {1} - {2}".format(season_title,
-                                                             season_episode,
-                                                             episode_title)
-            elif sess.TYPE == 'track':
+                now_playing_title = "{0} - {1} - {2}".format(
+                    season_title, season_episode, episode_title
+                )
+            elif sess.TYPE == "track":
                 # example:
                 # "Billy Talent - Afraid of Heights - Afraid of Heights"
                 track_artist = sess.grandparentTitle
                 track_album = sess.parentTitle
                 track_title = sess.title
-                now_playing_title = "{0} - {1} - {2}".format(track_artist,
-                                                             track_album,
-                                                             track_title)
+                now_playing_title = "{0} - {1} - {2}".format(
+                    track_artist, track_album, track_title
+                )
             else:
                 # example:
                 # "picture_of_last_summer_camp (2015)"
