@@ -7,22 +7,37 @@ from homeassistant.components.switch import SwitchDevice
 from homeassistant.helpers.dispatcher import dispatcher_connect
 
 from . import (
-    CONF_MANUAL_RUN_MINS, DOMAIN as DOMAIN_RACHIO, KEY_DEVICE_ID, KEY_ENABLED,
-    KEY_ID, KEY_NAME, KEY_ON, KEY_SUBTYPE, KEY_SUMMARY, KEY_ZONE_ID,
-    KEY_ZONE_NUMBER, SIGNAL_RACHIO_CONTROLLER_UPDATE,
-    SIGNAL_RACHIO_ZONE_UPDATE, SUBTYPE_SLEEP_MODE_OFF, SUBTYPE_SLEEP_MODE_ON,
-    SUBTYPE_ZONE_COMPLETED, SUBTYPE_ZONE_STARTED, SUBTYPE_ZONE_STOPPED)
+    CONF_MANUAL_RUN_MINS,
+    DOMAIN as DOMAIN_RACHIO,
+    KEY_DEVICE_ID,
+    KEY_ENABLED,
+    KEY_ID,
+    KEY_NAME,
+    KEY_ON,
+    KEY_SUBTYPE,
+    KEY_SUMMARY,
+    KEY_ZONE_ID,
+    KEY_ZONE_NUMBER,
+    SIGNAL_RACHIO_CONTROLLER_UPDATE,
+    SIGNAL_RACHIO_ZONE_UPDATE,
+    SUBTYPE_SLEEP_MODE_OFF,
+    SUBTYPE_SLEEP_MODE_ON,
+    SUBTYPE_ZONE_COMPLETED,
+    SUBTYPE_ZONE_STARTED,
+    SUBTYPE_ZONE_STOPPED,
+)
 
 _LOGGER = logging.getLogger(__name__)
 
-ATTR_ZONE_SUMMARY = 'Summary'
-ATTR_ZONE_NUMBER = 'Zone number'
+ATTR_ZONE_SUMMARY = "Summary"
+ATTR_ZONE_NUMBER = "Zone number"
 
 
 def setup_platform(hass, config, add_entities, discovery_info=None):
     """Set up the Rachio switches."""
-    manual_run_time = timedelta(minutes=hass.data[DOMAIN_RACHIO].config.get(
-        CONF_MANUAL_RUN_MINS))
+    manual_run_time = timedelta(
+        minutes=hass.data[DOMAIN_RACHIO].config.get(CONF_MANUAL_RUN_MINS)
+    )
     _LOGGER.info("Rachio run time is %s", str(manual_run_time))
 
     # Add all zones from all controllers as switches
@@ -89,8 +104,9 @@ class RachioStandbySwitch(RachioSwitch):
 
     def __init__(self, hass, controller):
         """Instantiate a new Rachio standby mode switch."""
-        dispatcher_connect(hass, SIGNAL_RACHIO_CONTROLLER_UPDATE,
-                           self._handle_any_update)
+        dispatcher_connect(
+            hass, SIGNAL_RACHIO_CONTROLLER_UPDATE, self._handle_any_update
+        )
         super().__init__(controller, poll=False)
         self._poll_update(controller.init_data)
 
@@ -112,8 +128,7 @@ class RachioStandbySwitch(RachioSwitch):
     def _poll_update(self, data=None) -> bool:
         """Request the state from the API."""
         if data is None:
-            data = self._controller.rachio.device.get(
-                self._controller.controller_id)[1]
+            data = self._controller.rachio.device.get(self._controller.controller_id)[1]
 
         return not data[KEY_ON]
 
@@ -149,13 +164,11 @@ class RachioZone(RachioSwitch):
         super().__init__(controller)
 
         # Listen for all zone updates
-        dispatcher_connect(hass, SIGNAL_RACHIO_ZONE_UPDATE,
-                           self._handle_update)
+        dispatcher_connect(hass, SIGNAL_RACHIO_ZONE_UPDATE, self._handle_update)
 
     def __str__(self):
         """Display the zone as a string."""
-        return 'Rachio Zone "{}" on {}'.format(self.name,
-                                               str(self._controller))
+        return 'Rachio Zone "{}" on {}'.format(self.name, str(self._controller))
 
     @property
     def zone_id(self) -> str:
@@ -170,8 +183,7 @@ class RachioZone(RachioSwitch):
     @property
     def unique_id(self) -> str:
         """Return a unique id by combinining controller id and zone number."""
-        return "{}-zone-{}".format(self._controller.controller_id,
-                                   self.zone_id)
+        return "{}-zone-{}".format(self._controller.controller_id, self.zone_id)
 
     @property
     def icon(self) -> str:
@@ -186,10 +198,7 @@ class RachioZone(RachioSwitch):
     @property
     def state_attributes(self) -> dict:
         """Return the optional state attributes."""
-        return {
-            ATTR_ZONE_NUMBER: self._zone_number,
-            ATTR_ZONE_SUMMARY: self._summary,
-        }
+        return {ATTR_ZONE_NUMBER: self._zone_number, ATTR_ZONE_SUMMARY: self._summary}
 
     def turn_on(self, **kwargs) -> None:
         """Start watering this zone."""
@@ -197,8 +206,7 @@ class RachioZone(RachioSwitch):
         self.turn_off()
 
         # Start this zone
-        self._controller.rachio.zone.start(self.zone_id,
-                                           self._manual_run_time.seconds)
+        self._controller.rachio.zone.start(self.zone_id, self._manual_run_time.seconds)
         _LOGGER.debug("Watering %s on %s", self.name, self._controller.name)
 
     def turn_off(self, **kwargs) -> None:
@@ -219,8 +227,7 @@ class RachioZone(RachioSwitch):
 
         if args[0][KEY_SUBTYPE] == SUBTYPE_ZONE_STARTED:
             self._state = True
-        elif args[0][KEY_SUBTYPE] in [SUBTYPE_ZONE_STOPPED,
-                                      SUBTYPE_ZONE_COMPLETED]:
+        elif args[0][KEY_SUBTYPE] in [SUBTYPE_ZONE_STOPPED, SUBTYPE_ZONE_COMPLETED]:
             self._state = False
 
         self.schedule_update_ha_state()
