@@ -6,25 +6,33 @@ import voluptuous as vol
 
 from homeassistant.components.switch import PLATFORM_SCHEMA, SwitchDevice
 from homeassistant.const import (
-    CONF_FRIENDLY_NAME, CONF_SCAN_INTERVAL, CONF_SWITCHES, CONF_TRIGGER_TIME,
-    CONF_ZONE)
+    CONF_FRIENDLY_NAME,
+    CONF_SCAN_INTERVAL,
+    CONF_SWITCHES,
+    CONF_TRIGGER_TIME,
+    CONF_ZONE,
+)
 from homeassistant.helpers import config_validation as cv
 
 from . import DATA_RAINBIRD
 
-DOMAIN = 'rainbird'
+DOMAIN = "rainbird"
 _LOGGER = logging.getLogger(__name__)
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend({
-    vol.Required(CONF_SWITCHES, default={}): vol.Schema({
-        cv.string: {
-            vol.Optional(CONF_FRIENDLY_NAME): cv.string,
-            vol.Required(CONF_ZONE): cv.string,
-            vol.Required(CONF_TRIGGER_TIME): cv.string,
-            vol.Optional(CONF_SCAN_INTERVAL): cv.string,
-        },
-    }),
-})
+PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
+    {
+        vol.Required(CONF_SWITCHES, default={}): vol.Schema(
+            {
+                cv.string: {
+                    vol.Optional(CONF_FRIENDLY_NAME): cv.string,
+                    vol.Required(CONF_ZONE): cv.string,
+                    vol.Required(CONF_TRIGGER_TIME): cv.string,
+                    vol.Optional(CONF_SCAN_INTERVAL): cv.string,
+                }
+            }
+        )
+    }
+)
 
 
 def setup_platform(hass, config, add_entities, discovery_info=None):
@@ -45,14 +53,10 @@ class RainBirdSwitch(SwitchDevice):
         self._rainbird = rb
         self._devid = dev_id
         self._zone = int(dev.get(CONF_ZONE))
-        self._name = dev.get(CONF_FRIENDLY_NAME,
-                             "Sprinkler {}".format(self._zone))
+        self._name = dev.get(CONF_FRIENDLY_NAME, "Sprinkler {}".format(self._zone))
         self._state = None
         self._duration = dev.get(CONF_TRIGGER_TIME)
-        self._attributes = {
-            "duration": self._duration,
-            "zone": self._zone
-        }
+        self._attributes = {"duration": self._duration, "zone": self._zone}
 
     @property
     def device_state_attributes(self):
