@@ -6,43 +6,63 @@ import socket
 
 import voluptuous as vol
 
-from homeassistant.components.media_player import (
-    MediaPlayerDevice, PLATFORM_SCHEMA)
+from homeassistant.components.media_player import MediaPlayerDevice, PLATFORM_SCHEMA
 from homeassistant.components.media_player.const import (
-    MEDIA_TYPE_CHANNEL, SUPPORT_NEXT_TRACK, SUPPORT_PAUSE,
-    SUPPORT_PLAY, SUPPORT_PLAY_MEDIA, SUPPORT_PREVIOUS_TRACK,
-    SUPPORT_SELECT_SOURCE, SUPPORT_TURN_OFF, SUPPORT_TURN_ON,
-    SUPPORT_VOLUME_MUTE, SUPPORT_VOLUME_STEP)
+    MEDIA_TYPE_CHANNEL,
+    SUPPORT_NEXT_TRACK,
+    SUPPORT_PAUSE,
+    SUPPORT_PLAY,
+    SUPPORT_PLAY_MEDIA,
+    SUPPORT_PREVIOUS_TRACK,
+    SUPPORT_SELECT_SOURCE,
+    SUPPORT_TURN_OFF,
+    SUPPORT_TURN_ON,
+    SUPPORT_VOLUME_MUTE,
+    SUPPORT_VOLUME_STEP,
+)
 from homeassistant.const import (
-    CONF_HOST, CONF_MAC, CONF_NAME, CONF_PORT, CONF_TIMEOUT, STATE_OFF,
-    STATE_ON)
+    CONF_HOST,
+    CONF_MAC,
+    CONF_NAME,
+    CONF_PORT,
+    CONF_TIMEOUT,
+    STATE_OFF,
+    STATE_ON,
+)
 import homeassistant.helpers.config_validation as cv
 from homeassistant.util import dt as dt_util
 
 _LOGGER = logging.getLogger(__name__)
 
-DEFAULT_NAME = 'Samsung TV Remote'
+DEFAULT_NAME = "Samsung TV Remote"
 DEFAULT_PORT = 55000
 DEFAULT_TIMEOUT = 1
 
 KEY_PRESS_TIMEOUT = 1.2
-KNOWN_DEVICES_KEY = 'samsungtv_known_devices'
-SOURCES = {
-    'TV': 'KEY_DTV',
-    'HDMI': 'KEY_HDMI'
-}
+KNOWN_DEVICES_KEY = "samsungtv_known_devices"
+SOURCES = {"TV": "KEY_TV", "HDMI": "KEY_HDMI"}
 
-SUPPORT_SAMSUNGTV = SUPPORT_PAUSE | SUPPORT_VOLUME_STEP | \
-    SUPPORT_VOLUME_MUTE | SUPPORT_PREVIOUS_TRACK | SUPPORT_SELECT_SOURCE | \
-    SUPPORT_NEXT_TRACK | SUPPORT_TURN_OFF | SUPPORT_PLAY | SUPPORT_PLAY_MEDIA
+SUPPORT_SAMSUNGTV = (
+    SUPPORT_PAUSE
+    | SUPPORT_VOLUME_STEP
+    | SUPPORT_VOLUME_MUTE
+    | SUPPORT_PREVIOUS_TRACK
+    | SUPPORT_SELECT_SOURCE
+    | SUPPORT_NEXT_TRACK
+    | SUPPORT_TURN_OFF
+    | SUPPORT_PLAY
+    | SUPPORT_PLAY_MEDIA
+)
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend({
-    vol.Required(CONF_HOST): cv.string,
-    vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
-    vol.Optional(CONF_PORT, default=DEFAULT_PORT): cv.port,
-    vol.Optional(CONF_MAC): cv.string,
-    vol.Optional(CONF_TIMEOUT, default=DEFAULT_TIMEOUT): cv.positive_int,
-})
+PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
+    {
+        vol.Required(CONF_HOST): cv.string,
+        vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
+        vol.Optional(CONF_PORT, default=DEFAULT_PORT): cv.port,
+        vol.Optional(CONF_MAC): cv.string,
+        vol.Optional(CONF_TIMEOUT, default=DEFAULT_TIMEOUT): cv.positive_int,
+    }
+)
 
 
 def setup_platform(hass, config, add_entities, discovery_info=None):
@@ -61,16 +81,16 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
         mac = config.get(CONF_MAC)
         timeout = config.get(CONF_TIMEOUT)
     elif discovery_info is not None:
-        tv_name = discovery_info.get('name')
-        model = discovery_info.get('model_name')
-        host = discovery_info.get('host')
+        tv_name = discovery_info.get("name")
+        model = discovery_info.get("model_name")
+        host = discovery_info.get("host")
         name = "{} ({})".format(tv_name, model)
         port = DEFAULT_PORT
         timeout = DEFAULT_TIMEOUT
         mac = None
-        udn = discovery_info.get('udn')
-        if udn and udn.startswith('uuid:'):
-            uuid = udn[len('uuid:'):]
+        udn = discovery_info.get("udn")
+        if udn and udn.startswith("uuid:"):
+            uuid = udn[len("uuid:") :]
     else:
         _LOGGER.warning("Cannot determine device")
         return
@@ -94,6 +114,7 @@ class SamsungTVDevice(MediaPlayerDevice):
         from samsungctl import exceptions
         from samsungctl import Remote
         import wakeonlan
+
         # Save a reference to the imported classes
         self._exceptions_class = exceptions
         self._remote_class = Remote
@@ -112,18 +133,18 @@ class SamsungTVDevice(MediaPlayerDevice):
         self._end_of_power_off = None
         # Generate a configuration for the Samsung library
         self._config = {
-            'name': 'HomeAssistant',
-            'description': name,
-            'id': 'ha.component.samsung',
-            'port': port,
-            'host': host,
-            'timeout': timeout,
+            "name": "HomeAssistant",
+            "description": name,
+            "id": "ha.component.samsung",
+            "port": port,
+            "host": host,
+            "timeout": timeout,
         }
 
-        if self._config['port'] in (8001, 8002):
-            self._config['method'] = 'websocket'
+        if self._config["port"] in (8001, 8002):
+            self._config["method"] = "websocket"
         else:
-            self._config['method'] = 'legacy'
+            self._config["method"] = "legacy"
 
     def update(self):
         """Update state of device."""
@@ -139,8 +160,7 @@ class SamsungTVDevice(MediaPlayerDevice):
 
     def send_key(self, key):
         """Send a key to the tv and handles exceptions."""
-        if self._power_off_in_progress() \
-                and key not in ('KEY_POWER', 'KEY_POWEROFF'):
+        if self._power_off_in_progress() and key not in ("KEY_POWER", "KEY_POWEROFF"):
             _LOGGER.info("TV is powering off, not sending command: %s", key)
             return
         try:
@@ -150,13 +170,14 @@ class SamsungTVDevice(MediaPlayerDevice):
                 try:
                     self.get_remote().control(key)
                     break
-                except (self._exceptions_class.ConnectionClosed,
-                        BrokenPipeError):
+                except (self._exceptions_class.ConnectionClosed, BrokenPipeError):
                     # BrokenPipe can occur when the commands is sent to fast
                     self._remote = None
             self._state = STATE_ON
-        except (self._exceptions_class.UnhandledResponse,
-                self._exceptions_class.AccessDenied):
+        except (
+            self._exceptions_class.UnhandledResponse,
+            self._exceptions_class.AccessDenied,
+        ):
             # We got a response so it's on.
             self._state = STATE_ON
             self._remote = None
@@ -169,8 +190,10 @@ class SamsungTVDevice(MediaPlayerDevice):
             self._state = STATE_OFF
 
     def _power_off_in_progress(self):
-        return self._end_of_power_off is not None and \
-               self._end_of_power_off > dt_util.utcnow()
+        return (
+            self._end_of_power_off is not None
+            and self._end_of_power_off > dt_util.utcnow()
+        )
 
     @property
     def unique_id(self) -> str:
@@ -208,10 +231,10 @@ class SamsungTVDevice(MediaPlayerDevice):
         """Turn off media player."""
         self._end_of_power_off = dt_util.utcnow() + timedelta(seconds=15)
 
-        if self._config['method'] == 'websocket':
-            self.send_key('KEY_POWER')
+        if self._config["method"] == "websocket":
+            self.send_key("KEY_POWER")
         else:
-            self.send_key('KEY_POWEROFF')
+            self.send_key("KEY_POWEROFF")
         # Force closing of remote session to provide instant UI feedback
         try:
             self.get_remote().close()
@@ -221,15 +244,15 @@ class SamsungTVDevice(MediaPlayerDevice):
 
     def volume_up(self):
         """Volume up the media player."""
-        self.send_key('KEY_VOLUP')
+        self.send_key("KEY_VOLUP")
 
     def volume_down(self):
         """Volume down media player."""
-        self.send_key('KEY_VOLDOWN')
+        self.send_key("KEY_VOLDOWN")
 
     def mute_volume(self, mute):
         """Send mute command."""
-        self.send_key('KEY_MUTE')
+        self.send_key("KEY_MUTE")
 
     def media_play_pause(self):
         """Simulate play pause media player."""
@@ -241,50 +264,50 @@ class SamsungTVDevice(MediaPlayerDevice):
     def media_play(self):
         """Send play command."""
         self._playing = True
-        self.send_key('KEY_PLAY')
+        self.send_key("KEY_PLAY")
 
     def media_pause(self):
         """Send media pause command to media player."""
         self._playing = False
-        self.send_key('KEY_PAUSE')
+        self.send_key("KEY_PAUSE")
 
     def media_next_track(self):
         """Send next track command."""
-        self.send_key('KEY_FF')
+        self.send_key("KEY_FF")
 
     def media_previous_track(self):
         """Send the previous track command."""
-        self.send_key('KEY_REWIND')
+        self.send_key("KEY_REWIND")
 
     async def async_play_media(self, media_type, media_id, **kwargs):
         """Support changing a channel."""
         if media_type != MEDIA_TYPE_CHANNEL:
-            _LOGGER.error('Unsupported media type')
+            _LOGGER.error("Unsupported media type")
             return
 
         # media_id should only be a channel number
         try:
             cv.positive_int(media_id)
         except vol.Invalid:
-            _LOGGER.error('Media ID must be positive integer')
+            _LOGGER.error("Media ID must be positive integer")
             return
 
         for digit in media_id:
-            await self.hass.async_add_job(self.send_key, 'KEY_' + digit)
+            await self.hass.async_add_job(self.send_key, "KEY_" + digit)
             await asyncio.sleep(KEY_PRESS_TIMEOUT, self.hass.loop)
-        await self.hass.async_add_job(self.send_key, 'KEY_ENTER')
+        await self.hass.async_add_job(self.send_key, "KEY_ENTER")
 
     def turn_on(self):
         """Turn the media player on."""
         if self._mac:
             self._wol.send_magic_packet(self._mac)
         else:
-            self.send_key('KEY_POWERON')
+            self.send_key("KEY_POWERON")
 
     async def async_select_source(self, source):
         """Select input source."""
         if source not in SOURCES:
-            _LOGGER.error('Unsupported source')
+            _LOGGER.error("Unsupported source")
             return
 
         await self.hass.async_add_job(self.send_key, SOURCES[source])
