@@ -5,15 +5,16 @@ import logging
 
 import voluptuous as vol
 
-from homeassistant.const import ATTR_ENTITY_ID, CONF_PLATFORM, SERVICE_TURN_ON
-import homeassistant.helpers.config_validation as cv
+from homeassistant.core import DOMAIN as HA_DOMAIN
+from homeassistant.const import CONF_PLATFORM, SERVICE_TURN_ON
+from homeassistant.helpers.config_validation import ENTITY_SERVICE_SCHEMA
 from homeassistant.helpers.entity import Entity
 from homeassistant.helpers.entity_component import EntityComponent
 from homeassistant.helpers.state import HASS_DOMAIN
 
-DOMAIN = 'scene'
-STATE = 'scening'
-STATES = 'states'
+DOMAIN = "scene"
+STATE = "scening"
+STATES = "states"
 
 
 def _hass_domain_validator(config):
@@ -27,17 +28,18 @@ def _hass_domain_validator(config):
 def _platform_validator(config):
     """Validate it is a valid  platform."""
     try:
-        platform = importlib.import_module('.{}'.format(config[CONF_PLATFORM]),
-                                           __name__)
+        platform = importlib.import_module(
+            ".{}".format(config[CONF_PLATFORM]), __name__
+        )
     except ImportError:
         try:
             platform = importlib.import_module(
-                'homeassistant.components.{}.scene'.format(
-                    config[CONF_PLATFORM]))
+                "homeassistant.components.{}.scene".format(config[CONF_PLATFORM])
+            )
         except ImportError:
-            raise vol.Invalid('Invalid platform specified') from None
+            raise vol.Invalid("Invalid platform specified") from None
 
-    if not hasattr(platform, 'PLATFORM_SCHEMA'):
+    if not hasattr(platform, "PLATFORM_SCHEMA"):
         return config
 
     return platform.PLATFORM_SCHEMA(config)
@@ -46,15 +48,11 @@ def _platform_validator(config):
 PLATFORM_SCHEMA = vol.Schema(
     vol.All(
         _hass_domain_validator,
-        vol.Schema({
-            vol.Required(CONF_PLATFORM): str
-        }, extra=vol.ALLOW_EXTRA),
-        _platform_validator
-    ), extra=vol.ALLOW_EXTRA)
-
-SCENE_SERVICE_SCHEMA = vol.Schema({
-    vol.Required(ATTR_ENTITY_ID): cv.entity_ids,
-})
+        vol.Schema({vol.Required(CONF_PLATFORM): str}, extra=vol.ALLOW_EXTRA),
+        _platform_validator,
+    ),
+    extra=vol.ALLOW_EXTRA,
+)
 
 
 async def async_setup(hass, config):
@@ -63,6 +61,10 @@ async def async_setup(hass, config):
     component = hass.data[DOMAIN] = EntityComponent(logger, DOMAIN, hass)
 
     await component.async_setup(config)
+    # Ensure Home Assistant platform always loaded.
+    await component.async_setup_platform(
+        HA_DOMAIN, {"platform": "homeasistant", STATES: []}
+    )
 
     async def async_handle_scene_service(service):
         """Handle calls to the switch services."""
@@ -73,8 +75,11 @@ async def async_setup(hass, config):
             await asyncio.wait(tasks)
 
     hass.services.async_register(
-        DOMAIN, SERVICE_TURN_ON, async_handle_scene_service,
-        schema=SCENE_SERVICE_SCHEMA)
+        DOMAIN,
+        SERVICE_TURN_ON,
+        async_handle_scene_service,
+        schema=ENTITY_SERVICE_SCHEMA,
+    )
 
     return True
 
