@@ -13,36 +13,37 @@ import homeassistant.util.dt as dt_util
 
 _LOGGER = logging.getLogger(__name__)
 
-ATTR_DEPARTURE_TIME1 = 'next_departure'
-ATTR_DEPARTURE_TIME2 = 'next_on_departure'
-ATTR_DURATION = 'duration'
-ATTR_PLATFORM = 'platform'
-ATTR_REMAINING_TIME = 'remaining_time'
-ATTR_START = 'start'
-ATTR_TARGET = 'destination'
-ATTR_TRAIN_NUMBER = 'train_number'
-ATTR_TRANSFERS = 'transfers'
+ATTR_DEPARTURE_TIME1 = "next_departure"
+ATTR_DEPARTURE_TIME2 = "next_on_departure"
+ATTR_DURATION = "duration"
+ATTR_PLATFORM = "platform"
+ATTR_REMAINING_TIME = "remaining_time"
+ATTR_START = "start"
+ATTR_TARGET = "destination"
+ATTR_TRAIN_NUMBER = "train_number"
+ATTR_TRANSFERS = "transfers"
 
 ATTRIBUTION = "Data provided by transport.opendata.ch"
 
-CONF_DESTINATION = 'to'
-CONF_START = 'from'
+CONF_DESTINATION = "to"
+CONF_START = "from"
 
-DEFAULT_NAME = 'Next Departure'
+DEFAULT_NAME = "Next Departure"
 
-ICON = 'mdi:bus'
+ICON = "mdi:bus"
 
 SCAN_INTERVAL = timedelta(seconds=90)
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend({
-    vol.Required(CONF_DESTINATION): cv.string,
-    vol.Required(CONF_START): cv.string,
-    vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
-})
+PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
+    {
+        vol.Required(CONF_DESTINATION): cv.string,
+        vol.Required(CONF_START): cv.string,
+        vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
+    }
+)
 
 
-async def async_setup_platform(
-        hass, config, async_add_entities, discovery_info=None):
+async def async_setup_platform(hass, config, async_add_entities, discovery_info=None):
     """Set up the Swiss public transport sensor."""
     from opendata_transport import OpendataTransport, exceptions
 
@@ -58,11 +59,11 @@ async def async_setup_platform(
     except exceptions.OpendataTransportError:
         _LOGGER.error(
             "Check at http://transport.opendata.ch/examples/stationboard.html "
-            "if your station names are valid")
+            "if your station names are valid"
+        )
         return
 
-    async_add_entities(
-        [SwissPublicTransportSensor(opendata, start, destination, name)])
+    async_add_entities([SwissPublicTransportSensor(opendata, start, destination, name)])
 
 
 class SwissPublicTransportSensor(Entity):
@@ -84,8 +85,11 @@ class SwissPublicTransportSensor(Entity):
     @property
     def state(self):
         """Return the state of the sensor."""
-        return self._opendata.connections[0]['departure'] \
-            if self._opendata is not None else None
+        return (
+            self._opendata.connections[0]["departure"]
+            if self._opendata is not None
+            else None
+        )
 
     @property
     def device_state_attributes(self):
@@ -94,19 +98,19 @@ class SwissPublicTransportSensor(Entity):
             return
 
         self._remaining_time = dt_util.parse_datetime(
-            self._opendata.connections[0]['departure']) -\
-            dt_util.as_local(dt_util.utcnow())
+            self._opendata.connections[0]["departure"]
+        ) - dt_util.as_local(dt_util.utcnow())
 
         attr = {
-            ATTR_TRAIN_NUMBER: self._opendata.connections[0]['number'],
-            ATTR_PLATFORM: self._opendata.connections[0]['platform'],
-            ATTR_TRANSFERS: self._opendata.connections[0]['transfers'],
-            ATTR_DURATION: self._opendata.connections[0]['duration'],
-            ATTR_DEPARTURE_TIME1: self._opendata.connections[1]['departure'],
-            ATTR_DEPARTURE_TIME2: self._opendata.connections[2]['departure'],
+            ATTR_TRAIN_NUMBER: self._opendata.connections[0]["number"],
+            ATTR_PLATFORM: self._opendata.connections[0]["platform"],
+            ATTR_TRANSFERS: self._opendata.connections[0]["transfers"],
+            ATTR_DURATION: self._opendata.connections[0]["duration"],
+            ATTR_DEPARTURE_TIME1: self._opendata.connections[1]["departure"],
+            ATTR_DEPARTURE_TIME2: self._opendata.connections[2]["departure"],
             ATTR_START: self._opendata.from_name,
             ATTR_TARGET: self._opendata.to_name,
-            ATTR_REMAINING_TIME: '{}'.format(self._remaining_time),
+            ATTR_REMAINING_TIME: "{}".format(self._remaining_time),
             ATTR_ATTRIBUTION: ATTRIBUTION,
         }
         return attr
