@@ -3,44 +3,49 @@ import logging
 
 from homeassistant.components.climate import ClimateDevice
 from homeassistant.components.climate.const import (
-    CURRENT_HVAC_COOL, CURRENT_HVAC_HEAT, FAN_HIGH, FAN_LOW, FAN_MIDDLE,
-    FAN_OFF, HVAC_MODE_AUTO, HVAC_MODE_HEAT, HVAC_MODE_OFF, PRESET_AWAY,
-    SUPPORT_PRESET_MODE, SUPPORT_TARGET_TEMPERATURE)
-from homeassistant.const import (
-    ATTR_TEMPERATURE, PRECISION_TENTHS, TEMP_CELSIUS)
+    CURRENT_HVAC_COOL,
+    CURRENT_HVAC_HEAT,
+    FAN_HIGH,
+    FAN_LOW,
+    FAN_MIDDLE,
+    FAN_OFF,
+    HVAC_MODE_AUTO,
+    HVAC_MODE_HEAT,
+    HVAC_MODE_OFF,
+    PRESET_AWAY,
+    SUPPORT_PRESET_MODE,
+    SUPPORT_TARGET_TEMPERATURE,
+)
+from homeassistant.const import ATTR_TEMPERATURE, PRECISION_TENTHS, TEMP_CELSIUS
 from homeassistant.util.temperature import convert as convert_temperature
 
 from . import DATA_TADO
 
 _LOGGER = logging.getLogger(__name__)
 
-CONST_MODE_SMART_SCHEDULE = 'SMART_SCHEDULE'  # Default mytado mode
-CONST_MODE_OFF = 'OFF'  # Switch off heating in a zone
+CONST_MODE_SMART_SCHEDULE = "SMART_SCHEDULE"  # Default mytado mode
+CONST_MODE_OFF = "OFF"  # Switch off heating in a zone
 
 # When we change the temperature setting, we need an overlay mode
 # wait until tado changes the mode automatic
-CONST_OVERLAY_TADO_MODE = 'TADO_MODE'
+CONST_OVERLAY_TADO_MODE = "TADO_MODE"
 # the user has change the temperature or mode manually
-CONST_OVERLAY_MANUAL = 'MANUAL'
+CONST_OVERLAY_MANUAL = "MANUAL"
 # the temperature will be reset after a timespan
-CONST_OVERLAY_TIMER = 'TIMER'
+CONST_OVERLAY_TIMER = "TIMER"
 
-CONST_MODE_FAN_HIGH = 'HIGH'
-CONST_MODE_FAN_MIDDLE = 'MIDDLE'
-CONST_MODE_FAN_LOW = 'LOW'
+CONST_MODE_FAN_HIGH = "HIGH"
+CONST_MODE_FAN_MIDDLE = "MIDDLE"
+CONST_MODE_FAN_LOW = "LOW"
 
-FAN_MAP_TADO = {
-    'HIGH': FAN_HIGH,
-    'MIDDLE': FAN_MIDDLE,
-    'LOW': FAN_LOW,
-}
+FAN_MAP_TADO = {"HIGH": FAN_HIGH, "MIDDLE": FAN_MIDDLE, "LOW": FAN_LOW}
 
 HVAC_MAP_TADO = {
-    'MANUAL': HVAC_MODE_HEAT,
-    'TIMER': HVAC_MODE_AUTO,
-    'TADO_MODE': HVAC_MODE_AUTO,
-    'SMART_SCHEDULE': HVAC_MODE_AUTO,
-    'OFF': HVAC_MODE_OFF
+    "MANUAL": HVAC_MODE_HEAT,
+    "TIMER": HVAC_MODE_AUTO,
+    "TADO_MODE": HVAC_MODE_AUTO,
+    "SMART_SCHEDULE": HVAC_MODE_AUTO,
+    "OFF": HVAC_MODE_OFF,
 }
 
 SUPPORT_FLAGS = SUPPORT_TARGET_TEMPERATURE | SUPPORT_PRESET_MODE
@@ -61,8 +66,7 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
 
     climate_devices = []
     for zone in zones:
-        device = create_climate_device(
-            tado, hass, zone, zone['name'], zone['id'])
+        device = create_climate_device(tado, hass, zone, zone["name"], zone["id"])
         if not device:
             continue
         climate_devices.append(device)
@@ -76,34 +80,35 @@ def create_climate_device(tado, hass, zone, name, zone_id):
     capabilities = tado.get_capabilities(zone_id)
 
     unit = TEMP_CELSIUS
-    ac_mode = capabilities['type'] == 'AIR_CONDITIONING'
+    ac_mode = capabilities["type"] == "AIR_CONDITIONING"
 
     if ac_mode:
-        temperatures = capabilities['HEAT']['temperatures']
-    elif 'temperatures' in capabilities:
-        temperatures = capabilities['temperatures']
+        temperatures = capabilities["HEAT"]["temperatures"]
+    elif "temperatures" in capabilities:
+        temperatures = capabilities["temperatures"]
     else:
         _LOGGER.debug("Received zone %s has no temperature; not adding", name)
         return
 
-    min_temp = float(temperatures['celsius']['min'])
-    max_temp = float(temperatures['celsius']['max'])
-    step = temperatures['celsius'].get('step', PRECISION_TENTHS)
+    min_temp = float(temperatures["celsius"]["min"])
+    max_temp = float(temperatures["celsius"]["max"])
+    step = temperatures["celsius"].get("step", PRECISION_TENTHS)
 
-    data_id = 'zone {} {}'.format(name, zone_id)
-    device = TadoClimate(tado,
-                         name, zone_id, data_id,
-                         hass.config.units.temperature(min_temp, unit),
-                         hass.config.units.temperature(max_temp, unit),
-                         step,
-                         ac_mode)
+    data_id = "zone {} {}".format(name, zone_id)
+    device = TadoClimate(
+        tado,
+        name,
+        zone_id,
+        data_id,
+        hass.config.units.temperature(min_temp, unit),
+        hass.config.units.temperature(max_temp, unit),
+        step,
+        ac_mode,
+    )
 
-    tado.add_sensor(data_id, {
-        'id': zone_id,
-        'zone': zone,
-        'name': name,
-        'climate': device
-    })
+    tado.add_sensor(
+        data_id, {"id": zone_id, "zone": zone, "name": name, "climate": device}
+    )
 
     return device
 
@@ -111,9 +116,18 @@ def create_climate_device(tado, hass, zone, name, zone_id):
 class TadoClimate(ClimateDevice):
     """Representation of a tado climate device."""
 
-    def __init__(self, store, zone_name, zone_id, data_id,
-                 min_temp, max_temp, step, ac_mode,
-                 tolerance=0.3):
+    def __init__(
+        self,
+        store,
+        zone_name,
+        zone_id,
+        data_id,
+        min_temp,
+        max_temp,
+        step,
+        ac_mode,
+        tolerance=0.3,
+    ):
         """Initialize of Tado climate device."""
         self._store = store
         self._data_id = data_id
@@ -261,14 +275,16 @@ class TadoClimate(ClimateDevice):
     @property
     def min_temp(self):
         """Return the minimum temperature."""
-        return convert_temperature(self._min_temp, self._unit,
-                                   self.hass.config.units.temperature_unit)
+        return convert_temperature(
+            self._min_temp, self._unit, self.hass.config.units.temperature_unit
+        )
 
     @property
     def max_temp(self):
         """Return the maximum temperature."""
-        return convert_temperature(self._max_temp, self._unit,
-                                   self.hass.config.units.temperature_unit)
+        return convert_temperature(
+            self._max_temp, self._unit, self.hass.config.units.temperature_unit
+        )
 
     def update(self):
         """Update the state of this climate device."""
@@ -280,37 +296,34 @@ class TadoClimate(ClimateDevice):
             _LOGGER.debug("Received no data for zone %s", self.zone_name)
             return
 
-        if 'sensorDataPoints' in data:
-            sensor_data = data['sensorDataPoints']
+        if "sensorDataPoints" in data:
+            sensor_data = data["sensorDataPoints"]
 
             unit = TEMP_CELSIUS
 
-            if 'insideTemperature' in sensor_data:
-                temperature = float(
-                    sensor_data['insideTemperature']['celsius'])
-                self._cur_temp = self.hass.config.units.temperature(
-                    temperature, unit)
+            if "insideTemperature" in sensor_data:
+                temperature = float(sensor_data["insideTemperature"]["celsius"])
+                self._cur_temp = self.hass.config.units.temperature(temperature, unit)
 
-            if 'humidity' in sensor_data:
-                humidity = float(
-                    sensor_data['humidity']['percentage'])
+            if "humidity" in sensor_data:
+                humidity = float(sensor_data["humidity"]["percentage"])
                 self._cur_humidity = humidity
 
             # temperature setting will not exist when device is off
-            if 'temperature' in data['setting'] and \
-                    data['setting']['temperature'] is not None:
-                setting = float(
-                    data['setting']['temperature']['celsius'])
-                self._target_temp = self.hass.config.units.temperature(
-                    setting, unit)
+            if (
+                "temperature" in data["setting"]
+                and data["setting"]["temperature"] is not None
+            ):
+                setting = float(data["setting"]["temperature"]["celsius"])
+                self._target_temp = self.hass.config.units.temperature(setting, unit)
 
-        if 'tadoMode' in data:
-            mode = data['tadoMode']
-            self._is_away = mode == 'AWAY'
+        if "tadoMode" in data:
+            mode = data["tadoMode"]
+            self._is_away = mode == "AWAY"
 
-        if 'setting' in data:
-            power = data['setting']['power']
-            if power == 'OFF':
+        if "setting" in data:
+            power = data["setting"]["power"]
+            if power == "OFF":
                 self._current_operation = CONST_MODE_OFF
                 self._current_fan = CONST_MODE_OFF
                 # There is no overlay, the mode will always be
@@ -326,23 +339,23 @@ class TadoClimate(ClimateDevice):
         cooling = False
         fan_speed = CONST_MODE_OFF
 
-        if 'overlay' in data:
-            overlay_data = data['overlay']
+        if "overlay" in data:
+            overlay_data = data["overlay"]
             overlay = overlay_data is not None
 
         if overlay:
-            termination = overlay_data['termination']['type']
+            termination = overlay_data["termination"]["type"]
 
-            if 'setting' in overlay_data:
-                setting_data = overlay_data['setting']
+            if "setting" in overlay_data:
+                setting_data = overlay_data["setting"]
                 setting = setting_data is not None
 
             if setting:
-                if 'mode' in setting_data:
-                    cooling = setting_data['mode'] == 'COOL'
+                if "mode" in setting_data:
+                    cooling = setting_data["mode"] == "COOL"
 
-                if 'fanSpeed' in setting_data:
-                    fan_speed = setting_data['fanSpeed']
+                if "fanSpeed" in setting_data:
+                    fan_speed = setting_data["fanSpeed"]
 
         if self._device_is_active:
             # If you set mode manually to off, there will be an overlay
@@ -355,29 +368,34 @@ class TadoClimate(ClimateDevice):
 
     def _control_heating(self):
         """Send new target temperature to mytado."""
-        if not self._active and None not in (
-                self._cur_temp, self._target_temp):
+        if not self._active and None not in (self._cur_temp, self._target_temp):
             self._active = True
-            _LOGGER.info("Obtained current and target temperature. "
-                         "Tado thermostat active")
+            _LOGGER.info(
+                "Obtained current and target temperature. " "Tado thermostat active"
+            )
 
         if self._current_operation == CONST_MODE_SMART_SCHEDULE:
-            _LOGGER.info("Switching mytado.com to SCHEDULE (default) "
-                         "for zone %s", self.zone_name)
+            _LOGGER.info(
+                "Switching mytado.com to SCHEDULE (default) " "for zone %s",
+                self.zone_name,
+            )
             self._store.reset_zone_overlay(self.zone_id)
             self._overlay_mode = self._current_operation
             return
 
         if self._current_operation == CONST_MODE_OFF:
-            _LOGGER.info("Switching mytado.com to OFF for zone %s",
-                         self.zone_name)
+            _LOGGER.info("Switching mytado.com to OFF for zone %s", self.zone_name)
             self._store.set_zone_off(self.zone_id, CONST_OVERLAY_MANUAL)
             self._overlay_mode = self._current_operation
             return
 
-        _LOGGER.info("Switching mytado.com to %s mode for zone %s",
-                     self._current_operation, self.zone_name)
+        _LOGGER.info(
+            "Switching mytado.com to %s mode for zone %s",
+            self._current_operation,
+            self.zone_name,
+        )
         self._store.set_zone_overlay(
-            self.zone_id, self._current_operation, self._target_temp)
+            self.zone_id, self._current_operation, self._target_temp
+        )
 
         self._overlay_mode = self._current_operation
