@@ -6,24 +6,25 @@ import requests
 import voluptuous as vol
 
 from homeassistant.components.sensor import PLATFORM_SCHEMA
-from homeassistant.const import (
-    CONF_HOST, CONF_NAME, CONF_PORT, POWER_WATT)
+from homeassistant.const import CONF_HOST, CONF_NAME, CONF_PORT, POWER_WATT
 from homeassistant.helpers import config_validation as cv
 from homeassistant.helpers.entity import Entity
 from homeassistant.util import Throttle
 
 _LOGGER = logging.getLogger(__name__)
 
-DEFAULT_NAME = 'ted'
+DEFAULT_NAME = "ted"
 
 MIN_TIME_BETWEEN_UPDATES = timedelta(seconds=10)
 
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend({
-    vol.Required(CONF_HOST): cv.string,
-    vol.Optional(CONF_PORT, default=80): cv.port,
-    vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
-})
+PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
+    {
+        vol.Required(CONF_HOST): cv.string,
+        vol.Optional(CONF_PORT, default=80): cv.port,
+        vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
+    }
+)
 
 
 def setup_platform(hass, config, add_entities, discovery_info=None):
@@ -31,7 +32,7 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
     host = config.get(CONF_HOST)
     port = config.get(CONF_PORT)
     name = config.get(CONF_NAME)
-    url = 'http://{}:{}/api/LiveData.xml'.format(host, port)
+    url = "http://{}:{}/api/LiveData.xml".format(host, port)
 
     gateway = Ted5000Gateway(url)
 
@@ -41,7 +42,7 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
     dev = []
     for mtu in gateway.data:
         dev.append(Ted5000Sensor(gateway, name, mtu, POWER_WATT))
-        dev.append(Ted5000Sensor(gateway, name, mtu, 'V'))
+        dev.append(Ted5000Sensor(gateway, name, mtu, "V"))
 
     add_entities(dev)
     return True
@@ -52,9 +53,9 @@ class Ted5000Sensor(Entity):
 
     def __init__(self, gateway, name, mtu, unit):
         """Initialize the sensor."""
-        units = {POWER_WATT: 'power', 'V': 'voltage'}
+        units = {POWER_WATT: "power", "V": "voltage"}
         self._gateway = gateway
-        self._name = '{} mtu{} {}'.format(name, mtu, units[unit])
+        self._name = "{} mtu{} {}".format(name, mtu, units[unit])
         self._mtu = mtu
         self._unit = unit
         self.update()
@@ -94,6 +95,7 @@ class Ted5000Gateway:
     def update(self):
         """Get the latest data from the Ted5000 XML API."""
         import xmltodict
+
         try:
             request = requests.get(self.url, timeout=10)
         except requests.exceptions.RequestException as err:
@@ -103,9 +105,7 @@ class Ted5000Gateway:
             mtus = int(doc["LiveData"]["System"]["NumberMTU"])
 
             for mtu in range(1, mtus + 1):
-                power = int(doc["LiveData"]["Power"]["MTU%d" % mtu]
-                            ["PowerNow"])
-                voltage = int(doc["LiveData"]["Voltage"]["MTU%d" % mtu]
-                              ["VoltageNow"])
+                power = int(doc["LiveData"]["Power"]["MTU%d" % mtu]["PowerNow"])
+                voltage = int(doc["LiveData"]["Voltage"]["MTU%d" % mtu]["VoltageNow"])
 
-                self.data[mtu] = {POWER_WATT: power, 'V': voltage / 10}
+                self.data[mtu] = {POWER_WATT: power, "V": voltage / 10}
