@@ -4,61 +4,105 @@ import logging
 
 import voluptuous as vol
 
-from homeassistant.components.media_player import (
-    MediaPlayerDevice, PLATFORM_SCHEMA)
+from homeassistant.components.media_player import MediaPlayerDevice, PLATFORM_SCHEMA
 from homeassistant.components.media_player.const import (
-    ATTR_APP_ID, ATTR_APP_NAME, ATTR_INPUT_SOURCE, ATTR_INPUT_SOURCE_LIST,
-    ATTR_MEDIA_ALBUM_ARTIST, ATTR_MEDIA_ALBUM_NAME, ATTR_MEDIA_ARTIST,
-    ATTR_MEDIA_CHANNEL, ATTR_MEDIA_CONTENT_ID, ATTR_MEDIA_CONTENT_TYPE,
-    ATTR_MEDIA_DURATION, ATTR_MEDIA_EPISODE, ATTR_MEDIA_PLAYLIST,
-    ATTR_MEDIA_POSITION, ATTR_MEDIA_POSITION_UPDATED_AT, ATTR_MEDIA_SEASON,
-    ATTR_MEDIA_SEEK_POSITION, ATTR_MEDIA_SERIES_TITLE, ATTR_MEDIA_SHUFFLE,
-    ATTR_MEDIA_TITLE, ATTR_MEDIA_TRACK, ATTR_MEDIA_VOLUME_LEVEL,
-    ATTR_MEDIA_VOLUME_MUTED, DOMAIN, SERVICE_CLEAR_PLAYLIST,
-    SERVICE_PLAY_MEDIA, SERVICE_SELECT_SOURCE, SUPPORT_CLEAR_PLAYLIST,
-    SUPPORT_SELECT_SOURCE, SUPPORT_SHUFFLE_SET, SUPPORT_TURN_OFF,
-    SUPPORT_TURN_ON, SUPPORT_VOLUME_MUTE, SUPPORT_VOLUME_SET,
-    SUPPORT_VOLUME_STEP)
+    ATTR_APP_ID,
+    ATTR_APP_NAME,
+    ATTR_INPUT_SOURCE,
+    ATTR_INPUT_SOURCE_LIST,
+    ATTR_MEDIA_ALBUM_ARTIST,
+    ATTR_MEDIA_ALBUM_NAME,
+    ATTR_MEDIA_ARTIST,
+    ATTR_MEDIA_CHANNEL,
+    ATTR_MEDIA_CONTENT_ID,
+    ATTR_MEDIA_CONTENT_TYPE,
+    ATTR_MEDIA_DURATION,
+    ATTR_MEDIA_EPISODE,
+    ATTR_MEDIA_PLAYLIST,
+    ATTR_MEDIA_POSITION,
+    ATTR_MEDIA_POSITION_UPDATED_AT,
+    ATTR_MEDIA_SEASON,
+    ATTR_MEDIA_SEEK_POSITION,
+    ATTR_MEDIA_SERIES_TITLE,
+    ATTR_MEDIA_SHUFFLE,
+    ATTR_MEDIA_TITLE,
+    ATTR_MEDIA_TRACK,
+    ATTR_MEDIA_VOLUME_LEVEL,
+    ATTR_MEDIA_VOLUME_MUTED,
+    DOMAIN,
+    SERVICE_CLEAR_PLAYLIST,
+    SERVICE_PLAY_MEDIA,
+    SERVICE_SELECT_SOURCE,
+    SUPPORT_CLEAR_PLAYLIST,
+    SUPPORT_SELECT_SOURCE,
+    SUPPORT_SHUFFLE_SET,
+    SUPPORT_TURN_OFF,
+    SUPPORT_TURN_ON,
+    SUPPORT_VOLUME_MUTE,
+    SUPPORT_VOLUME_SET,
+    SUPPORT_VOLUME_STEP,
+)
 from homeassistant.const import (
-    ATTR_ENTITY_ID, ATTR_ENTITY_PICTURE, ATTR_SUPPORTED_FEATURES, CONF_NAME,
-    CONF_STATE, CONF_STATE_TEMPLATE, SERVICE_MEDIA_NEXT_TRACK,
-    SERVICE_MEDIA_PAUSE, SERVICE_MEDIA_PLAY, SERVICE_MEDIA_PLAY_PAUSE,
-    SERVICE_MEDIA_PREVIOUS_TRACK, SERVICE_MEDIA_SEEK, SERVICE_MEDIA_STOP,
-    SERVICE_SHUFFLE_SET, SERVICE_TURN_OFF, SERVICE_TURN_ON,
-    SERVICE_VOLUME_DOWN, SERVICE_VOLUME_MUTE, SERVICE_VOLUME_SET,
-    SERVICE_VOLUME_UP, STATE_IDLE, STATE_OFF, STATE_ON, STATE_UNAVAILABLE)
+    ATTR_ENTITY_ID,
+    ATTR_ENTITY_PICTURE,
+    ATTR_SUPPORTED_FEATURES,
+    CONF_NAME,
+    CONF_STATE,
+    CONF_STATE_TEMPLATE,
+    SERVICE_MEDIA_NEXT_TRACK,
+    SERVICE_MEDIA_PAUSE,
+    SERVICE_MEDIA_PLAY,
+    SERVICE_MEDIA_PLAY_PAUSE,
+    SERVICE_MEDIA_PREVIOUS_TRACK,
+    SERVICE_MEDIA_SEEK,
+    SERVICE_MEDIA_STOP,
+    SERVICE_SHUFFLE_SET,
+    SERVICE_TURN_OFF,
+    SERVICE_TURN_ON,
+    SERVICE_VOLUME_DOWN,
+    SERVICE_VOLUME_MUTE,
+    SERVICE_VOLUME_SET,
+    SERVICE_VOLUME_UP,
+    STATE_IDLE,
+    STATE_OFF,
+    STATE_ON,
+    STATE_UNAVAILABLE,
+)
 from homeassistant.core import callback
 from homeassistant.helpers import config_validation as cv
 from homeassistant.helpers.service import async_call_from_config
 
 _LOGGER = logging.getLogger(__name__)
 
-ATTR_ACTIVE_CHILD = 'active_child'
-ATTR_DATA = 'data'
+ATTR_ACTIVE_CHILD = "active_child"
+ATTR_DATA = "data"
 
-CONF_ATTRS = 'attributes'
-CONF_CHILDREN = 'children'
-CONF_COMMANDS = 'commands'
-CONF_SERVICE = 'service'
-CONF_SERVICE_DATA = 'service_data'
+CONF_ATTRS = "attributes"
+CONF_CHILDREN = "children"
+CONF_COMMANDS = "commands"
+CONF_SERVICE = "service"
+CONF_SERVICE_DATA = "service_data"
 
 OFF_STATES = [STATE_IDLE, STATE_OFF, STATE_UNAVAILABLE]
 
 ATTRS_SCHEMA = cv.schema_with_slug_keys(cv.string)
 CMD_SCHEMA = cv.schema_with_slug_keys(cv.SERVICE_SCHEMA)
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend({
-    vol.Required(CONF_NAME): cv.string,
-    vol.Optional(CONF_CHILDREN, default=[]): cv.entity_ids,
-    vol.Optional(CONF_COMMANDS, default={}): CMD_SCHEMA,
-    vol.Optional(CONF_ATTRS, default={}):
-        vol.Or(cv.ensure_list(ATTRS_SCHEMA), ATTRS_SCHEMA),
-    vol.Optional(CONF_STATE_TEMPLATE): cv.template
-}, extra=vol.REMOVE_EXTRA)
+PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
+    {
+        vol.Required(CONF_NAME): cv.string,
+        vol.Optional(CONF_CHILDREN, default=[]): cv.entity_ids,
+        vol.Optional(CONF_COMMANDS, default={}): CMD_SCHEMA,
+        vol.Optional(CONF_ATTRS, default={}): vol.Or(
+            cv.ensure_list(ATTRS_SCHEMA), ATTRS_SCHEMA
+        ),
+        vol.Optional(CONF_STATE_TEMPLATE): cv.template,
+    },
+    extra=vol.REMOVE_EXTRA,
+)
 
 
-async def async_setup_platform(hass, config, async_add_entities,
-                               discovery_info=None):
+async def async_setup_platform(hass, config, async_add_entities, discovery_info=None):
     """Set up the universal media players."""
     player = UniversalMediaPlayer(
         hass,
@@ -66,7 +110,7 @@ async def async_setup_platform(hass, config, async_add_entities,
         config.get(CONF_CHILDREN),
         config.get(CONF_COMMANDS),
         config.get(CONF_ATTRS),
-        config.get(CONF_STATE_TEMPLATE)
+        config.get(CONF_STATE_TEMPLATE),
     )
 
     async_add_entities([player])
@@ -75,8 +119,7 @@ async def async_setup_platform(hass, config, async_add_entities,
 class UniversalMediaPlayer(MediaPlayerDevice):
     """Representation of an universal media player."""
 
-    def __init__(self, hass, name, children,
-                 commands, attributes, state_template=None):
+    def __init__(self, hass, name, children, commands, attributes, state_template=None):
         """Initialize the Universal media device."""
         self.hass = hass
         self._name = name
@@ -84,7 +127,7 @@ class UniversalMediaPlayer(MediaPlayerDevice):
         self._cmds = commands
         self._attrs = {}
         for key, val in attributes.items():
-            attr = val.split('|', 1)
+            attr = val.split("|", 1)
             if len(attr) == 1:
                 attr.append(None)
             self._attrs[key] = attr
@@ -98,6 +141,7 @@ class UniversalMediaPlayer(MediaPlayerDevice):
 
         This method must be run in the event loop and returns a coroutine.
         """
+
         @callback
         def async_on_dependency_update(*_):
             """Update ha state when dependencies update."""
@@ -111,7 +155,8 @@ class UniversalMediaPlayer(MediaPlayerDevice):
                 depend.append(entity)
 
         self.hass.helpers.event.async_track_state_change(
-            list(set(depend)), async_on_dependency_update)
+            list(set(depend)), async_on_dependency_update
+        )
 
     def _entity_lkp(self, entity_id, state_attr=None):
         """Look up an entity state."""
@@ -128,7 +173,8 @@ class UniversalMediaPlayer(MediaPlayerDevice):
         """Return either the override or the active child for attr_name."""
         if attr_name in self._attrs:
             return self._entity_lkp(
-                self._attrs[attr_name][0], self._attrs[attr_name][1])
+                self._attrs[attr_name][0], self._attrs[attr_name][1]
+            )
 
         return self._child_attr(attr_name)
 
@@ -137,17 +183,21 @@ class UniversalMediaPlayer(MediaPlayerDevice):
         active_child = self._child_state
         return active_child.attributes.get(attr_name) if active_child else None
 
-    async def _async_call_service(self, service_name, service_data=None,
-                                  allow_override=False):
+    async def _async_call_service(
+        self, service_name, service_data=None, allow_override=False
+    ):
         """Call either a specified or active child's service."""
         if service_data is None:
             service_data = {}
 
         if allow_override and service_name in self._cmds:
             await async_call_from_config(
-                self.hass, self._cmds[service_name],
-                variables=service_data, blocking=True,
-                validate_config=False)
+                self.hass,
+                self._cmds[service_name],
+                variables=service_data,
+                blocking=True,
+                validate_config=False,
+            )
             return
 
         active_child = self._child_state
@@ -158,7 +208,8 @@ class UniversalMediaPlayer(MediaPlayerDevice):
         service_data[ATTR_ENTITY_ID] = active_child.entity_id
 
         await self.hass.services.async_call(
-            DOMAIN, service_name, service_data, blocking=True)
+            DOMAIN, service_name, service_data, blocking=True
+        )
 
     @property
     def should_poll(self):
@@ -172,7 +223,8 @@ class UniversalMediaPlayer(MediaPlayerDevice):
             return self._state_template.async_render()
         if CONF_STATE in self._attrs:
             master_state = self._entity_lkp(
-                self._attrs[CONF_STATE][0], self._attrs[CONF_STATE][1])
+                self._attrs[CONF_STATE][0], self._attrs[CONF_STATE][1]
+            )
             return master_state if master_state else STATE_OFF
 
         return None
@@ -208,8 +260,7 @@ class UniversalMediaPlayer(MediaPlayerDevice):
     @property
     def is_volume_muted(self):
         """Boolean if volume is muted."""
-        return self._override_or_child_attr(ATTR_MEDIA_VOLUME_MUTED) \
-            in [True, STATE_ON]
+        return self._override_or_child_attr(ATTR_MEDIA_VOLUME_MUTED) in [True, STATE_ON]
 
     @property
     def media_content_id(self):
@@ -327,14 +378,12 @@ class UniversalMediaPlayer(MediaPlayerDevice):
         if SERVICE_TURN_OFF in self._cmds:
             flags |= SUPPORT_TURN_OFF
 
-        if any([cmd in self._cmds for cmd in [SERVICE_VOLUME_UP,
-                                              SERVICE_VOLUME_DOWN]]):
+        if any([cmd in self._cmds for cmd in [SERVICE_VOLUME_UP, SERVICE_VOLUME_DOWN]]):
             flags |= SUPPORT_VOLUME_STEP
         if SERVICE_VOLUME_SET in self._cmds:
             flags |= SUPPORT_VOLUME_SET
 
-        if SERVICE_VOLUME_MUTE in self._cmds and \
-                ATTR_MEDIA_VOLUME_MUTED in self._attrs:
+        if SERVICE_VOLUME_MUTE in self._cmds and ATTR_MEDIA_VOLUME_MUTED in self._attrs:
             flags |= SUPPORT_VOLUME_MUTE
 
         if SERVICE_SELECT_SOURCE in self._cmds:
@@ -343,8 +392,7 @@ class UniversalMediaPlayer(MediaPlayerDevice):
         if SERVICE_CLEAR_PLAYLIST in self._cmds:
             flags |= SUPPORT_CLEAR_PLAYLIST
 
-        if SERVICE_SHUFFLE_SET in self._cmds and \
-                ATTR_MEDIA_SHUFFLE in self._attrs:
+        if SERVICE_SHUFFLE_SET in self._cmds and ATTR_MEDIA_SHUFFLE in self._attrs:
             flags |= SUPPORT_SHUFFLE_SET
 
         return flags
@@ -353,8 +401,7 @@ class UniversalMediaPlayer(MediaPlayerDevice):
     def device_state_attributes(self):
         """Return device specific state attributes."""
         active_child = self._child_state
-        return {ATTR_ACTIVE_CHILD: active_child.entity_id} \
-            if active_child else {}
+        return {ATTR_ACTIVE_CHILD: active_child.entity_id} if active_child else {}
 
     @property
     def media_position(self):
@@ -386,8 +433,7 @@ class UniversalMediaPlayer(MediaPlayerDevice):
         This method must be run in the event loop and returns a coroutine.
         """
         data = {ATTR_MEDIA_VOLUME_MUTED: mute}
-        return self._async_call_service(
-            SERVICE_VOLUME_MUTE, data, allow_override=True)
+        return self._async_call_service(SERVICE_VOLUME_MUTE, data, allow_override=True)
 
     def async_set_volume_level(self, volume):
         """Set volume level, range 0..1.
@@ -395,8 +441,7 @@ class UniversalMediaPlayer(MediaPlayerDevice):
         This method must be run in the event loop and returns a coroutine.
         """
         data = {ATTR_MEDIA_VOLUME_LEVEL: volume}
-        return self._async_call_service(
-            SERVICE_VOLUME_SET, data, allow_override=True)
+        return self._async_call_service(SERVICE_VOLUME_SET, data, allow_override=True)
 
     def async_media_play(self):
         """Send play command.
@@ -446,8 +491,7 @@ class UniversalMediaPlayer(MediaPlayerDevice):
 
         This method must be run in the event loop and returns a coroutine.
         """
-        data = {ATTR_MEDIA_CONTENT_TYPE: media_type,
-                ATTR_MEDIA_CONTENT_ID: media_id}
+        data = {ATTR_MEDIA_CONTENT_TYPE: media_type, ATTR_MEDIA_CONTENT_ID: media_id}
         return self._async_call_service(SERVICE_PLAY_MEDIA, data)
 
     def async_volume_up(self):
@@ -462,8 +506,7 @@ class UniversalMediaPlayer(MediaPlayerDevice):
 
         This method must be run in the event loop and returns a coroutine.
         """
-        return self._async_call_service(
-            SERVICE_VOLUME_DOWN, allow_override=True)
+        return self._async_call_service(SERVICE_VOLUME_DOWN, allow_override=True)
 
     def async_media_play_pause(self):
         """Play or pause the media player.
@@ -479,7 +522,8 @@ class UniversalMediaPlayer(MediaPlayerDevice):
         """
         data = {ATTR_INPUT_SOURCE: source}
         return self._async_call_service(
-            SERVICE_SELECT_SOURCE, data, allow_override=True)
+            SERVICE_SELECT_SOURCE, data, allow_override=True
+        )
 
     def async_clear_playlist(self):
         """Clear players playlist.
@@ -494,8 +538,7 @@ class UniversalMediaPlayer(MediaPlayerDevice):
         This method must be run in the event loop and returns a coroutine.
         """
         data = {ATTR_MEDIA_SHUFFLE: shuffle}
-        return self._async_call_service(
-            SERVICE_SHUFFLE_SET, data, allow_override=True)
+        return self._async_call_service(SERVICE_SHUFFLE_SET, data, allow_override=True)
 
     async def async_update(self):
         """Update state in HA."""
