@@ -10,97 +10,107 @@ from homeassistant.util.temperature import convert as convert_temperature
 from homeassistant.helpers.entity_component import EntityComponent
 from homeassistant.helpers.entity import Entity
 from homeassistant.helpers.config_validation import (  # noqa
-    PLATFORM_SCHEMA, PLATFORM_SCHEMA_BASE)
+    PLATFORM_SCHEMA,
+    PLATFORM_SCHEMA_BASE,
+)
 import homeassistant.helpers.config_validation as cv
 from homeassistant.const import (
-    ATTR_ENTITY_ID, ATTR_TEMPERATURE, SERVICE_TURN_ON, SERVICE_TURN_OFF,
-    STATE_ON, STATE_OFF, TEMP_CELSIUS, PRECISION_WHOLE,
-    PRECISION_TENTHS, TEMP_FAHRENHEIT)
+    ATTR_ENTITY_ID,
+    ATTR_TEMPERATURE,
+    SERVICE_TURN_ON,
+    SERVICE_TURN_OFF,
+    STATE_ON,
+    STATE_OFF,
+    TEMP_CELSIUS,
+    PRECISION_WHOLE,
+    PRECISION_TENTHS,
+    TEMP_FAHRENHEIT,
+)
 
 DEFAULT_MIN_TEMP = 110
 DEFAULT_MAX_TEMP = 140
 
-DOMAIN = 'water_heater'
+DOMAIN = "water_heater"
 
-ENTITY_ID_FORMAT = DOMAIN + '.{}'
+ENTITY_ID_FORMAT = DOMAIN + ".{}"
 SCAN_INTERVAL = timedelta(seconds=60)
 
-SERVICE_SET_AWAY_MODE = 'set_away_mode'
-SERVICE_SET_TEMPERATURE = 'set_temperature'
-SERVICE_SET_OPERATION_MODE = 'set_operation_mode'
+SERVICE_SET_AWAY_MODE = "set_away_mode"
+SERVICE_SET_TEMPERATURE = "set_temperature"
+SERVICE_SET_OPERATION_MODE = "set_operation_mode"
 
-STATE_ECO = 'eco'
-STATE_ELECTRIC = 'electric'
-STATE_PERFORMANCE = 'performance'
-STATE_HIGH_DEMAND = 'high_demand'
-STATE_HEAT_PUMP = 'heat_pump'
-STATE_GAS = 'gas'
+STATE_ECO = "eco"
+STATE_ELECTRIC = "electric"
+STATE_PERFORMANCE = "performance"
+STATE_HIGH_DEMAND = "high_demand"
+STATE_HEAT_PUMP = "heat_pump"
+STATE_GAS = "gas"
 
 SUPPORT_TARGET_TEMPERATURE = 1
 SUPPORT_OPERATION_MODE = 2
 SUPPORT_AWAY_MODE = 4
 
-ATTR_MAX_TEMP = 'max_temp'
-ATTR_MIN_TEMP = 'min_temp'
-ATTR_AWAY_MODE = 'away_mode'
-ATTR_OPERATION_MODE = 'operation_mode'
-ATTR_OPERATION_LIST = 'operation_list'
-ATTR_TARGET_TEMP_HIGH = 'target_temp_high'
-ATTR_TARGET_TEMP_LOW = 'target_temp_low'
-ATTR_CURRENT_TEMPERATURE = 'current_temperature'
+ATTR_MAX_TEMP = "max_temp"
+ATTR_MIN_TEMP = "min_temp"
+ATTR_AWAY_MODE = "away_mode"
+ATTR_OPERATION_MODE = "operation_mode"
+ATTR_OPERATION_LIST = "operation_list"
+ATTR_TARGET_TEMP_HIGH = "target_temp_high"
+ATTR_TARGET_TEMP_LOW = "target_temp_low"
+ATTR_CURRENT_TEMPERATURE = "current_temperature"
 
-CONVERTIBLE_ATTRIBUTE = [
-    ATTR_TEMPERATURE,
-]
+CONVERTIBLE_ATTRIBUTE = [ATTR_TEMPERATURE]
 
 _LOGGER = logging.getLogger(__name__)
 
-ON_OFF_SERVICE_SCHEMA = vol.Schema({
-    vol.Optional(ATTR_ENTITY_ID): cv.comp_entity_ids,
-})
+ON_OFF_SERVICE_SCHEMA = vol.Schema({vol.Optional(ATTR_ENTITY_ID): cv.comp_entity_ids})
 
-SET_AWAY_MODE_SCHEMA = vol.Schema({
-    vol.Optional(ATTR_ENTITY_ID): cv.comp_entity_ids,
-    vol.Required(ATTR_AWAY_MODE): cv.boolean,
-})
-SET_TEMPERATURE_SCHEMA = vol.Schema(vol.All(
+SET_AWAY_MODE_SCHEMA = vol.Schema(
     {
-        vol.Required(ATTR_TEMPERATURE, 'temperature'): vol.Coerce(float),
         vol.Optional(ATTR_ENTITY_ID): cv.comp_entity_ids,
-        vol.Optional(ATTR_OPERATION_MODE): cv.string,
+        vol.Required(ATTR_AWAY_MODE): cv.boolean,
     }
-))
-SET_OPERATION_MODE_SCHEMA = vol.Schema({
-    vol.Optional(ATTR_ENTITY_ID): cv.comp_entity_ids,
-    vol.Required(ATTR_OPERATION_MODE): cv.string,
-})
+)
+SET_TEMPERATURE_SCHEMA = vol.Schema(
+    vol.All(
+        {
+            vol.Required(ATTR_TEMPERATURE, "temperature"): vol.Coerce(float),
+            vol.Optional(ATTR_ENTITY_ID): cv.comp_entity_ids,
+            vol.Optional(ATTR_OPERATION_MODE): cv.string,
+        }
+    )
+)
+SET_OPERATION_MODE_SCHEMA = vol.Schema(
+    {
+        vol.Optional(ATTR_ENTITY_ID): cv.comp_entity_ids,
+        vol.Required(ATTR_OPERATION_MODE): cv.string,
+    }
+)
 
 
 async def async_setup(hass, config):
     """Set up water_heater devices."""
-    component = hass.data[DOMAIN] = \
-        EntityComponent(_LOGGER, DOMAIN, hass, SCAN_INTERVAL)
+    component = hass.data[DOMAIN] = EntityComponent(
+        _LOGGER, DOMAIN, hass, SCAN_INTERVAL
+    )
     await component.async_setup(config)
 
     component.async_register_entity_service(
-        SERVICE_SET_AWAY_MODE, SET_AWAY_MODE_SCHEMA,
-        async_service_away_mode
+        SERVICE_SET_AWAY_MODE, SET_AWAY_MODE_SCHEMA, async_service_away_mode
     )
     component.async_register_entity_service(
-        SERVICE_SET_TEMPERATURE, SET_TEMPERATURE_SCHEMA,
-        async_service_temperature_set
+        SERVICE_SET_TEMPERATURE, SET_TEMPERATURE_SCHEMA, async_service_temperature_set
     )
     component.async_register_entity_service(
-        SERVICE_SET_OPERATION_MODE, SET_OPERATION_MODE_SCHEMA,
-        'async_set_operation_mode'
+        SERVICE_SET_OPERATION_MODE,
+        SET_OPERATION_MODE_SCHEMA,
+        "async_set_operation_mode",
     )
     component.async_register_entity_service(
-        SERVICE_TURN_OFF, ON_OFF_SERVICE_SCHEMA,
-        'async_turn_off'
+        SERVICE_TURN_OFF, ON_OFF_SERVICE_SCHEMA, "async_turn_off"
     )
     component.async_register_entity_service(
-        SERVICE_TURN_ON, ON_OFF_SERVICE_SCHEMA,
-        'async_turn_on'
+        SERVICE_TURN_ON, ON_OFF_SERVICE_SCHEMA, "async_turn_on"
     )
 
     return True
@@ -136,23 +146,35 @@ class WaterHeaterDevice(Entity):
         """Return the optional state attributes."""
         data = {
             ATTR_CURRENT_TEMPERATURE: show_temp(
-                self.hass, self.current_temperature, self.temperature_unit,
-                self.precision),
+                self.hass,
+                self.current_temperature,
+                self.temperature_unit,
+                self.precision,
+            ),
             ATTR_MIN_TEMP: show_temp(
-                self.hass, self.min_temp, self.temperature_unit,
-                self.precision),
+                self.hass, self.min_temp, self.temperature_unit, self.precision
+            ),
             ATTR_MAX_TEMP: show_temp(
-                self.hass, self.max_temp, self.temperature_unit,
-                self.precision),
+                self.hass, self.max_temp, self.temperature_unit, self.precision
+            ),
             ATTR_TEMPERATURE: show_temp(
-                self.hass, self.target_temperature, self.temperature_unit,
-                self.precision),
+                self.hass,
+                self.target_temperature,
+                self.temperature_unit,
+                self.precision,
+            ),
             ATTR_TARGET_TEMP_HIGH: show_temp(
-                self.hass, self.target_temperature_high, self.temperature_unit,
-                self.precision),
+                self.hass,
+                self.target_temperature_high,
+                self.temperature_unit,
+                self.precision,
+            ),
             ATTR_TARGET_TEMP_LOW: show_temp(
-                self.hass, self.target_temperature_low, self.temperature_unit,
-                self.precision),
+                self.hass,
+                self.target_temperature_low,
+                self.temperature_unit,
+                self.precision,
+            ),
         }
 
         supported_features = self.supported_features
@@ -215,7 +237,8 @@ class WaterHeaterDevice(Entity):
     async def async_set_temperature(self, **kwargs):
         """Set new target temperature."""
         await self.hass.async_add_executor_job(
-            ft.partial(self.set_temperature, **kwargs))
+            ft.partial(self.set_temperature, **kwargs)
+        )
 
     def set_operation_mode(self, operation_mode):
         """Set new target operation mode."""
@@ -223,8 +246,7 @@ class WaterHeaterDevice(Entity):
 
     async def async_set_operation_mode(self, operation_mode):
         """Set new target operation mode."""
-        await self.hass.async_add_executor_job(self.set_operation_mode,
-                                               operation_mode)
+        await self.hass.async_add_executor_job(self.set_operation_mode, operation_mode)
 
     def turn_away_mode_on(self):
         """Turn away mode on."""
@@ -250,14 +272,16 @@ class WaterHeaterDevice(Entity):
     @property
     def min_temp(self):
         """Return the minimum temperature."""
-        return convert_temperature(DEFAULT_MIN_TEMP, TEMP_FAHRENHEIT,
-                                   self.temperature_unit)
+        return convert_temperature(
+            DEFAULT_MIN_TEMP, TEMP_FAHRENHEIT, self.temperature_unit
+        )
 
     @property
     def max_temp(self):
         """Return the maximum temperature."""
-        return convert_temperature(DEFAULT_MAX_TEMP, TEMP_FAHRENHEIT,
-                                   self.temperature_unit)
+        return convert_temperature(
+            DEFAULT_MAX_TEMP, TEMP_FAHRENHEIT, self.temperature_unit
+        )
 
 
 async def async_service_away_mode(entity, service):
@@ -276,9 +300,7 @@ async def async_service_temperature_set(entity, service):
     for value, temp in service.data.items():
         if value in CONVERTIBLE_ATTRIBUTE:
             kwargs[value] = convert_temperature(
-                temp,
-                hass.config.units.temperature_unit,
-                entity.temperature_unit
+                temp, hass.config.units.temperature_unit, entity.temperature_unit
             )
         else:
             kwargs[value] = temp
