@@ -7,9 +7,11 @@ from homeassistant.const import (
     EVENT_SERVICE_REGISTERED,
     EVENT_SERVICE_REMOVED,
     EVENT_STATE_CHANGED,
-    EVENT_THEMES_UPDATED)
+    EVENT_THEMES_UPDATED,
+)
 from homeassistant.components.persistent_notification import (
-    EVENT_PERSISTENT_NOTIFICATIONS_UPDATED)
+    EVENT_PERSISTENT_NOTIFICATIONS_UPDATED,
+)
 from homeassistant.components.lovelace import EVENT_LOVELACE_UPDATED
 from homeassistant.helpers.area_registry import EVENT_AREA_REGISTRY_UPDATED
 from homeassistant.helpers.device_registry import EVENT_DEVICE_REGISTRY_UPDATED
