@@ -5,40 +5,60 @@ import pywink
 
 from homeassistant.components.climate import ClimateDevice
 from homeassistant.components.climate.const import (
-    ATTR_TARGET_TEMP_HIGH, ATTR_TARGET_TEMP_LOW, CURRENT_HVAC_COOL,
-    CURRENT_HVAC_HEAT, CURRENT_HVAC_IDLE, CURRENT_HVAC_OFF, FAN_AUTO, FAN_HIGH,
-    FAN_LOW, FAN_MEDIUM, FAN_ON, HVAC_MODE_AUTO, HVAC_MODE_COOL,
-    HVAC_MODE_FAN_ONLY, HVAC_MODE_HEAT, HVAC_MODE_OFF, PRESET_AWAY, PRESET_ECO,
-    SUPPORT_AUX_HEAT, SUPPORT_FAN_MODE, SUPPORT_TARGET_TEMPERATURE,
-    SUPPORT_TARGET_TEMPERATURE_RANGE, PRESET_NONE)
-from homeassistant.const import (
-    ATTR_TEMPERATURE, PRECISION_TENTHS, TEMP_CELSIUS)
+    ATTR_TARGET_TEMP_HIGH,
+    ATTR_TARGET_TEMP_LOW,
+    CURRENT_HVAC_COOL,
+    CURRENT_HVAC_HEAT,
+    CURRENT_HVAC_IDLE,
+    CURRENT_HVAC_OFF,
+    FAN_AUTO,
+    FAN_HIGH,
+    FAN_LOW,
+    FAN_MEDIUM,
+    FAN_ON,
+    HVAC_MODE_AUTO,
+    HVAC_MODE_COOL,
+    HVAC_MODE_FAN_ONLY,
+    HVAC_MODE_HEAT,
+    HVAC_MODE_OFF,
+    PRESET_AWAY,
+    PRESET_ECO,
+    SUPPORT_AUX_HEAT,
+    SUPPORT_FAN_MODE,
+    SUPPORT_TARGET_TEMPERATURE,
+    SUPPORT_TARGET_TEMPERATURE_RANGE,
+    PRESET_NONE,
+)
+from homeassistant.const import ATTR_TEMPERATURE, PRECISION_TENTHS, TEMP_CELSIUS
 from homeassistant.helpers.temperature import display_temp as show_temp
 
 from . import DOMAIN, WinkDevice
 
 _LOGGER = logging.getLogger(__name__)
 
-ATTR_ECO_TARGET = 'eco_target'
-ATTR_EXTERNAL_TEMPERATURE = 'external_temperature'
-ATTR_OCCUPIED = 'occupied'
-ATTR_SCHEDULE_ENABLED = 'schedule_enabled'
-ATTR_SMART_TEMPERATURE = 'smart_temperature'
-ATTR_TOTAL_CONSUMPTION = 'total_consumption'
+ATTR_ECO_TARGET = "eco_target"
+ATTR_EXTERNAL_TEMPERATURE = "external_temperature"
+ATTR_OCCUPIED = "occupied"
+ATTR_SCHEDULE_ENABLED = "schedule_enabled"
+ATTR_SMART_TEMPERATURE = "smart_temperature"
+ATTR_TOTAL_CONSUMPTION = "total_consumption"
 
 HA_HVAC_TO_WINK = {
-    HVAC_MODE_AUTO: 'auto',
-    HVAC_MODE_COOL: 'cool_only',
-    HVAC_MODE_FAN_ONLY: 'fan_only',
-    HVAC_MODE_HEAT: 'heat_only',
-    HVAC_MODE_OFF: 'off',
+    HVAC_MODE_AUTO: "auto",
+    HVAC_MODE_COOL: "cool_only",
+    HVAC_MODE_FAN_ONLY: "fan_only",
+    HVAC_MODE_HEAT: "heat_only",
+    HVAC_MODE_OFF: "off",
 }
 
 WINK_HVAC_TO_HA = {value: key for key, value in HA_HVAC_TO_WINK.items()}
 
 SUPPORT_FLAGS_THERMOSTAT = (
-    SUPPORT_TARGET_TEMPERATURE | SUPPORT_TARGET_TEMPERATURE_RANGE |
-    SUPPORT_FAN_MODE | SUPPORT_AUX_HEAT)
+    SUPPORT_TARGET_TEMPERATURE
+    | SUPPORT_TARGET_TEMPERATURE_RANGE
+    | SUPPORT_FAN_MODE
+    | SUPPORT_AUX_HEAT
+)
 SUPPORT_FAN_THERMOSTAT = [FAN_AUTO, FAN_ON]
 SUPPORT_PRESET_THERMOSTAT = [PRESET_AWAY, PRESET_ECO]
 
@@ -51,11 +71,11 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
     """Set up the Wink climate devices."""
     for climate in pywink.get_thermostats():
         _id = climate.object_id() + climate.name()
-        if _id not in hass.data[DOMAIN]['unique_ids']:
+        if _id not in hass.data[DOMAIN]["unique_ids"]:
             add_entities([WinkThermostat(climate, hass)])
     for climate in pywink.get_air_conditioners():
         _id = climate.object_id() + climate.name()
-        if _id not in hass.data[DOMAIN]['unique_ids']:
+        if _id not in hass.data[DOMAIN]["unique_ids"]:
             add_entities([WinkAC(climate, hass)])
 
 
@@ -69,7 +89,7 @@ class WinkThermostat(WinkDevice, ClimateDevice):
 
     async def async_added_to_hass(self):
         """Call when entity is added to hass."""
-        self.hass.data[DOMAIN]['entities']['climate'].append(self)
+        self.hass.data[DOMAIN]["entities"]["climate"].append(self)
 
     @property
     def temperature_unit(self):
@@ -83,8 +103,11 @@ class WinkThermostat(WinkDevice, ClimateDevice):
         data = {}
         if self.external_temperature is not None:
             data[ATTR_EXTERNAL_TEMPERATURE] = show_temp(
-                self.hass, self.external_temperature, self.temperature_unit,
-                PRECISION_TENTHS)
+                self.hass,
+                self.external_temperature,
+                self.temperature_unit,
+                PRECISION_TENTHS,
+            )
 
         if self.smart_temperature:
             data[ATTR_SMART_TEMPERATURE] = self.smart_temperature
@@ -153,10 +176,10 @@ class WinkThermostat(WinkDevice, ClimateDevice):
     def target_humidity(self):
         """Return the humidity we try to reach."""
         target_hum = None
-        if self.wink.current_humidifier_mode() == 'on':
+        if self.wink.current_humidifier_mode() == "on":
             if self.wink.current_humidifier_set_point() is not None:
                 target_hum = self.wink.current_humidifier_set_point() * 100
-        elif self.wink.current_dehumidifier_mode() == 'on':
+        elif self.wink.current_dehumidifier_mode() == "on":
             if self.wink.current_dehumidifier_set_point() is not None:
                 target_hum = self.wink.current_dehumidifier_set_point() * 100
         else:
@@ -190,9 +213,9 @@ class WinkThermostat(WinkDevice, ClimateDevice):
     @property
     def is_aux_heat(self):
         """Return true if aux heater."""
-        if 'aux' not in self.wink.hvac_modes():
+        if "aux" not in self.wink.hvac_modes():
             return None
-        if self.wink.current_hvac_mode() == 'aux':
+        if self.wink.current_hvac_mode() == "aux":
             return True
         return False
 
@@ -230,7 +253,9 @@ class WinkThermostat(WinkDevice, ClimateDevice):
             except KeyError:
                 _LOGGER.error(
                     "Invalid operation mode mapping. %s doesn't map. "
-                    "Please report this.", mode)
+                    "Please report this.",
+                    mode,
+                )
         return hvac_list
 
     @property
@@ -241,9 +266,9 @@ class WinkThermostat(WinkDevice, ClimateDevice):
         """
         if not self.wink.is_on():
             return CURRENT_HVAC_OFF
-        if self.wink.cool_on:
+        if self.wink.cool_on():
             return CURRENT_HVAC_COOL
-        if self.wink.heat_on:
+        if self.wink.heat_on():
             return CURRENT_HVAC_HEAT
         return CURRENT_HVAC_IDLE
 
@@ -282,9 +307,9 @@ class WinkThermostat(WinkDevice, ClimateDevice):
     @property
     def fan_mode(self):
         """Return whether the fan is on."""
-        if self.wink.current_fan_mode() == 'on':
+        if self.wink.current_fan_mode() == "on":
             return FAN_ON
-        if self.wink.current_fan_mode() == 'auto':
+        if self.wink.current_fan_mode() == "auto":
             return FAN_AUTO
         # No Fan available so disable slider
         return None
@@ -302,11 +327,11 @@ class WinkThermostat(WinkDevice, ClimateDevice):
 
     def turn_aux_heat_on(self):
         """Turn auxiliary heater on."""
-        self.wink.set_operation_mode('aux')
+        self.wink.set_operation_mode("aux")
 
     def turn_aux_heat_off(self):
         """Turn auxiliary heater off."""
-        self.wink.set_operation_mode('heat_only')
+        self.wink.set_operation_mode("heat_only")
 
     @property
     def min_temp(self):
@@ -409,7 +434,7 @@ class WinkAC(WinkDevice, ClimateDevice):
         if not self.wink.is_on():
             return HVAC_MODE_OFF
 
-        wink_mode = self.wink.current_hvac_mode()
+        wink_mode = self.wink.current_mode()
         if wink_mode == "auto_eco":
             return HVAC_MODE_AUTO
         return WINK_HVAC_TO_HA.get(wink_mode)
@@ -422,7 +447,7 @@ class WinkAC(WinkDevice, ClimateDevice):
         """
         hvac_list = [HVAC_MODE_OFF]
 
-        modes = self.wink.hvac_modes()
+        modes = self.wink.modes()
         for mode in modes:
             if mode == "auto_eco":
                 continue
@@ -432,7 +457,9 @@ class WinkAC(WinkDevice, ClimateDevice):
             except KeyError:
                 _LOGGER.error(
                     "Invalid operation mode mapping. %s doesn't map. "
-                    "Please report this.", mode)
+                    "Please report this.",
+                    mode,
+                )
         return hvac_list
 
     def set_temperature(self, **kwargs):
