@@ -6,91 +6,107 @@ from datetime import timedelta
 import voluptuous as vol
 from yeelight import Bulb, BulbException
 from homeassistant.components.discovery import SERVICE_YEELIGHT
-from homeassistant.const import CONF_DEVICES, CONF_NAME, CONF_SCAN_INTERVAL, \
-    CONF_HOST, ATTR_ENTITY_ID
+from homeassistant.const import (
+    CONF_DEVICES,
+    CONF_NAME,
+    CONF_SCAN_INTERVAL,
+    CONF_HOST,
+    ATTR_ENTITY_ID,
+)
 from homeassistant.components.light import DOMAIN as LIGHT_DOMAIN
-from homeassistant.components.binary_sensor import DOMAIN as \
-    BINARY_SENSOR_DOMAIN
+from homeassistant.components.binary_sensor import DOMAIN as BINARY_SENSOR_DOMAIN
 from homeassistant.helpers import discovery
 from homeassistant.helpers.discovery import load_platform
 import homeassistant.helpers.config_validation as cv
-from homeassistant.helpers.dispatcher import dispatcher_send, \
-    dispatcher_connect
+from homeassistant.helpers.dispatcher import dispatcher_send, dispatcher_connect
 from homeassistant.helpers.event import track_time_interval
 
 _LOGGER = logging.getLogger(__name__)
 
 DOMAIN = "yeelight"
 DATA_YEELIGHT = DOMAIN
-DATA_UPDATED = 'yeelight_{}_data_updated'
-DEVICE_INITIALIZED = '{}_device_initialized'.format(DOMAIN)
+DATA_UPDATED = "yeelight_{}_data_updated"
+DEVICE_INITIALIZED = "{}_device_initialized".format(DOMAIN)
 
-DEFAULT_NAME = 'Yeelight'
+DEFAULT_NAME = "Yeelight"
 DEFAULT_TRANSITION = 350
 
-CONF_MODEL = 'model'
-CONF_TRANSITION = 'transition'
-CONF_SAVE_ON_CHANGE = 'save_on_change'
-CONF_MODE_MUSIC = 'use_music_mode'
-CONF_FLOW_PARAMS = 'flow_params'
-CONF_CUSTOM_EFFECTS = 'custom_effects'
+CONF_MODEL = "model"
+CONF_TRANSITION = "transition"
+CONF_SAVE_ON_CHANGE = "save_on_change"
+CONF_MODE_MUSIC = "use_music_mode"
+CONF_FLOW_PARAMS = "flow_params"
+CONF_CUSTOM_EFFECTS = "custom_effects"
 
-ATTR_COUNT = 'count'
-ATTR_ACTION = 'action'
-ATTR_TRANSITIONS = 'transitions'
+ATTR_COUNT = "count"
+ATTR_ACTION = "action"
+ATTR_TRANSITIONS = "transitions"
 
-ACTION_RECOVER = 'recover'
-ACTION_STAY = 'stay'
-ACTION_OFF = 'off'
+ACTION_RECOVER = "recover"
+ACTION_STAY = "stay"
+ACTION_OFF = "off"
 
-ACTIVE_MODE_NIGHTLIGHT = '1'
+ACTIVE_MODE_NIGHTLIGHT = "1"
 
 SCAN_INTERVAL = timedelta(seconds=30)
 
-YEELIGHT_RGB_TRANSITION = 'RGBTransition'
-YEELIGHT_HSV_TRANSACTION = 'HSVTransition'
-YEELIGHT_TEMPERATURE_TRANSACTION = 'TemperatureTransition'
-YEELIGHT_SLEEP_TRANSACTION = 'SleepTransition'
+YEELIGHT_RGB_TRANSITION = "RGBTransition"
+YEELIGHT_HSV_TRANSACTION = "HSVTransition"
+YEELIGHT_TEMPERATURE_TRANSACTION = "TemperatureTransition"
+YEELIGHT_SLEEP_TRANSACTION = "SleepTransition"
 
 YEELIGHT_FLOW_TRANSITION_SCHEMA = {
     vol.Optional(ATTR_COUNT, default=0): cv.positive_int,
-    vol.Optional(ATTR_ACTION, default=ACTION_RECOVER):
-        vol.Any(ACTION_RECOVER, ACTION_OFF, ACTION_STAY),
-    vol.Required(ATTR_TRANSITIONS): [{
-        vol.Exclusive(YEELIGHT_RGB_TRANSITION, CONF_TRANSITION):
-            vol.All(cv.ensure_list, [cv.positive_int]),
-        vol.Exclusive(YEELIGHT_HSV_TRANSACTION, CONF_TRANSITION):
-            vol.All(cv.ensure_list, [cv.positive_int]),
-        vol.Exclusive(YEELIGHT_TEMPERATURE_TRANSACTION, CONF_TRANSITION):
-            vol.All(cv.ensure_list, [cv.positive_int]),
-        vol.Exclusive(YEELIGHT_SLEEP_TRANSACTION, CONF_TRANSITION):
-            vol.All(cv.ensure_list, [cv.positive_int]),
-    }]
+    vol.Optional(ATTR_ACTION, default=ACTION_RECOVER): vol.Any(
+        ACTION_RECOVER, ACTION_OFF, ACTION_STAY
+    ),
+    vol.Required(ATTR_TRANSITIONS): [
+        {
+            vol.Exclusive(YEELIGHT_RGB_TRANSITION, CONF_TRANSITION): vol.All(
+                cv.ensure_list, [cv.positive_int]
+            ),
+            vol.Exclusive(YEELIGHT_HSV_TRANSACTION, CONF_TRANSITION): vol.All(
+                cv.ensure_list, [cv.positive_int]
+            ),
+            vol.Exclusive(YEELIGHT_TEMPERATURE_TRANSACTION, CONF_TRANSITION): vol.All(
+                cv.ensure_list, [cv.positive_int]
+            ),
+            vol.Exclusive(YEELIGHT_SLEEP_TRANSACTION, CONF_TRANSITION): vol.All(
+                cv.ensure_list, [cv.positive_int]
+            ),
+        }
+    ],
 }
 
-DEVICE_SCHEMA = vol.Schema({
-    vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
-    vol.Optional(CONF_TRANSITION, default=DEFAULT_TRANSITION): cv.positive_int,
-    vol.Optional(CONF_MODE_MUSIC, default=False): cv.boolean,
-    vol.Optional(CONF_SAVE_ON_CHANGE, default=False): cv.boolean,
-    vol.Optional(CONF_MODEL): cv.string,
-})
+DEVICE_SCHEMA = vol.Schema(
+    {
+        vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
+        vol.Optional(CONF_TRANSITION, default=DEFAULT_TRANSITION): cv.positive_int,
+        vol.Optional(CONF_MODE_MUSIC, default=False): cv.boolean,
+        vol.Optional(CONF_SAVE_ON_CHANGE, default=False): cv.boolean,
+        vol.Optional(CONF_MODEL): cv.string,
+    }
+)
 
-CONFIG_SCHEMA = vol.Schema({
-    DOMAIN: vol.Schema({
-        vol.Optional(CONF_DEVICES, default={}): {cv.string: DEVICE_SCHEMA},
-        vol.Optional(CONF_SCAN_INTERVAL, default=SCAN_INTERVAL):
-            cv.time_period,
-        vol.Optional(CONF_CUSTOM_EFFECTS): [{
-            vol.Required(CONF_NAME): cv.string,
-            vol.Required(CONF_FLOW_PARAMS): YEELIGHT_FLOW_TRANSITION_SCHEMA
-        }]
-    }),
-}, extra=vol.ALLOW_EXTRA)
+CONFIG_SCHEMA = vol.Schema(
+    {
+        DOMAIN: vol.Schema(
+            {
+                vol.Optional(CONF_DEVICES, default={}): {cv.string: DEVICE_SCHEMA},
+                vol.Optional(CONF_SCAN_INTERVAL, default=SCAN_INTERVAL): cv.time_period,
+                vol.Optional(CONF_CUSTOM_EFFECTS): [
+                    {
+                        vol.Required(CONF_NAME): cv.string,
+                        vol.Required(CONF_FLOW_PARAMS): YEELIGHT_FLOW_TRANSITION_SCHEMA,
+                    }
+                ],
+            }
+        )
+    },
+    extra=vol.ALLOW_EXTRA,
+)
 
-YEELIGHT_SERVICE_SCHEMA = vol.Schema({
-    vol.Required(ATTR_ENTITY_ID): cv.entity_ids,
-})
+YEELIGHT_SERVICE_SCHEMA = vol.Schema({vol.Required(ATTR_ENTITY_ID): cv.entity_ids})
 
 UPDATE_REQUEST_PROPERTIES = [
     "power",
@@ -120,10 +136,9 @@ def setup(hass, config):
     yeelight_data = hass.data[DATA_YEELIGHT] = {}
 
     def device_discovered(_, info):
-        _LOGGER.debug("Adding autodetected %s", info['hostname'])
+        _LOGGER.debug("Adding autodetected %s", info["hostname"])
 
-        name = "yeelight_%s_%s" % (info['device_type'],
-                                   info['properties']['mac'])
+        name = "yeelight_%s_%s" % (info["device_type"], info["properties"]["mac"])
 
         device_config = DEVICE_SCHEMA({CONF_NAME: name})
 
@@ -135,18 +150,16 @@ def setup(hass, config):
         for device in list(yeelight_data.values()):
             device.update()
 
-    track_time_interval(
-        hass, update, conf.get(CONF_SCAN_INTERVAL, SCAN_INTERVAL)
-    )
+    track_time_interval(hass, update, conf.get(CONF_SCAN_INTERVAL, SCAN_INTERVAL))
 
     def load_platforms(ipaddr):
         platform_config = hass.data[DATA_YEELIGHT][ipaddr].config.copy()
         platform_config[CONF_HOST] = ipaddr
-        platform_config[CONF_CUSTOM_EFFECTS] = \
-            config.get(DOMAIN, {}).get(CONF_CUSTOM_EFFECTS, {})
+        platform_config[CONF_CUSTOM_EFFECTS] = config.get(DOMAIN, {}).get(
+            CONF_CUSTOM_EFFECTS, {}
+        )
         load_platform(hass, LIGHT_DOMAIN, DOMAIN, platform_config, config)
-        load_platform(hass, BINARY_SENSOR_DOMAIN, DOMAIN, platform_config,
-                      config)
+        load_platform(hass, BINARY_SENSOR_DOMAIN, DOMAIN, platform_config, config)
 
     dispatcher_connect(hass, DEVICE_INITIALIZED, load_platforms)
 
@@ -227,13 +240,13 @@ class YeelightDevice:
     def is_nightlight_supported(self) -> bool:
         """Return true / false if nightlight is supported."""
         if self.model:
-            return self.bulb.get_model_specs().get('night_light', False)
+            return self.bulb.get_model_specs().get("night_light", False)
 
         return self._active_mode is not None
 
     @property
     def _active_mode(self):
-        return self.bulb.last_properties.get('active_mode')
+        return self.bulb.last_properties.get("active_mode")
 
     @property
     def type(self):
@@ -255,8 +268,9 @@ class YeelightDevice:
         try:
             self.bulb.turn_off(duration=duration, light_type=light_type)
         except BulbException as ex:
-            _LOGGER.error("Unable to turn the bulb off: %s, %s: %s",
-                          self.ipaddr, self.name, ex)
+            _LOGGER.error(
+                "Unable to turn the bulb off: %s, %s: %s", self.ipaddr, self.name, ex
+            )
 
     def _update_properties(self):
         """Read new properties from the device."""
@@ -270,8 +284,9 @@ class YeelightDevice:
                 self._initialize_device()
         except BulbException as ex:
             if self._available:  # just inform once
-                _LOGGER.error("Unable to update device %s, %s: %s",
-                              self.ipaddr, self.name, ex)
+                _LOGGER.error(
+                    "Unable to update device %s, %s: %s", self.ipaddr, self.name, ex
+                )
             self._available = False
 
         return self._available
