@@ -10,9 +10,7 @@ from homeassistant.helpers.dispatcher import async_dispatcher_send
 from homeassistant.helpers.event import async_call_later
 from . import ZigbeeChannel, parse_and_log_command
 from ..helpers import get_attr_id_by_name
-from ..const import (
-    SIGNAL_ATTR_UPDATED, SIGNAL_MOVE_LEVEL, SIGNAL_SET_LEVEL
-)
+from ..const import SIGNAL_ATTR_UPDATED, SIGNAL_MOVE_LEVEL, SIGNAL_SET_LEVEL
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -31,19 +29,13 @@ class OnOffChannel(ZigbeeChannel):
     @callback
     def cluster_command(self, tsn, command_id, args):
         """Handle commands received to this cluster."""
-        cmd = parse_and_log_command(
-            self.unique_id,
-            self._cluster,
-            tsn,
-            command_id,
-            args
-        )
+        cmd = parse_and_log_command(self, tsn, command_id, args)
 
-        if cmd in ('off', 'off_with_effect'):
+        if cmd in ("off", "off_with_effect"):
             self.attribute_updated(self.ON_OFF, False)
-        elif cmd in ('on', 'on_with_recall_global_scene'):
+        elif cmd in ("on", "on_with_recall_global_scene"):
             self.attribute_updated(self.ON_OFF, True)
-        elif cmd == 'on_with_timed_off':
+        elif cmd == "on_with_timed_off":
             should_accept = args[0]
             on_time = args[1]
             # 0 is always accept 1 is only accept when already on
@@ -56,9 +48,9 @@ class OnOffChannel(ZigbeeChannel):
                     self._off_listener = async_call_later(
                         self.device.hass,
                         (on_time / 10),  # value is in 10ths of a second
-                        self.set_to_off
+                        self.set_to_off,
                     )
-        elif cmd == 'toggle':
+        elif cmd == "toggle":
             self.attribute_updated(self.ON_OFF, not bool(self._state))
 
     @callback
@@ -74,26 +66,24 @@ class OnOffChannel(ZigbeeChannel):
             async_dispatcher_send(
                 self._zha_device.hass,
                 "{}_{}".format(self.unique_id, SIGNAL_ATTR_UPDATED),
-                value
+                value,
             )
             self._state = bool(value)
 
     async def async_initialize(self, from_cache):
         """Initialize channel."""
         self._state = bool(
-            await self.get_attribute_value(self.ON_OFF, from_cache=from_cache))
+            await self.get_attribute_value(self.ON_OFF, from_cache=from_cache)
+        )
         await super().async_initialize(from_cache)
 
     async def async_update(self):
         """Initialize channel."""
         from_cache = not self.device.is_mains_powered
-        _LOGGER.debug(
-            "%s is attempting to update onoff state - from cache: %s",
-            self._unique_id,
-            from_cache
-        )
+        self.debug("attempting to update onoff state - from cache: %s", from_cache)
         self._state = bool(
-            await self.get_attribute_value(self.ON_OFF, from_cache=from_cache))
+            await self.get_attribute_value(self.ON_OFF, from_cache=from_cache)
+        )
         await super().async_update()
 
 
@@ -105,48 +95,38 @@ class LevelControlChannel(ZigbeeChannel):
     @callback
     def cluster_command(self, tsn, command_id, args):
         """Handle commands received to this cluster."""
-        cmd = parse_and_log_command(
-            self.unique_id,
-            self._cluster,
-            tsn,
-            command_id,
-            args
-        )
+        cmd = parse_and_log_command(self, tsn, command_id, args)
 
-        if cmd in ('move_to_level', 'move_to_level_with_on_off'):
+        if cmd in ("move_to_level", "move_to_level_with_on_off"):
             self.dispatch_level_change(SIGNAL_SET_LEVEL, args[0])
-        elif cmd in ('move', 'move_with_on_off'):
+        elif cmd in ("move", "move_with_on_off"):
             # We should dim slowly -- for now, just step once
             rate = args[1]
-            if args[0] == 0xff:
+            if args[0] == 0xFF:
                 rate = 10  # Should read default move rate
-            self.dispatch_level_change(
-                SIGNAL_MOVE_LEVEL, -rate if args[0] else rate)
-        elif cmd in ('step', 'step_with_on_off'):
+            self.dispatch_level_change(SIGNAL_MOVE_LEVEL, -rate if args[0] else rate)
+        elif cmd in ("step", "step_with_on_off"):
             # Step (technically may change on/off)
             self.dispatch_level_change(
-                SIGNAL_MOVE_LEVEL, -args[1] if args[0] else args[1])
+                SIGNAL_MOVE_LEVEL, -args[1] if args[0] else args[1]
+            )
 
     @callback
     def attribute_updated(self, attrid, value):
         """Handle attribute updates on this cluster."""
-        _LOGGER.debug("%s: received attribute: %s update with value: %i",
-                      self.unique_id, attrid, value)
+        self.debug("received attribute: %s update with value: %s", attrid, value)
         if attrid == self.CURRENT_LEVEL:
             self.dispatch_level_change(SIGNAL_SET_LEVEL, value)
 
     def dispatch_level_change(self, command, level):
         """Dispatch level change."""
         async_dispatcher_send(
-            self._zha_device.hass,
-            "{}_{}".format(self.unique_id, command),
-            level
+            self._zha_device.hass, "{}_{}".format(self.unique_id, command), level
         )
 
     async def async_initialize(self, from_cache):
         """Initialize channel."""
-        await self.get_attribute_value(
-            self.CURRENT_LEVEL, from_cache=from_cache)
+        await self.get_attribute_value(self.CURRENT_LEVEL, from_cache=from_cache)
         await super().async_initialize(from_cache)
 
 
@@ -157,13 +137,13 @@ class BasicChannel(ZigbeeChannel):
     BATTERY = 3
 
     POWER_SOURCES = {
-        UNKNOWN: 'Unknown',
-        1: 'Mains (single phase)',
-        2: 'Mains (3 phase)',
-        BATTERY: 'Battery',
-        4: 'DC source',
-        5: 'Emergency mains constantly powered',
-        6: 'Emergency mains and transfer switch'
+        UNKNOWN: "Unknown",
+        1: "Mains (single phase)",
+        2: "Mains (3 phase)",
+        BATTERY: "Battery",
+        4: "DC source",
+        5: "Emergency mains constantly powered",
+        6: "Emergency mains and transfer switch",
     }
 
     def __init__(self, cluster, device):
@@ -179,7 +159,8 @@ class BasicChannel(ZigbeeChannel):
     async def async_initialize(self, from_cache):
         """Initialize channel."""
         self._power_source = await self.get_attribute_value(
-            'power_source', from_cache=from_cache)
+            "power_source", from_cache=from_cache
+        )
         await super().async_initialize(from_cache)
 
     def get_power_source(self):
@@ -193,7 +174,7 @@ class PowerConfigurationChannel(ZigbeeChannel):
     @callback
     def attribute_updated(self, attrid, value):
         """Handle attribute updates on this cluster."""
-        attr = self._report_config[1].get('attr')
+        attr = self._report_config[1].get("attr")
         if isinstance(attr, str):
             attr_id = get_attr_id_by_name(self.cluster, attr)
         else:
@@ -202,7 +183,7 @@ class PowerConfigurationChannel(ZigbeeChannel):
             async_dispatcher_send(
                 self._zha_device.hass,
                 "{}_{}".format(self.unique_id, SIGNAL_ATTR_UPDATED),
-                value
+                value,
             )
 
     async def async_initialize(self, from_cache):
@@ -216,11 +197,9 @@ class PowerConfigurationChannel(ZigbeeChannel):
 
     async def async_read_state(self, from_cache):
         """Read data from the cluster."""
+        await self.get_attribute_value("battery_size", from_cache=from_cache)
         await self.get_attribute_value(
-            'battery_size', from_cache=from_cache)
-        await self.get_attribute_value(
-            'battery_percentage_remaining', from_cache=from_cache)
-        await self.get_attribute_value(
-            'battery_voltage', from_cache=from_cache)
-        await self.get_attribute_value(
-            'battery_quantity', from_cache=from_cache)
+            "battery_percentage_remaining", from_cache=from_cache
+        )
+        await self.get_attribute_value("battery_voltage", from_cache=from_cache)
+        await self.get_attribute_value("battery_quantity", from_cache=from_cache)
