@@ -25,42 +25,44 @@ class IASZoneChannel(ZigbeeChannel):
             async_dispatcher_send(
                 self._zha_device.hass,
                 "{}_{}".format(self.unique_id, SIGNAL_ATTR_UPDATED),
-                state
+                state,
             )
-            _LOGGER.debug("Updated alarm state: %s", state)
+            self.debug("Updated alarm state: %s", state)
         elif command_id == 1:
-            _LOGGER.debug("Enroll requested")
+            self.debug("Enroll requested")
             res = self._cluster.enroll_response(0, 0)
             self._zha_device.hass.async_create_task(res)
 
     async def async_configure(self):
         """Configure IAS device."""
         # Xiaomi devices don't need this and it disrupts pairing
-        if self._zha_device.manufacturer == 'LUMI':
+        if self._zha_device.manufacturer == "LUMI":
             return
         from zigpy.exceptions import DeliveryError
-        _LOGGER.debug("%s: started IASZoneChannel configuration",
-                      self._unique_id)
+
+        self.debug("started IASZoneChannel configuration")
 
         await bind_cluster(self.unique_id, self._cluster)
         ieee = self._cluster.endpoint.device.application.ieee
 
         try:
-            res = await self._cluster.write_attributes({'cie_addr': ieee})
-            _LOGGER.debug(
-                "%s: wrote cie_addr: %s to '%s' cluster: %s",
-                self.unique_id, str(ieee), self._cluster.ep_attribute,
-                res[0]
+            res = await self._cluster.write_attributes({"cie_addr": ieee})
+            self.debug(
+                "wrote cie_addr: %s to '%s' cluster: %s",
+                str(ieee),
+                self._cluster.ep_attribute,
+                res[0],
             )
         except DeliveryError as ex:
-            _LOGGER.debug(
-                "%s: Failed to write cie_addr: %s to '%s' cluster: %s",
-                self.unique_id, str(ieee), self._cluster.ep_attribute, str(ex)
+            self.debug(
+                "Failed to write cie_addr: %s to '%s' cluster: %s",
+                str(ieee),
+                self._cluster.ep_attribute,
+                str(ex),
             )
-        _LOGGER.debug("%s: finished IASZoneChannel configuration",
-                      self._unique_id)
+        self.debug("%s: finished IASZoneChannel configuration")
 
-        await self.get_attribute_value('zone_type', from_cache=False)
+        await self.get_attribute_value("zone_type", from_cache=False)
 
     @callback
     def attribute_updated(self, attrid, value):
@@ -70,11 +72,11 @@ class IASZoneChannel(ZigbeeChannel):
             async_dispatcher_send(
                 self._zha_device.hass,
                 "{}_{}".format(self.unique_id, SIGNAL_ATTR_UPDATED),
-                value
+                value,
             )
 
     async def async_initialize(self, from_cache):
         """Initialize channel."""
-        await self.get_attribute_value('zone_status', from_cache=from_cache)
-        await self.get_attribute_value('zone_state', from_cache=from_cache)
+        await self.get_attribute_value("zone_status", from_cache=from_cache)
+        await self.get_attribute_value("zone_state", from_cache=from_cache)
         await super().async_initialize(from_cache)
