@@ -15,23 +15,55 @@ import traceback
 from homeassistant.components.system_log import LogEntry, _figure_out_source
 from homeassistant.core import callback
 from homeassistant.helpers.device_registry import (
-    CONNECTION_ZIGBEE, async_get_registry as get_dev_reg)
+    CONNECTION_ZIGBEE,
+    async_get_registry as get_dev_reg,
+)
 from homeassistant.helpers.dispatcher import async_dispatcher_send
 
 from ..api import async_get_device_info
 from .const import (
-    ADD_DEVICE_RELAY_LOGGERS, ATTR_MANUFACTURER, BELLOWS, CONF_BAUDRATE,
-    CONF_DATABASE, CONF_RADIO_TYPE, CONF_USB_PATH, CONTROLLER, CURRENT,
-    DATA_ZHA, DATA_ZHA_BRIDGE_ID, DATA_ZHA_GATEWAY, DEBUG_LEVELS,
-    DEFAULT_BAUDRATE, DEFAULT_DATABASE_NAME, DEVICE_FULL_INIT,
-    DEVICE_INFO, DEVICE_JOINED, DEVICE_REMOVED, DOMAIN, IEEE, LOG_ENTRY,
-    LOG_OUTPUT, MODEL, NWK, ORIGINAL, RADIO, RADIO_DESCRIPTION, RAW_INIT,
-    SIGNAL_REMOVE, SIGNATURE, TYPE, UNKNOWN_MANUFACTURER, UNKNOWN_MODEL, ZHA,
-    ZHA_GW_MSG, ZIGPY, ZIGPY_DECONZ, ZIGPY_XBEE)
-from .device import DeviceStatus, ZHADevice
-from .discovery import (
-    async_dispatch_discovery_info, async_process_endpoint
+    ADD_DEVICE_RELAY_LOGGERS,
+    ATTR_MANUFACTURER,
+    BELLOWS,
+    CONF_BAUDRATE,
+    CONF_DATABASE,
+    CONF_RADIO_TYPE,
+    CONF_USB_PATH,
+    CONTROLLER,
+    CURRENT,
+    DATA_ZHA,
+    DATA_ZHA_BRIDGE_ID,
+    DATA_ZHA_GATEWAY,
+    DEBUG_LEVELS,
+    DEFAULT_BAUDRATE,
+    DEFAULT_DATABASE_NAME,
+    DEVICE_FULL_INIT,
+    DEVICE_INFO,
+    DEVICE_JOINED,
+    DEVICE_REMOVED,
+    DOMAIN,
+    IEEE,
+    LOG_ENTRY,
+    LOG_OUTPUT,
+    MODEL,
+    NWK,
+    ORIGINAL,
+    RADIO,
+    RADIO_DESCRIPTION,
+    RAW_INIT,
+    SIGNAL_REMOVE,
+    SIGNATURE,
+    TYPE,
+    UNKNOWN_MANUFACTURER,
+    UNKNOWN_MODEL,
+    ZHA,
+    ZHA_GW_MSG,
+    ZIGPY,
+    ZIGPY_DECONZ,
+    ZIGPY_XBEE,
 )
+from .device import DeviceStatus, ZHADevice
+from .discovery import async_dispatch_discovery_info, async_process_endpoint
 from .patches import apply_application_controller_patch
 from .registries import INPUT_BIND_ONLY_CLUSTERS, RADIO_TYPES
 from .store import async_get_registry
@@ -39,8 +71,9 @@ from .store import async_get_registry
 _LOGGER = logging.getLogger(__name__)
 
 EntityReference = collections.namedtuple(
-    'EntityReference',
-    'reference_id zha_device cluster_channels device_info remove_future')
+    "EntityReference",
+    "reference_id zha_device cluster_channels device_info remove_future",
+)
 
 
 class ZHAGateway:
@@ -59,7 +92,7 @@ class ZHAGateway:
         hass.data[DATA_ZHA][DATA_ZHA_GATEWAY] = self
         self._log_levels = {
             ORIGINAL: async_capture_log_levels(),
-            CURRENT: async_capture_log_levels()
+            CURRENT: async_capture_log_levels(),
         }
         self.debug_enabled = False
         self._log_relay_handler = LogRelayHandler(hass, self)
@@ -82,16 +115,15 @@ class ZHAGateway:
         if CONF_DATABASE in self._config:
             database = self._config[CONF_DATABASE]
         else:
-            database = os.path.join(
-                self._hass.config.config_dir, DEFAULT_DATABASE_NAME)
+            database = os.path.join(self._hass.config.config_dir, DEFAULT_DATABASE_NAME)
 
-        self.application_controller = radio_details[CONTROLLER](
-            radio, database)
+        self.application_controller = radio_details[CONTROLLER](radio, database)
         apply_application_controller_patch(self)
         self.application_controller.add_listener(self)
         await self.application_controller.startup(auto_form=True)
         self._hass.data[DATA_ZHA][DATA_ZHA_BRIDGE_ID] = str(
-            self.application_controller.ieee)
+            self.application_controller.ieee
+        )
 
         init_tasks = []
         for device in self.application_controller.devices.values():
@@ -109,11 +141,7 @@ class ZHAGateway:
         async_dispatcher_send(
             self._hass,
             ZHA_GW_MSG,
-            {
-                TYPE: DEVICE_JOINED,
-                NWK: device.nwk,
-                IEEE: str(device.ieee)
-            }
+            {TYPE: DEVICE_JOINED, NWK: device.nwk, IEEE: str(device.ieee)},
         )
 
     def raw_device_initialized(self, device):
@@ -131,14 +159,13 @@ class ZHAGateway:
                 IEEE: str(device.ieee),
                 MODEL: device.model if device.model else UNKNOWN_MODEL,
                 ATTR_MANUFACTURER: manuf if manuf else UNKNOWN_MANUFACTURER,
-                SIGNATURE: device.get_signature()
-            }
+                SIGNATURE: device.get_signature(),
+            },
         )
 
     def device_initialized(self, device):
         """Handle device joined and basic information discovered."""
-        self._hass.async_create_task(
-            self.async_device_initialized(device, True))
+        self._hass.async_create_task(self.async_device_initialized(device, True))
 
     def device_left(self, device):
         """Handle device leaving the network."""
@@ -151,7 +178,8 @@ class ZHAGateway:
                 remove_tasks.append(entity_ref.remove_future)
             await asyncio.wait(remove_tasks)
         reg_device = self.ha_device_registry.async_get_device(
-            {(DOMAIN, str(device.ieee))}, set())
+            {(DOMAIN, str(device.ieee))}, set()
+        )
         if reg_device is not None:
             self.ha_device_registry.async_remove_device(reg_device.id)
 
@@ -163,20 +191,14 @@ class ZHAGateway:
             device_info = async_get_device_info(self._hass, zha_device)
             zha_device.async_unsub_dispatcher()
             async_dispatcher_send(
-                self._hass,
-                "{}_{}".format(SIGNAL_REMOVE, str(zha_device.ieee))
-            )
-            asyncio.ensure_future(
-                self._async_remove_device(zha_device, entity_refs)
+                self._hass, "{}_{}".format(SIGNAL_REMOVE, str(zha_device.ieee))
             )
+            asyncio.ensure_future(self._async_remove_device(zha_device, entity_refs))
             if device_info is not None:
                 async_dispatcher_send(
                     self._hass,
                     ZHA_GW_MSG,
-                    {
-                        TYPE: DEVICE_REMOVED,
-                        DEVICE_INFO: device_info
-                    }
+                    {TYPE: DEVICE_REMOVED, DEVICE_INFO: device_info},
                 )
 
     def get_device(self, ieee):
@@ -186,7 +208,8 @@ class ZHAGateway:
     def get_entity_reference(self, entity_id):
         """Return entity reference for given entity_id if found."""
         for entity_reference in itertools.chain.from_iterable(
-                self.device_registry.values()):
+            self.device_registry.values()
+        ):
             if entity_id == entity_reference.reference_id:
                 return entity_reference
 
@@ -195,7 +218,8 @@ class ZHAGateway:
         if entity.zha_device.ieee in self.device_registry:
             entity_refs = self.device_registry.get(entity.zha_device.ieee)
             self.device_registry[entity.zha_device.ieee] = [
-                e for e in entity_refs if e.reference_id != entity.entity_id]
+                e for e in entity_refs if e.reference_id != entity.entity_id
+            ]
 
     @property
     def devices(self):
@@ -208,8 +232,14 @@ class ZHAGateway:
         return self._device_registry
 
     def register_entity_reference(
-            self, ieee, reference_id, zha_device, cluster_channels,
-            device_info, remove_future):
+        self,
+        ieee,
+        reference_id,
+        zha_device,
+        cluster_channels,
+        device_info,
+        remove_future,
+    ):
         """Record the creation of a hass entity associated with ieee."""
         self._device_registry[ieee].append(
             EntityReference(
@@ -217,7 +247,7 @@ class ZHAGateway:
                 zha_device=zha_device,
                 cluster_channels=cluster_channels,
                 device_info=device_info,
-                remove_future=remove_future
+                remove_future=remove_future,
             )
         )
 
@@ -239,8 +269,7 @@ class ZHAGateway:
         async_set_logger_levels(self._log_levels[ORIGINAL])
         self._log_levels[CURRENT] = async_capture_log_levels()
         for logger_name in ADD_DEVICE_RELAY_LOGGERS:
-            logging.getLogger(logger_name).removeHandler(
-                self._log_relay_handler)
+            logging.getLogger(logger_name).removeHandler(self._log_relay_handler)
         self.debug_enabled = False
 
     @callback
@@ -256,7 +285,7 @@ class ZHAGateway:
                 identifiers={(DOMAIN, str(zha_device.ieee))},
                 name=zha_device.name,
                 manufacturer=zha_device.manufacturer,
-                model=zha_device.model
+                model=zha_device.model,
             )
         if not is_new_join:
             entry = self.zha_storage.async_get_or_create(zha_device)
@@ -265,8 +294,8 @@ class ZHAGateway:
 
     @callback
     def async_device_became_available(
-            self, sender, is_reply, profile, cluster, src_ep, dst_ep, tsn,
-            command_id, args):
+        self, sender, is_reply, profile, cluster, src_ep, dst_ep, tsn, command_id, args
+    ):
         """Handle tasks when a device becomes available."""
         self.async_update_device(sender)
 
@@ -297,21 +326,28 @@ class ZHAGateway:
             discovery_infos = []
             for endpoint_id, endpoint in device.endpoints.items():
                 async_process_endpoint(
-                    self._hass, self._config, endpoint_id, endpoint,
-                    discovery_infos, device, zha_device, is_new_join
+                    self._hass,
+                    self._config,
+                    endpoint_id,
+                    endpoint,
+                    discovery_infos,
+                    device,
+                    zha_device,
+                    is_new_join,
                 )
                 if endpoint_id != 0:
                     for cluster in endpoint.in_clusters.values():
-                        cluster.bind_only = \
+                        cluster.bind_only = (
                             cluster.cluster_id in INPUT_BIND_ONLY_CLUSTERS
+                        )
                     for cluster in endpoint.out_clusters.values():
                         # output clusters are always bind only
                         cluster.bind_only = True
         else:
             is_rejoin = is_new_join is True
             _LOGGER.debug(
-                'skipping discovery for previously discovered device: %s',
-                "{} - is rejoin: {}".format(zha_device.ieee, is_rejoin)
+                "skipping discovery for previously discovered device: %s",
+                "{} - is rejoin: {}".format(zha_device.ieee, is_rejoin),
             )
 
         if is_new_join:
@@ -324,7 +360,7 @@ class ZHAGateway:
             _LOGGER.debug(
                 "attempting to request fresh state for %s %s",
                 zha_device.name,
-                "with power source: {}".format(zha_device.power_source)
+                "with power source: {}".format(zha_device.power_source),
             )
             await zha_device.async_initialize(from_cache=False)
         else:
@@ -332,25 +368,16 @@ class ZHAGateway:
 
         if not is_rejoin:
             for discovery_info in discovery_infos:
-                async_dispatch_discovery_info(
-                    self._hass,
-                    is_new_join,
-                    discovery_info
-                )
+                async_dispatch_discovery_info(self._hass, is_new_join, discovery_info)
 
         if is_new_join:
             device_info = async_get_device_info(
-                self._hass,
-                zha_device,
-                self.ha_device_registry
+                self._hass, zha_device, self.ha_device_registry
             )
             async_dispatcher_send(
                 self._hass,
                 ZHA_GW_MSG,
-                {
-                    TYPE: DEVICE_FULL_INIT,
-                    DEVICE_INFO: device_info
-                }
+                {TYPE: DEVICE_FULL_INIT, DEVICE_INFO: device_info},
             )
 
     async def shutdown(self):
@@ -397,13 +424,7 @@ class LogRelayHandler(logging.Handler):
             if not record.exc_info:
                 stack = [f for f, _, _, _ in traceback.extract_stack()]
 
-        entry = LogEntry(record, stack,
-                         _figure_out_source(record, stack, self.hass))
+        entry = LogEntry(record, stack, _figure_out_source(record, stack, self.hass))
         async_dispatcher_send(
-            self.hass,
-            ZHA_GW_MSG,
-            {
-                TYPE: LOG_OUTPUT,
-                LOG_ENTRY: entry.to_dict()
-            }
+            self.hass, ZHA_GW_MSG, {TYPE: LOG_OUTPUT, LOG_ENTRY: entry.to_dict()}
         )
