@@ -24,11 +24,13 @@ from .const import _SECRET_NAMESPACE, SECRET_YAML
 from .objects import NodeListClass, NodeStrClass
 
 
+# mypy: allow-untyped-calls, no-warn-return-any
+
 _LOGGER = logging.getLogger(__name__)
 __SECRET_CACHE = {}  # type: Dict[str, JSON_TYPE]
 
 JSON_TYPE = Union[List, Dict, str]  # pylint: disable=invalid-name
-DICT_T = TypeVar('DICT_T', bound=Dict)  # pylint: disable=invalid-name
+DICT_T = TypeVar("DICT_T", bound=Dict)  # pylint: disable=invalid-name
 
 
 def clear_secret_cache() -> None:
@@ -43,12 +45,12 @@ def clear_secret_cache() -> None:
 class SafeLineLoader(yaml.SafeLoader):
     """Loader class that keeps track of line numbers."""
 
-    def compose_node(self, parent: yaml.nodes.Node,
-                     index: int) -> yaml.nodes.Node:
+    def compose_node(self, parent: yaml.nodes.Node, index: int) -> yaml.nodes.Node:
         """Annotate a node with the first line it was seen."""
         last_line = self.line  # type: int
-        node = super(SafeLineLoader,
-                     self).compose_node(parent, index)  # type: yaml.nodes.Node
+        node = super(SafeLineLoader, self).compose_node(
+            parent, index
+        )  # type: yaml.nodes.Node
         node.__line__ = last_line + 1  # type: ignore
         return node
 
@@ -56,7 +58,7 @@ class SafeLineLoader(yaml.SafeLoader):
 def load_yaml(fname: str) -> JSON_TYPE:
     """Load a YAML file."""
     try:
-        with open(fname, encoding='utf-8') as conf_file:
+        with open(fname, encoding="utf-8") as conf_file:
             # If configuration file is empty YAML returns None
             # We convert that to an empty dict
             return yaml.load(conf_file, Loader=SafeLineLoader) or OrderedDict()
@@ -70,38 +72,43 @@ def load_yaml(fname: str) -> JSON_TYPE:
 
 # pylint: disable=pointless-statement
 @overload
-def _add_reference(obj: Union[list, NodeListClass],
-                   loader: yaml.SafeLoader,
-                   node: yaml.nodes.Node) -> NodeListClass: ...
+def _add_reference(
+    obj: Union[list, NodeListClass], loader: yaml.SafeLoader, node: yaml.nodes.Node
+) -> NodeListClass:
+    ...
 
 
 @overload  # noqa: F811
-def _add_reference(obj: Union[str, NodeStrClass],
-                   loader: yaml.SafeLoader,
-                   node: yaml.nodes.Node) -> NodeStrClass: ...
+def _add_reference(
+    obj: Union[str, NodeStrClass], loader: yaml.SafeLoader, node: yaml.nodes.Node
+) -> NodeStrClass:
+    ...
 
 
 @overload  # noqa: F811
-def _add_reference(obj: DICT_T,
-                   loader: yaml.SafeLoader,
-                   node: yaml.nodes.Node) -> DICT_T: ...
+def _add_reference(
+    obj: DICT_T, loader: yaml.SafeLoader, node: yaml.nodes.Node
+) -> DICT_T:
+    ...
+
+
 # pylint: enable=pointless-statement
 
 
-def _add_reference(obj, loader: SafeLineLoader,  # type: ignore # noqa: F811
-                   node: yaml.nodes.Node):
+def _add_reference(  # type: ignore # noqa: F811
+    obj, loader: SafeLineLoader, node: yaml.nodes.Node
+):
     """Add file reference information to an object."""
     if isinstance(obj, list):
         obj = NodeListClass(obj)
     if isinstance(obj, str):
         obj = NodeStrClass(obj)
-    setattr(obj, '__config_file__', loader.name)
-    setattr(obj, '__line__', node.start_mark.line)
+    setattr(obj, "__config_file__", loader.name)
+    setattr(obj, "__line__", node.start_mark.line)
     return obj
 
 
-def _include_yaml(loader: SafeLineLoader,
-                  node: yaml.nodes.Node) -> JSON_TYPE:
+def _include_yaml(loader: SafeLineLoader, node: yaml.nodes.Node) -> JSON_TYPE:
     """Load another YAML file and embeds it using the !include tag.
 
     Example:
@@ -113,7 +120,7 @@ def _include_yaml(loader: SafeLineLoader,
 
 def _is_file_valid(name: str) -> bool:
     """Decide if a file is valid."""
-    return not name.startswith('.')
+    return not name.startswith(".")
 
 
 def _find_files(directory: str, pattern: str) -> Iterator[str]:
@@ -126,12 +133,13 @@ def _find_files(directory: str, pattern: str) -> Iterator[str]:
                 yield filename
 
 
-def _include_dir_named_yaml(loader: SafeLineLoader,
-                            node: yaml.nodes.Node) -> OrderedDict:
+def _include_dir_named_yaml(
+    loader: SafeLineLoader, node: yaml.nodes.Node
+) -> OrderedDict:
     """Load multiple files from directory as a dictionary."""
     mapping = OrderedDict()  # type: OrderedDict
     loc = os.path.join(os.path.dirname(loader.name), node.value)
-    for fname in _find_files(loc, '*.yaml'):
+    for fname in _find_files(loc, "*.yaml"):
         filename = os.path.splitext(os.path.basename(fname))[0]
         if os.path.basename(fname) == SECRET_YAML:
             continue
@@ -139,12 +147,13 @@ def _include_dir_named_yaml(loader: SafeLineLoader,
     return _add_reference(mapping, loader, node)
 
 
-def _include_dir_merge_named_yaml(loader: SafeLineLoader,
-                                  node: yaml.nodes.Node) -> OrderedDict:
+def _include_dir_merge_named_yaml(
+    loader: SafeLineLoader, node: yaml.nodes.Node
+) -> OrderedDict:
     """Load multiple files from directory as a merged dictionary."""
     mapping = OrderedDict()  # type: OrderedDict
     loc = os.path.join(os.path.dirname(loader.name), node.value)
-    for fname in _find_files(loc, '*.yaml'):
+    for fname in _find_files(loc, "*.yaml"):
         if os.path.basename(fname) == SECRET_YAML:
             continue
         loaded_yaml = load_yaml(fname)
@@ -153,21 +162,25 @@ def _include_dir_merge_named_yaml(loader: SafeLineLoader,
     return _add_reference(mapping, loader, node)
 
 
-def _include_dir_list_yaml(loader: SafeLineLoader,
-                           node: yaml.nodes.Node) -> List[JSON_TYPE]:
+def _include_dir_list_yaml(
+    loader: SafeLineLoader, node: yaml.nodes.Node
+) -> List[JSON_TYPE]:
     """Load multiple files from directory as a list."""
     loc = os.path.join(os.path.dirname(loader.name), node.value)
-    return [load_yaml(f) for f in _find_files(loc, '*.yaml')
-            if os.path.basename(f) != SECRET_YAML]
+    return [
+        load_yaml(f)
+        for f in _find_files(loc, "*.yaml")
+        if os.path.basename(f) != SECRET_YAML
+    ]
 
 
-def _include_dir_merge_list_yaml(loader: SafeLineLoader,
-                                 node: yaml.nodes.Node) -> JSON_TYPE:
+def _include_dir_merge_list_yaml(
+    loader: SafeLineLoader, node: yaml.nodes.Node
+) -> JSON_TYPE:
     """Load multiple files from directory as a merged list."""
-    loc = os.path.join(os.path.dirname(loader.name),
-                       node.value)  # type: str
+    loc = os.path.join(os.path.dirname(loader.name), node.value)  # type: str
     merged_list = []  # type: List[JSON_TYPE]
-    for fname in _find_files(loc, '*.yaml'):
+    for fname in _find_files(loc, "*.yaml"):
         if os.path.basename(fname) == SECRET_YAML:
             continue
         loaded_yaml = load_yaml(fname)
@@ -176,8 +189,7 @@ def _include_dir_merge_list_yaml(loader: SafeLineLoader,
     return _add_reference(merged_list, loader, node)
 
 
-def _ordered_dict(loader: SafeLineLoader,
-                  node: yaml.nodes.MappingNode) -> OrderedDict:
+def _ordered_dict(loader: SafeLineLoader, node: yaml.nodes.MappingNode) -> OrderedDict:
     """Load YAML mappings into an ordered dictionary to preserve key order."""
     loader.flatten_mapping(node)
     nodes = loader.construct_pairs(node)
@@ -189,17 +201,21 @@ def _ordered_dict(loader: SafeLineLoader,
         try:
             hash(key)
         except TypeError:
-            fname = getattr(loader.stream, 'name', '')
+            fname = getattr(loader.stream, "name", "")
             raise yaml.MarkedYAMLError(
-                context="invalid key: \"{}\"".format(key),
-                context_mark=yaml.Mark(fname, 0, line, -1, None, None)
+                context='invalid key: "{}"'.format(key),
+                context_mark=yaml.Mark(fname, 0, line, -1, None, None),
             )
 
         if key in seen:
-            fname = getattr(loader.stream, 'name', '')
+            fname = getattr(loader.stream, "name", "")
             _LOGGER.error(
-                'YAML file %s contains duplicate key "%s". '
-                'Check lines %d and %d.', fname, key, seen[key], line)
+                'YAML file %s contains duplicate key "%s". ' "Check lines %d and %d.",
+                fname,
+                key,
+                seen[key],
+                line,
+            )
         seen[key] = line
 
     return _add_reference(OrderedDict(nodes), loader, node)
@@ -211,14 +227,13 @@ def _construct_seq(loader: SafeLineLoader, node: yaml.nodes.Node) -> JSON_TYPE:
     return _add_reference(obj, loader, node)
 
 
-def _env_var_yaml(loader: SafeLineLoader,
-                  node: yaml.nodes.Node) -> str:
+def _env_var_yaml(loader: SafeLineLoader, node: yaml.nodes.Node) -> str:
     """Load environment variables and embed it into the configuration YAML."""
     args = node.value.split()
 
     # Check for a default value
     if len(args) > 1:
-        return os.getenv(args[0], ' '.join(args[1:]))
+        return os.getenv(args[0], " ".join(args[1:]))
     if args[0] in os.environ:
         return os.environ[args[0]]
     _LOGGER.error("Environment variable %s not defined.", node.value)
@@ -231,35 +246,39 @@ def _load_secret_yaml(secret_path: str) -> JSON_TYPE:
     if secret_path in __SECRET_CACHE:
         return __SECRET_CACHE[secret_path]
 
-    _LOGGER.debug('Loading %s', secret_path)
+    _LOGGER.debug("Loading %s", secret_path)
     try:
         secrets = load_yaml(secret_path)
         if not isinstance(secrets, dict):
-            raise HomeAssistantError('Secrets is not a dictionary')
-        if 'logger' in secrets:
-            logger = str(secrets['logger']).lower()
-            if logger == 'debug':
+            raise HomeAssistantError("Secrets is not a dictionary")
+        if "logger" in secrets:
+            logger = str(secrets["logger"]).lower()
+            if logger == "debug":
                 _LOGGER.setLevel(logging.DEBUG)
             else:
-                _LOGGER.error("secrets.yaml: 'logger: debug' expected,"
-                              " but 'logger: %s' found", logger)
-            del secrets['logger']
+                _LOGGER.error(
+                    "secrets.yaml: 'logger: debug' expected," " but 'logger: %s' found",
+                    logger,
+                )
+            del secrets["logger"]
     except FileNotFoundError:
         secrets = {}
     __SECRET_CACHE[secret_path] = secrets
     return secrets
 
 
-def secret_yaml(loader: SafeLineLoader,
-                node: yaml.nodes.Node) -> JSON_TYPE:
+def secret_yaml(loader: SafeLineLoader, node: yaml.nodes.Node) -> JSON_TYPE:
     """Load secrets and embed it into the configuration YAML."""
     secret_path = os.path.dirname(loader.name)
     while True:
         secrets = _load_secret_yaml(secret_path)
 
         if node.value in secrets:
-            _LOGGER.debug("Secret %s retrieved from secrets.yaml in "
-                          "folder %s", node.value, secret_path)
+            _LOGGER.debug(
+                "Secret %s retrieved from secrets.yaml in " "folder %s",
+                node.value,
+                secret_path,
+            )
             return secrets[node.value]
 
         if secret_path == os.path.dirname(sys.path[0]):
@@ -294,16 +313,18 @@ def secret_yaml(loader: SafeLineLoader,
     raise HomeAssistantError("Secret {} not defined".format(node.value))
 
 
-yaml.SafeLoader.add_constructor('!include', _include_yaml)
-yaml.SafeLoader.add_constructor(yaml.resolver.BaseResolver.DEFAULT_MAPPING_TAG,
-                                _ordered_dict)
+yaml.SafeLoader.add_constructor("!include", _include_yaml)
 yaml.SafeLoader.add_constructor(
-    yaml.resolver.BaseResolver.DEFAULT_SEQUENCE_TAG, _construct_seq)
-yaml.SafeLoader.add_constructor('!env_var', _env_var_yaml)
-yaml.SafeLoader.add_constructor('!secret', secret_yaml)
-yaml.SafeLoader.add_constructor('!include_dir_list', _include_dir_list_yaml)
-yaml.SafeLoader.add_constructor('!include_dir_merge_list',
-                                _include_dir_merge_list_yaml)
-yaml.SafeLoader.add_constructor('!include_dir_named', _include_dir_named_yaml)
-yaml.SafeLoader.add_constructor('!include_dir_merge_named',
-                                _include_dir_merge_named_yaml)
+    yaml.resolver.BaseResolver.DEFAULT_MAPPING_TAG, _ordered_dict
+)
+yaml.SafeLoader.add_constructor(
+    yaml.resolver.BaseResolver.DEFAULT_SEQUENCE_TAG, _construct_seq
+)
+yaml.SafeLoader.add_constructor("!env_var", _env_var_yaml)
+yaml.SafeLoader.add_constructor("!secret", secret_yaml)
+yaml.SafeLoader.add_constructor("!include_dir_list", _include_dir_list_yaml)
+yaml.SafeLoader.add_constructor("!include_dir_merge_list", _include_dir_merge_list_yaml)
+yaml.SafeLoader.add_constructor("!include_dir_named", _include_dir_named_yaml)
+yaml.SafeLoader.add_constructor(
+    "!include_dir_merge_named", _include_dir_merge_named_yaml
+)
